/*!
 * Quasar Framework v0.7.1
 * (c) 2016 Razvan Stoenescu
 * Released under the MIT License.
 */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Velocity$1 = _interopDefault(require('velocity-animate'));
var velocityAnimate_velocity_ui = require('velocity-animate/velocity.ui');
var moment = _interopDefault(require('moment'));
var Hammer = _interopDefault(require('hammerjs'));
var FastClick = _interopDefault(require('fastclick'));

function getUserAgent() {
  return (navigator.userAgent || navigator.vendor || window.opera).toLowerCase();
}

function getMatch(userAgent, platformMatch) {
  var match = /(edge)\/([\w.]+)/.exec(userAgent) || /(opr)[\/]([\w.]+)/.exec(userAgent) || /(chrome)[\/]([\w.]+)/.exec(userAgent) || /(iemobile)[\/]([\w.]+)/.exec(userAgent) || /(version)(applewebkit)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) || /(webkit)[\/]([\w.]+).*(version)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) || /(webkit)[\/]([\w.]+)/.exec(userAgent) || /(opera)(?:.*version|)[\/]([\w.]+)/.exec(userAgent) || /(msie) ([\w.]+)/.exec(userAgent) || userAgent.indexOf('trident') >= 0 && /(rv)(?::| )([\w.]+)/.exec(userAgent) || userAgent.indexOf('compatible') < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(userAgent) || [];

  return {
    browser: match[5] || match[3] || match[1] || '',
    version: match[2] || match[4] || '0',
    versionNumber: match[4] || match[2] || '0',
    platform: platformMatch[0] || ''
  };
}

function getPlatformMatch(userAgent) {
  return (/(ipad)/.exec(userAgent) || /(ipod)/.exec(userAgent) || /(windows phone)/.exec(userAgent) || /(iphone)/.exec(userAgent) || /(kindle)/.exec(userAgent) || /(silk)/.exec(userAgent) || /(android)/.exec(userAgent) || /(win)/.exec(userAgent) || /(mac)/.exec(userAgent) || /(linux)/.exec(userAgent) || /(cros)/.exec(userAgent) || /(playbook)/.exec(userAgent) || /(bb)/.exec(userAgent) || /(blackberry)/.exec(userAgent) || []
  );
}

function getPlatform() {
  var userAgent = getUserAgent(),
      platformMatch = getPlatformMatch(userAgent),
      matched = getMatch(userAgent, platformMatch),
      browser = {};

  if (matched.browser) {
    browser[matched.browser] = true;
    browser.version = matched.version;
    browser.versionNumber = parseInt(matched.versionNumber, 10);
  }

  if (matched.platform) {
    browser[matched.platform] = true;
  }

  if (browser.android || browser.bb || browser.blackberry || browser.ipad || browser.iphone || browser.ipod || browser.kindle || browser.playbook || browser.silk || browser['windows phone']) {
    browser.mobile = true;
  }

  if (browser.ipod || browser.ipad || browser.iphone) {
    browser.ios = true;
  }

  if (browser['windows phone']) {
    browser.winphone = true;
    delete browser['windows phone'];
  }

  if (browser.cros || browser.mac || browser.linux || browser.win) {
    browser.desktop = true;
  }

  if (browser.chrome || browser.opr || browser.safari) {
    browser.webkit = true;
  }

  if (browser.rv || browser.iemobile) {
    matched.browser = 'ie';
    browser.ie = true;
  }

  if (browser.edge) {
    matched.browser = 'edge';
    browser.edge = true;
  }

  if (browser.safari && browser.blackberry || browser.bb) {
    matched.browser = 'blackberry';
    browser.blackberry = true;
  }

  if (browser.safari && browser.playbook) {
    matched.browser = 'playbook';
    browser.playbook = true;
  }

  if (browser.opr) {
    matched.browser = 'opera';
    browser.opera = true;
  }

  if (browser.safari && browser.android) {
    matched.browser = 'android';
    browser.android = true;
  }

  if (browser.safari && browser.kindle) {
    matched.browser = 'kindle';
    browser.kindle = true;
  }

  if (browser.safari && browser.silk) {
    matched.browser = 'silk';
    browser.silk = true;
  }

  browser.name = matched.browser;
  browser.platform = matched.platform;

  if (window._cordovaNative) {
    browser.cordova = true;
  }

  return browser;
}

var Platform = {
  is: getPlatform(),
  has: {
    touch: function () {
      return !!('ontouchstart' in document.documentElement) || window.navigator.msMaxTouchPoints > 0;
    }()
  },
  within: {
    iframe: window.self !== window.top
  }
};

function parseEventNames(eventNames) {
  return eventNames.trim().replace(/\s\s+/g, ' ').split(' ');
}

function remove$1(events, eventName, filterFn) {
  events[eventName] = events[eventName].filter(filterFn);
  if (events[eventName].length === 0) {
    delete events[eventName];
  }
}

function on(eventNames, callback, context, once) {
  var _this = this;

  if (!eventNames) {
    throw new Error('Missing event(s) name(s)');
  }
  if (!callback) {
    throw new Error('Missing callback');
  }
  if (typeof callback !== 'function') {
    throw new Error('Callback is not a function');
  }

  parseEventNames(eventNames).forEach(function (eventName) {
    if (!_this.events.hasOwnProperty(eventName)) {
      _this.events[eventName] = [];
    }

    if (_this.events[eventName].some(function (item) {
      return item.cb === callback;
    })) {
      return;
    }

    _this.events[eventName].push({
      cb: callback,
      context: context,
      once: once
    });
  });
}

function off(eventNames, callback) {
  var _this2 = this;

  if (!eventNames) {
    this.events = {};
    return;
  }

  if (callback && typeof callback !== 'function') {
    throw new Error('Callback is not a function');
  }

  parseEventNames(eventNames).forEach(function (eventName) {
    if (!_this2.events.hasOwnProperty(eventName)) {
      return;
    }

    if (!callback) {
      delete _this2.events[eventName];
      return;
    }

    remove$1(_this2.events, eventName, function (ev) {
      return ev.cb !== callback;
    });
  });
}

function once(eventNames, callback, context) {
  on.call(this, eventNames, callback, context, true);
}

function trigger$1(eventNames) {
  var _this3 = this;

  for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  if (!eventNames) {
    eventNames = getList.call(this).join(' ');
  }

  parseEventNames(eventNames).forEach(function (eventName) {
    if (!_this3.events.hasOwnProperty(eventName)) {
      return;
    }

    var onceList = [];

    _this3.events[eventName].forEach(function (ev) {
      ev.cb.apply(ev.context, args);
      if (ev.once) {
        onceList.push(ev);
      }
    });

    remove$1(_this3.events, eventName, function (ev) {
      return !onceList.includes(ev);
    });
  });
}

function hasSubscriber(eventNames, callback) {
  var _this4 = this;

  if (!eventNames) {
    return Object.keys(this.events).length !== 0;
  }

  if (typeof eventNames === 'function') {
    callback = eventNames;
    eventNames = getList.call(this).join(' ');
  }

  if (callback && typeof callback !== 'function') {
    throw new Error('Callback is not a function');
  }

  var foundSubscriber = false;

  parseEventNames(eventNames).forEach(function (eventName) {
    var result = _this4.events.hasOwnProperty(eventName);

    if (!result) {
      return;
    }

    if (callback) {
      result = _this4.events[eventName].some(function (item) {
        return item.cb === callback;
      });

      if (result) {
        foundSubscriber = true;
      }
      return;
    }

    foundSubscriber = true;
  });

  return foundSubscriber;
}

function getList() {
  return Object.keys(this.events);
}

function createEmitter() {
  var props = {
    events: {}
  };

  return {
    on: on.bind(props),
    off: off.bind(props),
    once: once.bind(props),
    trigger: trigger$1.bind(props),

    hasSubscriber: hasSubscriber.bind(props),
    getList: getList.bind(props)
  };
}

var Events = createEmitter();

function set$1(theme) {
  if (current) {
    document.body.classList.remove(current);
  }

  current = theme;
  document.body.classList.add(theme);
}

var current;

var theme = Object.freeze({
	set: set$1,
	get current () { return current; }
});

var transitionSlide = {
  css: false,

  enter: function enter(el, done) {
    Velocity(el, 'stop');
    Velocity(el, 'slideDown', done);
  },
  enterCancelled: function enterCancelled(el) {
    Velocity(el, 'stop');
    el.removeAttribute('style');
  },
  leave: function leave(el, done) {
    Velocity(el, 'stop');
    Velocity(el, 'slideUp', done);
  },
  leaveCancelled: function leaveCancelled(el) {
    Velocity(el, 'stop');
    el.removeAttribute('style');
  }
};

var GridSelectedFilter = function (data, filter, selectionMode, singleSelection) {
  if (!filter || selectionMode === 'none') {
    return data;
  }

  if (selectionMode === 'single') {
    return singleSelection;
  }

  return data.filter(function (row) {
    return row.__selected;
  });
}

var directiveAttr = function (attribs, oldAttribs) {
  var _this = this;

  if (typeof attribs === 'undefined') {
    console.error('v-attr received empty new value from "' + oldAttribs + '"', this.el);
    return;
  }

  var values = Array.isArray(attribs) ? attribs : [attribs];

  if (typeof oldAttribs !== 'undefined') {
    var oldValues = Array.isArray(oldAttribs) ? oldAttribs : [oldAttribs];

    oldValues = oldValues.filter(function (val) {
      return !values.includes(val);
    });
    oldValues.forEach(function (val) {
      _this.el.removeAttribute(val);
    });
  }

  values.forEach(function (value) {
    _this.el.setAttribute(value, '');
  });
}

var directiveGoBack = {
  bind: function bind() {
    var _this = this;

    if (Platform.is.cordova) {
      this.goBack = function () {
        window.history.go(-1);
      };
    } else {
      this.goBack = function () {
        _this.vm.$router.go(_this.route);
      };
    }

    this.el.addEventListener('click', this.goBack);
  },
  update: function update(route) {
    this.route = route;
  },
  unbind: function unbind() {
    this.el.removeEventListener('click', this.goBack);
  }
};

var template = "<div>\n  <div class=\"modal-header\">\n    {{{* title || ''}}}\n  </div>\n  <div v-if=\"message\" class=\"modal-body modal-scroll\">\n    {{{* message}}}\n  </div>\n  <div v-if=\"inputs\" class=\"modal-body modal-scroll\">\n    <div v-for=\"input in inputs\" class=\"floating-label\" style=\"margin-bottom: 10px\">\n      <input type=\"text\" class=\"full-width\" v-model=\"input.model\" required>\n      <label>{{ input.label }}</label>\n    </div>\n  </div>\n  <div v-if=\"radios\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"radio in radios\" class=\"item\">\n      <div class=\"item-primary\">\n        <quasar-radio :model.sync=\"radioModel\" :value.once=\"radio.value\"></quasar-radio>\n      </div>\n      <div class=\"item-content\">\n        {{{* radio.label}}}\n      </div>\n    </label>\n  </div>\n  <div v-if=\"checkboxes\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"checkbox in checkboxes\" class=\"item\">\n      <div class=\"item-primary\">\n        <quasar-checkbox :model.sync=\"checkbox.checked\"></quasar-checkbox>\n      </div>\n      <div class=\"item-content\">\n        {{{* checkbox.label}}}\n      </div>\n    </label>\n  </div>\n  <div v-if=\"toggles\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"toggle in toggles\" class=\"item\">\n      <div class=\"item-content has-secondary\">\n        {{{* toggle.label}}}\n      </div>\n      <div class=\"item-secondary\">\n        <quasar-toggle :model.sync=\"toggle.checked\"></quasar-toggle>\n      </div>\n    </label>\n  </div>\n  <div v-if=\"progress\" class=\"modal-slim-body\">\n    <quasar-progress\n      :model=\"progress.model\"\n      class=\"primary stripe\"\n      :class=\"{indeterminate: progress.indeterminate}\"\n    ></quasar-progress>\n    <span v-if=\"!progress.indeterminate\">\n      {{progress.model}} %\n    </span>\n  </div>\n  <div\n    v-if=\"buttons\"\n    class=\"modal-buttons\"\n    :class=\"{row: !stackButtons, column: stackButtons}\"\n  >\n    <button\n      v-for=\"button in buttons\"\n      class=\"primary clear\"\n      @click=\"trigger(button.handler)\"\n    >\n      {{{* button.label}}}\n    </button>\n  </div>\n</div>\n";

var handlers = [];

if (Platform.is.desktop) {
  window.addEventListener('keyup', function (evt) {
    if (handlers.length === 0) {
      return;
    }

    if (evt.which === 27 || evt.keyCode === 27) {
      handlers[handlers.length - 1]();
    }
  });
}

var EscapeKey = {
  register: function register(handler) {
    if (Platform.is.desktop) {
      handlers.push(handler);
    }
  },
  pop: function pop() {
    if (Platform.is.desktop) {
      handlers.pop();
    }
  }
};

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
};





var asyncGenerator = function () {
  function AwaitValue(value) {
    this.value = value;
  }

  function AsyncGenerator(gen) {
    var front, back;

    function send(key, arg) {
      return new Promise(function (resolve, reject) {
        var request = {
          key: key,
          arg: arg,
          resolve: resolve,
          reject: reject,
          next: null
        };

        if (back) {
          back = back.next = request;
        } else {
          front = back = request;
          resume(key, arg);
        }
      });
    }

    function resume(key, arg) {
      try {
        var result = gen[key](arg);
        var value = result.value;

        if (value instanceof AwaitValue) {
          Promise.resolve(value.value).then(function (arg) {
            resume("next", arg);
          }, function (arg) {
            resume("throw", arg);
          });
        } else {
          settle(result.done ? "return" : "normal", result.value);
        }
      } catch (err) {
        settle("throw", err);
      }
    }

    function settle(type, value) {
      switch (type) {
        case "return":
          front.resolve({
            value: value,
            done: true
          });
          break;

        case "throw":
          front.reject(value);
          break;

        default:
          front.resolve({
            value: value,
            done: false
          });
          break;
      }

      front = front.next;

      if (front) {
        resume(front.key, front.arg);
      } else {
        back = null;
      }
    }

    this._invoke = send;

    if (typeof gen.return !== "function") {
      this.return = undefined;
    }
  }

  if (typeof Symbol === "function" && Symbol.asyncIterator) {
    AsyncGenerator.prototype[Symbol.asyncIterator] = function () {
      return this;
    };
  }

  AsyncGenerator.prototype.next = function (arg) {
    return this._invoke("next", arg);
  };

  AsyncGenerator.prototype.throw = function (arg) {
    return this._invoke("throw", arg);
  };

  AsyncGenerator.prototype.return = function (arg) {
    return this._invoke("return", arg);
  };

  return {
    wrap: function (fn) {
      return function () {
        return new AsyncGenerator(fn.apply(this, arguments));
      };
    },
    await: function (value) {
      return new AwaitValue(value);
    }
  };
}();





var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();







var get = function get(object, property, receiver) {
  if (object === null) object = Function.prototype;
  var desc = Object.getOwnPropertyDescriptor(object, property);

  if (desc === undefined) {
    var parent = Object.getPrototypeOf(object);

    if (parent === null) {
      return undefined;
    } else {
      return get(parent, property, receiver);
    }
  } else if ("value" in desc) {
    return desc.value;
  } else {
    var getter = desc.get;

    if (getter === undefined) {
      return undefined;
    }

    return getter.call(receiver);
  }
};

















var set$2 = function set$2(object, property, value, receiver) {
  var desc = Object.getOwnPropertyDescriptor(object, property);

  if (desc === undefined) {
    var parent = Object.getPrototypeOf(object);

    if (parent !== null) {
      set$2(parent, property, value, receiver);
    }
  } else if ("value" in desc && desc.writable) {
    desc.value = value;
  } else {
    var setter = desc.set;

    if (setter !== undefined) {
      setter.call(receiver, value);
    }
  }

  return value;
};

var duration = 300;
var openedModalNumber = 0;

var Modal = function () {
  function Modal(userVm) {
    var _this = this;

    classCallCheck(this, Modal);

    if (!userVm) {
      throw new Error('Modal needs a VueModel.');
    }

    if (userVm.nodeType) {
      this.__customElement = userVm;
    } else if (!userVm.template) {
      console.error('Error in Modal create object:', userVm);
      throw new Error('Modal needs a template.');
    } else if (userVm.el) {
      console.error('Error in Modal create object:', userVm);
      throw new Error('Specifying "el" property for VM in a Modal is forbidden');
    }

    var vm = void 0;

    if (this.__customElement) {
      vm = { el: this.__customElement };
    } else {
      vm = Utils.extend(true, userVm);
      vm.template = '<div class="modal hidden fullscreen flex items-center justify-center">\n            <div v-el:backdrop class="modal-backdrop backdrop"></div>\n            <div v-el:content class="modal-content">' + userVm.template + '</div></div>';

      vm.data = userVm.data;
      vm.methods = vm.methods || {};
      vm.methods.close = function (onClose) {
        _this.close(onClose);
      };
    }

    this.vm = new Vue(vm);
    if (!this.__customElement) {
      this.vm.$mount().$appendTo(document.body);
      this.$content = this.vm.$els.content;
      this.$backdrop = this.vm.$els.backdrop;
    } else {
      this.$content = this.vm.$el.getElementsByClassName('modal-content')[0];
      this.$backdrop = this.vm.$el.getElementsByClassName('modal-backdrop')[0];
    }

    this.$el = this.vm.$el;
    this.__onShowHandlers = [];
    this.__onCloseHandlers = [];
    this.selfDestroy = true;
  }

  createClass(Modal, [{
    key: 'show',
    value: function show(onShow) {
      var _this2 = this;

      if (this.active) {
        console.warn('Modal is already displayed');
        return;
      }

      if (!this.$el.closest('body')) {
        throw new Error('Modal was previously destroyed. Create another one.');
      }

      if (this.minimized && this.maximized) {
        throw new Error('Modal cannot be minimized & maximized simultaneous.');
      }

      this.$content.classList.remove('minimized', 'maximized');
      if (this.minimized) {
        this.$content.classList.add('minimized');
      }
      if (this.maximized) {
        this.$content.classList.add('maximized');
      }

      if (this.closeWithBackdrop) {
        this.$backdrop.addEventListener('click', this.close);
      }

      document.body.classList.add('with-modal');

      var effect = void 0,
          options = {
        duration: duration,
        complete: function complete() {
          EscapeKey.register(function () {
            _this2.close(_this2.onEscapeKey);
          });
          _this2.__onShowHandlers.forEach(function (handler) {
            handler();
          });
          if (typeof onShow === 'function') {
            onShow();
          }
          _this2.active = true;
        }
      };

      if (this.transitionIn) {
        effect = this.transitionIn;
      } else if (current === 'mat') {
        effect = 'transition.slideUpIn';
      } else if (!this.minimized && (this.maximized || Utils.dom.viewport().width <= 600)) {
        effect = { translateX: [0, '101%'] };
      } else {
        effect = 'transition.shrinkIn';
      }

      this.$el.classList.remove('hidden');
      setTimeout(function () {
        [].slice.call(_this2.$el.getElementsByClassName('modal-scroll')).forEach(function (el) {
          el.scrollTop = 0;
        });
      }, 10);
      if (!this.maximized) {
        this.$backdrop.classList.add('active');
      }

      this.__popstate = function () {
        if (!Platform.within.iframe && window.history.state && window.history.state.modalId && window.history.state.modalId >= _this2.__modalId) {
          return;
        }
        openedModalNumber--;
        _this2.active = false;

        var effect = void 0,
            options = {
          duration: duration,
          complete: function complete() {
            _this2.$el.classList.add('hidden');
            if (!openedModalNumber) {
              document.body.classList.remove('with-modal');
            }

            if (_this2.selfDestroy) {
              _this2.destroy();
            }
            if (_this2.__closedByBackButton && _this2.onBackButton) {
              _this2.onBackButton();
            }
            _this2.__onCloseHandlers.forEach(function (handler) {
              handler();
            });
            if (typeof _this2.__onClose === 'function') {
              _this2.__onClose();
              delete _this2.__onClose;
            }
          }
        };

        if (_this2.transitionOut) {
          effect = _this2.transitionOut;
        } else if (!_this2.minimized && (_this2.maximized || Utils.dom.viewport().width <= 600)) {
          effect = current === 'ios' ? { translateX: ['101%', 0] } : 'transition.slideDownOut';
        } else {
          effect = current === 'ios' ? 'transition.shrinkOut' : 'transition.expandOut';
        }

        _this2.$backdrop.classList.remove('active');
        if (_this2.closeWithBackdrop) {
          _this2.$backdrop.removeEventListener('click', _this2.close);
        }
        if (!Platform.within.iframe) {
          window.removeEventListener('popstate', _this2.__popstate);
        }
        EscapeKey.pop();
        Velocity(_this2.$content, effect, options);
      };
      this.__modalId = ++openedModalNumber;
      this.__closedByBackButton = true;
      if (!Platform.within.iframe) {
        window.history.pushState({ modalId: this.__modalId }, '');
        window.addEventListener('popstate', this.__popstate);
      }

      Velocity(this.$content, effect, options);

      return this;
    }
  }, {
    key: 'close',
    value: function close(onClose) {
      this.__onClose = onClose;
      this.__closedByBackButton = false;
      if (Platform.within.iframe) {
        this.__popstate();
      } else {
        window.history.go(-1);
      }
      return this;
    }
  }, {
    key: 'onShow',
    value: function onShow(handler) {
      this.__registerTrigger('onShow', handler);
      return this;
    }
  }, {
    key: 'onClose',
    value: function onClose(handler) {
      this.__registerTrigger('onClose', handler);
      return this;
    }
  }, {
    key: '__registerTrigger',
    value: function __registerTrigger(event, handler) {
      if (typeof handler !== 'function') {
        throw new Error('Modal ' + event + ' handler must be a function.');
      }

      this['__' + event + 'Handlers'].push(handler);
      return this;
    }
  }, {
    key: 'set',
    value: function set(properties) {
      var _this3 = this;

      if (properties !== Object(properties)) {
        throw new Error('Modal.set() needs an object as parameter.');
      }

      Object.keys(properties).forEach(function (property) {
        _this3[property] = properties[property];
      });

      return this;
    }
  }, {
    key: 'css',
    value: function css(properties) {
      if (properties !== Object(properties)) {
        throw new Error('Modal.css() needs an object as parameter.');
      }

      Utils.dom.css(this.$content, properties);
      return this;
    }
  }, {
    key: 'destroy',
    value: function destroy() {
      this.vm.$destroy(!this.__customElement);
    }
  }]);
  return Modal;
}();

var Modal$1 = {
  create: function create(vm) {
    return new Modal(vm);
  }
};

function parseButtons(buttons) {
  if (buttons === false) {
    return false;
  }

  if (!Array.isArray(buttons)) {
    throw new Error('Dialog buttons parameter must be an array.');
  }

  if (buttons.some(function (button) {
    return typeof button !== 'string' && (Object(button) !== button || typeof button.label === 'undefined' || typeof button.handler !== 'function');
  })) {
    throw new Error('At least one of Dialog\'s button parameter is neither a string nor an object with both label handler.');
  }

  return buttons.map(function (button) {
    if (typeof button === 'string') {
      return {
        label: button,
        handler: function handler() {}
      };
    }
    return button;
  });
}

function parseInputs(inputs) {
  if (!Array.isArray(inputs)) {
    throw new Error('Dialog inputs parameter must be an array.');
  }

  return inputs.map(function (input) {
    input.model = input.model || '';
    return input;
  });
}

function parseRadios(radios) {
  if (!Array.isArray(radios)) {
    throw new Error('Dialog radios parameter must be an array.');
  }

  if (radios.some(function (radio) {
    return typeof radio.label === 'undefined' || typeof radio.value === 'undefined';
  })) {
    throw new Error('One of Dialog\'s radio parameter is missing either label or value');
  }

  var selectedValue = radios.filter(function (radio) {
    return radio.selected;
  });

  if (selectedValue.length === 0) {
    return radios[0].value;
  }

  if (selectedValue.length > 1) {
    throw new Error('Multiple Dialog radio parameters are selected.');
  }

  return selectedValue[0].value;
}

function parseCheckboxes(checkboxes) {
  if (!Array.isArray(checkboxes)) {
    throw new Error('Dialog checkboxes parameter must be an array.');
  }

  if (checkboxes.some(function (checkbox) {
    return typeof checkbox.label === 'undefined' || typeof checkbox.value === 'undefined';
  })) {
    throw new Error('One of Dialog\'s checkbox parameter is missing either label or value');
  }

  return checkboxes.map(function (checkbox) {
    checkbox.checked = checkbox.checked || false;
    return checkbox;
  });
}

function parseProgress(progress) {
  if (progress !== Object(progress)) {
    throw new Error('Progress property is not an Object.');
  }

  if (!progress.hasOwnProperty('model') && !progress.indeterminate) {
    throw new Error('Specify either a model or set as indeterminate.');
  }

  return progress;
}

function create$1(options) {
  var data = Utils.extend({}, options);

  if (typeof data.buttons === 'undefined') {
    data.buttons = [{ label: 'Ok', handler: function handler() {}
    }];
  } else {
    data.buttons = parseButtons(data.buttons);
  }

  if (data.inputs) {
    data.inputs = parseInputs(data.inputs);
  } else if (data.radios) {
    data.radioModel = parseRadios(data.radios);
  } else if (data.checkboxes) {
    data.checkboxes = parseCheckboxes(data.checkboxes);
  } else if (data.toggles) {
    data.toggles = parseCheckboxes(data.toggles);
  } else if (data.progress) {
    data.progress = parseProgress(data.progress);
  }

  return Modal$1.create({
    template: template,
    data: data,
    methods: {
      trigger: function trigger(handler) {
        var data = this.getData();
        function fn() {
          handler(data);
        }
        this.close(fn);
      },
      getData: function getData() {
        if (this.inputs) {
          return this.inputs.map(function (input) {
            return {
              name: input.name,
              value: input.model
            };
          });
        }
        if (this.radios) {
          return this.radioModel;
        }
        if (this.checkboxes || this.toggles) {
          return (this.checkboxes || this.toggles).filter(function (checkbox) {
            return checkbox.checked;
          }).map(function (checkbox) {
            return checkbox.value;
          });
        }
        if (this.progress && !this.progress.indeterminate) {
          return this.progress.model;
        }
      }
    }
  }).set({
    minimized: true
  });
}

var Dialog = {
  create: create$1
};

var openURL = (function (url) {
  if (Platform.is.cordova) {
    navigator.app.loadUrl(url, {
      openExternal: true
    });

    return;
  }

  var win = window.open(url, '_blank');

  if (win) {
    win.focus();
  } else {
    Dialog.create({
      title: 'Cannot Open Window',
      message: 'Please allow popups first, then please try again.'
    }).show();
  }
});

var now = Date.now;

var debounce = function (fn) {
  var wait = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 250;
  var immediate = arguments[2];

  var timeout = void 0,
      args = void 0,
      context = void 0,
      timestamp = void 0,
      result = void 0,
      later = function later() {
    var last = now() - timestamp;

    if (last < wait && last >= 0) {
      timeout = setTimeout(later, wait - last);
    } else {
      timeout = null;
      if (!immediate) {
        result = fn.apply(context, args);
        if (!timeout) {
          context = args = null;
        }
      }
    }
  };

  return function () {
    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var callNow = immediate && !timeout;

    context = this;
    timestamp = now();

    if (!timeout) {
      timeout = setTimeout(later, wait);
    }
    if (callNow) {
      result = fn.apply(context, args);
      context = args = null;
    }

    return result;
  };
}

var throttle = function (fn) {
  var limit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 250;

  var wait = false;

  return function () {
    if (wait) {
      return;
    }

    wait = true;

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    fn.apply(this, args);
    setTimeout(function () {
      wait = false;
    }, limit);
  };
}

function offset(el) {
  var rect = el.getBoundingClientRect();

  return {
    top: rect.top,
    left: rect.left
  };
}

function style(el, property) {
  return window.getComputedStyle(el).getPropertyValue(property);
}

function height$1(el) {
  return parseFloat(window.getComputedStyle(el).getPropertyValue('height'), 10);
}

function width(el) {
  return parseFloat(window.getComputedStyle(el).getPropertyValue('width'), 10);
}

function css$1(element, css) {
  var style = element.style;

  Object.keys(css).forEach(function (prop) {
    style[prop] = css[prop];
  });
}

function viewport() {
  var e = window,
      a = 'inner';

  if (!('innerWidth' in window)) {
    a = 'client';
    e = document.documentElement || document.body;
  }

  return {
    width: e[a + 'Width'],
    height: e[a + 'Height']
  };
}

function ready$1(fn) {
  if (typeof fn !== 'function') {
    return;
  }

  if (document.readyState === 'complete') {
    return fn();
  }

  document.addEventListener('DOMContentLoaded', fn, false);
}

function childOf(target, parent) {
  var element = target;

  while (element && element.nodeType) {
    if (element === parent) {
      return true;
    }

    element = element.parentNode;
  }

  return false;
}

function getScrollTarget(el) {
  return el.closest('.layout-view') || window;
}

function getScrollPosition(scrollTarget) {
  if (scrollTarget === window) {
    return window.pageYOffset || window.scrollY || document.body.scrollTop || 0;
  }
  return scrollTarget.scrollTop;
}

var dom = Object.freeze({
	offset: offset,
	style: style,
	height: height$1,
	width: width,
	css: css$1,
	viewport: viewport,
	ready: ready$1,
	childOf: childOf,
	getScrollTarget: getScrollTarget,
	getScrollPosition: getScrollPosition
});

function rightClick(e) {
  if (!e) {
    e = window.event;
  }

  if (e.which) {
    return e.which == 3;
  }
  if (e.button) {
    return e.button == 2;
  }

  return false;
}

function position(e) {
  var posx = void 0,
      posy = void 0;

  if (!e) {
    e = window.event;
  }
  if (e.touches && e.touches[0]) {
    e = e.touches[0];
  }

  if (e.clientX || e.clientY) {
    posx = e.clientX;
    posy = e.clientY;
  } else if (e.pageX || e.pageY) {
    posx = e.pageX - document.body.scrollLeft - document.documentElement.scrollLeft;
    posy = e.pageY - document.body.scrollTop - document.documentElement.scrollTop;
  }

  return {
    top: posy,
    left: posx
  };
}

function targetElement$1(e) {
  var target = void 0;

  if (!e) {
    e = window.event;
  }

  if (e.target) {
    target = e.target;
  } else if (e.srcElement) {
    target = e.srcElement;
  }

  if (target.nodeType === 3) {
    target = target.parentNode;
  }

  return target;
}

var event = Object.freeze({
	rightClick: rightClick,
	position: position,
	targetElement: targetElement$1
});

var toString = Object.prototype.toString;
var hasOwn = Object.prototype.hasOwnProperty;
var class2type = {};

'Boolean Number String Function Array Date RegExp Object'.split(' ').forEach(function (name) {
  class2type['[object ' + name + ']'] = name.toLowerCase();
});

function type(obj) {
  return obj == null ? String(obj) : class2type[toString.call(obj)] || 'object';
}

function isPlainObject(obj) {
  if (!obj || type(obj) !== 'object') {
    return false;
  }

  if (obj.constructor && !hasOwn.call(obj, 'constructor') && !hasOwn.call(obj.constructor.prototype, 'isPrototypeOf')) {
    return false;
  }

  var key = void 0;
  for (key in obj) {}

  return key === undefined || hasOwn.call(obj, key);
}

function extend() {
  var options = void 0,
      name = void 0,
      src = void 0,
      copy = void 0,
      copyIsArray = void 0,
      clone = void 0,
      target = arguments[0] || {},
      i = 1,
      length = arguments.length,
      deep = false;

  if (typeof target === 'boolean') {
    deep = target;
    target = arguments[1] || {};
    i = 2;
  }

  if ((typeof target === 'undefined' ? 'undefined' : _typeof(target)) !== 'object' && type(target) !== 'function') {
    target = {};
  }

  if (length === i) {
    target = this;
    i--;
  }

  for (; i < length; i++) {
    if ((options = arguments[i]) != null) {
      for (name in options) {
        src = target[name];
        copy = options[name];

        if (target === copy) {
          continue;
        }

        if (deep && copy && (isPlainObject(copy) || (copyIsArray = type(copy) === 'array'))) {
          if (copyIsArray) {
            copyIsArray = false;
            clone = src && type(src) === 'array' ? src : [];
          } else {
            clone = src && isPlainObject(src) ? src : {};
          }

          target[name] = extend(deep, clone, copy);
        } else if (copy !== undefined) {
          target[name] = copy;
        }
      }
    }
  }

  return target;
}

function s4() {
  return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
}

var uid = function () {
  return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
}

var Utils = {
  openURL: openURL,
  debounce: debounce,
  throttle: throttle,
  extend: extend,
  dom: dom,
  uid: uid,
  event: event
};

var directiveScrollFire = {
  bind: function bind() {
    this.scrollTarget = Utils.dom.getScrollTarget(this.el);
  },
  update: function update(handler) {
    var _this = this;

    this.scrollTarget.removeEventListener('scroll', this.scroll);

    if (typeof handler !== 'function') {
      this.scroll = function () {};
      console.error('v-scroll-fire requires a function as parameter', this.el);
      return;
    }

    this.scroll = Utils.debounce(function () {
      var containerBottom = void 0,
          elementBottom = void 0,
          fire = void 0;

      if (_this.scrollTarget === window) {
        elementBottom = _this.el.getBoundingClientRect().bottom;
        fire = elementBottom < Utils.dom.viewport().height;
      } else {
        containerBottom = Utils.dom.offset(_this.scrollTarget).top + Utils.dom.height(_this.scrollTarget);
        elementBottom = Utils.dom.offset(_this.el).top + Utils.dom.height(_this.el);
        fire = elementBottom < containerBottom;
      }

      if (fire) {
        _this.scrollTarget.removeEventListener('scroll', _this.scroll);
        handler(_this.el);
      }
    }, 25);

    this.scrollTarget.addEventListener('scroll', this.scroll);
    this.scroll();
  },
  unbind: function unbind() {
    this.scrollTarget.removeEventListener('scroll', this.scroll);
  }
};

var directiveScroll = {
  bind: function bind() {
    var _this = this;

    this.scrollTarget = Utils.dom.getScrollTarget(this.el);
    this.scroll = function () {
      _this.handler(Utils.dom.getScrollPosition(_this.scrollTarget));
    };
  },
  update: function update(handler) {
    this.scrollTarget.removeEventListener('scroll', this.scroll);

    if (typeof handler !== 'function') {
      console.error('v-scroll requires a function as parameter', this.el);
      return;
    }

    this.handler = handler;
    this.scrollTarget.addEventListener('scroll', this.scroll);
  },
  unbind: function unbind() {
    this.scrollTarget.removeEventListener('scroll', this.scroll);
  }
};

var directiveTooltip = {
  bind: function bind() {
    if (this.modifiers.wrap) {
      this.target = document.createElement('div');

      this.el.parentNode.insertBefore(this.target, this.el);
      this.target.appendChild(this.el);
    } else {
      this.target = this.el;
    }

    this.target.classList.add('quasar-tooltip');

    if (this.modifiers.inline) {
      this.target.classList.add('flex', 'inline');
    }
  },
  update: function update(value) {
    this.target.setAttribute('quasar-tooltip', value);
  }
};

var Checkbox = { template: "<label class=\"quasar-checkbox\" :class=\"{disabled: disable}\"><input type=\"checkbox\" v-model=\"model\" v-attr=\"attrib\"><div></div></label>",
  props: {
    model: {
      type: Boolean,
      twoWay: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  }
};

var Chips = { template: "<div class=\"quasar-chips group\" @click=\"focus\" :class=\"{active: active, disabled: disable}\"><span class=\"chip label bg-light text-grey-9\" v-for=\"label in model\" track-by=\"$index\">{{ label }} <i class=\"on-right\" @click=\"remove($index)\">close</i></span><div class=\"quasar-chips-input chip label text-grey-9\"><input type=\"text\" class=\"no-style\" v-el:input v-model=\"input\" @keyup.enter=\"add()\" @focus=\"active = true\" @blur=\"active = false\" v-attr=\"attrib\" :placeholder=\"placeholder\"> <button class=\"small\" @click=\"add()\" :class=\"{invisible: !input.length}\"><i>send</i></button></div></div>",
  props: {
    model: {
      type: Array,
      twoWay: true,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    placeholder: String
  },
  data: function data() {
    return {
      active: false,
      input: ''
    };
  },

  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  },
  methods: {
    add: function add() {
      if (!this.disable && this.input) {
        this.model.push(this.input);
        this.input = '';
      }
    },
    remove: function remove(index) {
      if (!this.disable && index >= 0 && index < this.model.length) {
        this.model.splice(index, 1);
      }
    },
    focus: function focus() {
      this.$els.input.focus();
    }
  }
};

var Collapsible = { template: "<div class=\"quasar-collapsible\"><div class=\"item item-link non-selectable item-collapsible\" @click=\"toggle()\"><i class=\"item-primary\" v-if=\"icon\" v-text=\"icon\"></i> <img class=\"item-primary thumbnail\" v-if=\"img\" :src=\"img\"><img class=\"item-primary\" v-if=\"avatar\" :src=\"avatar\"><div class=\"item-content has-secondary\">{{ label }}</div><i class=\"item-secondary\" :class=\"{'rotate-180': active}\">keyboard_arrow_down</i></div><div class=\"quasar-collapsible-sub-item\" v-show=\"active\" transition=\"slide\"><slot></slot></div></div>",
  props: {
    active: {
      type: Boolean,
      default: false,
      twoWay: true,
      coerce: Boolean
    },
    icon: String,
    img: String,
    avatar: String,
    label: String
  },
  methods: {
    toggle: function toggle() {
      this.active = !this.active;
    }
  }
};

var ContextMenuDesktop = { template: "<div><quasar-popover v-ref:popover touch-position><slot></slot></quasar-popover></div>",
  props: {
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    open: function open() {
      this.$refs.popover.open();
    },
    close: function close() {
      this.$refs.popover.close();
    },
    toggle: function toggle() {
      this.$refs.popover.toggle();
    }
  },
  ready: function ready() {
    var _this = this;

    this.target = this.$el.parentNode;

    this.handler = function (event) {
      if (_this.disable) {
        return;
      }
      event.preventDefault();
      event.stopPropagation();
      if (Utils.dom.childOf(Utils.event.targetElement(event), _this.target)) {
        _this.$refs.popover.toggle(event);
      }
    };

    this.target.addEventListener('contextmenu', this.handler);
  },
  beforeDestroy: function beforeDestroy() {
    this.target.removeEventListener('contexmenu', this.handler);
  }
};

var ContextMenuMobile = { template: "<div class=\"modal hidden fullscreen flex items-center justify-center\"><div class=\"modal-backdrop backdrop\"></div><div class=\"modal-content\"><div class=\"modal-scroll\"><slot></slot></div></div></div>",
  props: {
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    open: function open() {
      this.handler();
    },
    close: function close() {
      this.target.classList.remove('non-selectable');
      this.modal.close();
    },
    toggle: function toggle() {
      if (this.modal.active) {
        this.close();
      } else {
        this.open();
      }
    }
  },
  ready: function ready() {
    var _this = this;

    this.target = this.$el.parentNode;

    this.handler = function () {
      if (_this.disable) {
        return;
      }
      _this.modal = Modal$1.create(_this.$el).set({
        minimized: true,
        closeWithBackdrop: true
      }).show();
    };

    this.touchStartHandler = function (event) {
      _this.target.classList.add('non-selectable');
      _this.touchTimer = setTimeout(function () {
        event.preventDefault();
        event.stopPropagation();
        _this.cleanup();
        setTimeout(function () {
          _this.handler();
        }, 10);
      }, 600);
    };
    this.cleanup = function () {
      _this.target.classList.remove('non-selectable');
      if (_this.touchTimer) {
        clearTimeout(_this.touchTimer);
        _this.touchTimer = null;
      }
    };
    this.target.addEventListener('touchstart', this.touchStartHandler);
    this.target.addEventListener('touchcancel', this.cleanup);
    this.target.addEventListener('touchmove', this.cleanup);
    this.target.addEventListener('touchend', this.cleanup);
  },
  beforeDestroy: function beforeDestroy() {
    this.target.removeEventListener('touchstart', this.touchStartHandler);
    this.target.removeEventListener('touchcancel', this.cleanup);
    this.target.removeEventListener('touchmove', this.cleanup);
    this.target.removeEventListener('touchend', this.cleanup);
  }
};

var PickerModal = { template: "<div><quasar-inline-datetime :model.sync=\"model\" :type=\"type\" class=\"no-border\" style=\"width: 100%\"><div class=\"modal-buttons row full-width\"><button @click=\"close()\" class=\"primary clear\">{{ cancelLabel }}</button> <button @click=\"set(model)\" class=\"primary clear\">{{ okLabel }}</button></div></quasar-inline-datetime></div>",
  methods: {}
};

var InputDatetimeMobile = { template: "<div class=\"cursor-pointer textfield\" @click=\"pick\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div>",
  props: {
    type: {
      type: String,
      default: 'date',
      twoWay: true
    },
    model: {
      type: String,
      required: true
    },
    format: {
      type: String
    },
    okLabel: {
      type: String,
      default: 'Set'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label: function label() {
      var format = void 0;

      if (this.format) {
        format = this.format;
      } else if (this.type === 'date') {
        format = 'YYYY/MM/DD';
      } else if (this.type === 'time') {
        format = 'HH:mm';
      } else {
        format = 'YYYY/MM/DD HH:mm:ss';
      }

      return moment(this.model).format(format);
    }
  },
  methods: {
    pick: function pick() {
      var _this = this;

      if (this.disable) {
        return;
      }

      var modal = void 0;

      PickerModal.data = {
        model: this.model,
        type: this.type,
        okLabel: this.okLabel,
        cancelLabel: this.cancelLabel
      };
      PickerModal.methods.set = function (model) {
        _this.model = model;
        modal.close();
      };

      modal = Modal$1.create(PickerModal);

      if (current === 'ios') {
        modal.$el.classList.remove('items-center');
        modal.$el.classList.add('items-end');
        modal.css({
          maxHeight: '80vh',
          height: 'auto',
          boxShadow: 'none',
          backgroundColor: '#e4e4e4'
        }).set({
          transitionIn: { translateY: [0, '101%'] },
          transitionOut: { translateY: ['101%', 0] },
          closeWithBackdrop: true
        }).show();
      } else {
        modal.set({
          minimized: true,
          closeWithBackdrop: true
        }).css({
          maxWidth: '95vw',
          maxHeight: '98vh'
        }).show();
      }
    }
  }
};

var InputDatetimeDesktop = { template: "<div class=\"quasar-datetime-desktop\"><quasar-popover :disable=\"disable\"><div slot=\"target\" class=\"cursor-pointer textfield\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div><quasar-inline-datetime :model.sync=\"model\" :type=\"type\"></quasar-inline-datetime></quasar-popover></div>",
  props: {
    type: {
      type: String,
      default: 'date',
      twoWay: true
    },
    model: {
      type: String,
      required: true
    },
    format: {
      type: String
    },
    okLabel: {
      type: String,
      default: 'Set'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label: function label() {
      var format = void 0;

      if (this.format) {
        format = this.format;
      } else if (this.type === 'date') {
        format = 'YYYY-MM-DD';
      } else if (this.type === 'time') {
        format = 'HH:mm';
      } else {
        format = 'YYYY-MM-DD HH:mm:ss';
      }

      return moment(this.model).format(format);
    }
  }
};

var MaterialInlineDatetime = { template: "<div class=\"quasar-datetime inline column gt-md-row\" :class=\"{disabled: disable}\"><div class=\"quasar-datetime-header column justify-center\"><div v-if=\"type === 'date' || type === 'datetime'\"><div class=\"quasar-datetime-weekdaystring\">{{ weekDayString }}</div><div class=\"quasar-datetime-datestring row gt-md-column items-center justify-center\"><span :class=\"{active: view === 'month'}\" class=\"quasar-datetime-link small\" @click=\"view = 'month'\">{{ monthString }} </span><span :class=\"{active: view === 'day'}\" class=\"quasar-datetime-link\" @click=\"view = 'day'\">{{ dayString }} </span><span :class=\"{active: view === 'year'}\" class=\"quasar-datetime-link small\" @click=\"view = 'year'\">{{ year }}</span></div></div><div v-if=\"type === 'time' || type === 'datetime'\" class=\"quasar-datetime-time row gt-md-column items-center justify-center\"><div class=\"quasar-datetime-clockstring\"><span :class=\"{active: view === 'hour'}\" class=\"quasar-datetime-link\" @click=\"view = 'hour'\">{{ __pad(hour, '&nbsp;&nbsp;') }} </span><span style=\"opacity: 0.6\">:</span> <span :class=\"{active: view === 'minute'}\" class=\"quasar-datetime-link\" @click=\"view = 'minute'\">{{ __pad(minute) }}</span></div><div class=\"quasar-datetime-ampm column justify-around\"><div :class=\"{active: am}\" class=\"quasar-datetime-link\" @click=\"toggleAmPm()\">AM</div><div :class=\"{active: !am}\" class=\"quasar-datetime-link\" @click=\"toggleAmPm()\">PM</div></div></div></div><div class=\"quasar-datetime-content auto column\"><div v-el:selector class=\"quasar-datetime-selector auto row items-center justify-center\"><div v-if=\"view === 'year'\" class=\"quasar-datetime-view-year full-width full-height\"><button v-for=\"n in 101\" class=\"primary clear full-width\" :class=\"{active: n + 1950 === year}\" @click=\"setYear(n + 1950)\">{{ n + 1950 }}</button></div><div v-if=\"view === 'month'\" class=\"quasar-datetime-view-month full-width full-height\"><button v-for=\"monthName in monthsList\" class=\"primary clear full-width\" :class=\"{active: month === $index + 1}\" @click=\"setMonth($index + 1, true)\">{{ monthName }}</button></div><div v-if=\"view === 'day'\" class=\"quasar-datetime-view-day quasar-datetime-animate\"><div class=\"row items-center content-center\"><button class=\"primary clear\" @click=\"setMonth(month - 1, true)\"><i>keyboard_arrow_left</i></button><div class=\"auto\">{{ monthStamp }}</div><button class=\"primary clear\" @click=\"setMonth(month + 1, true)\"><i>keyboard_arrow_right</i></button></div><div class=\"quasar-datetime-weekdays row items-center justify-start\"><div>Mo</div><div>Tu</div><div>We</div><div>Th</div><div>Fr</div><div>Sa</div><div>Su</div></div><div class=\"quasar-datetime-days row wrap items-center justify-start content-center\"><div v-for=\"fillerDay in fillerDays\" class=\"quasar-datetime-fillerday\"></div><div v-for=\"monthDay in daysInMonth\" class=\"flex items-center content-center justify-center cursor-pointer\" :class=\"{active: monthDay + 1 === day}\" @click=\"setDay(monthDay + 1)\">{{ monthDay + 1 }}</div></div></div><div v-if=\"view === 'hour' || view === 'minute'\" v-el:clock class=\"column items-center content-center justify-center\"><div v-if=\"view === 'hour'\" class=\"quasar-datetime-clock cursor-pointer\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><div class=\"quasar-datetime-clock-circle full-width full-height\"><div class=\"quasar-datetime-clock-center\"></div><div class=\"quasar-datetime-clock-pointer\" :style=\"clockPointerStyle\"><span></span></div><div v-for=\"n in 12\" class=\"quasar-datetime-clock-position\" :class=\"['quasar-datetime-clock-pos-' + (n + 1), n + 1 === hour ? 'active' : '']\">{{ n + 1 }}</div></div></div><div v-if=\"view === 'minute'\" class=\"quasar-datetime-clock cursor-pointer\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><div class=\"quasar-datetime-clock-circle full-width full-height\"><div class=\"quasar-datetime-clock-center\"></div><div class=\"quasar-datetime-clock-pointer\" :style=\"clockPointerStyle\"><span></span></div><div v-for=\"n in 12\" class=\"quasar-datetime-clock-position\" :class=\"['quasar-datetime-clock-pos-' + n, n * 5 === minute ? 'active' : '']\">{{ n * 5 }}</div></div></div></div></div><slot></slot></div></div>",
  props: {
    model: {
      type: String,
      twoWay: true,
      required: true
    },
    type: {
      type: String,
      default: 'date',
      validator: function validator(value) {
        return ['date', 'time', 'datetime'].includes(value);
      }
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    var view = void 0;

    switch (this.type) {
      case 'time':
        view = 'hour';
        break;
      case 'date':
      default:
        view = 'day';
        break;
    }

    return {
      view: view,
      date: moment(this.model),
      dragging: false,
      centerClockPosition: 0,
      monthsList: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    };
  },

  watch: {
    model: function model(value) {
      this.date = moment(value);
    },
    view: function view(value) {
      if (value !== 'year' && value !== 'month') {
        return;
      }

      var view = this.$els.selector,
          rows = value === 'year' ? this.year - 1950 : this.month;

      this.$nextTick(function () {
        view.scrollTop = rows * Utils.dom.height(view.children[0].children[0]) - Utils.dom.height(view) / 2.5;
      });
    }
  },
  computed: {
    year: function year() {
      return this.date.year();
    },
    month: function month() {
      return this.date.month() + 1;
    },
    day: function day() {
      return this.date.date();
    },
    dayString: function dayString() {
      return this.date.format('Do');
    },
    monthString: function monthString() {
      return this.date.format('MMM');
    },
    monthStamp: function monthStamp() {
      return this.date.format('MMMM YYYY');
    },
    weekDayString: function weekDayString() {
      return this.date.format('dddd');
    },
    fillerDays: function fillerDays() {
      return Math.max(0, this.date.clone().date(1).day() - 1);
    },
    daysInMonth: function daysInMonth() {
      return this.date.daysInMonth();
    },
    hour: function hour() {
      var hour = this.date.hour();
      return hour === 0 ? 12 : hour >= 13 ? hour - 12 : hour;
    },
    minute: function minute() {
      return this.date.minute();
    },
    am: function am() {
      return this.date.hour() <= 11;
    },
    clockPointerStyle: function clockPointerStyle() {
      var divider = this.view === 'minute' ? 60 : 12,
          degrees = Math.round((this.view === 'minute' ? this.minute : this.hour) * (360 / divider)) - 180;

      return {
        '-webkit-transform': 'rotate(' + degrees + 'deg)',
        '-ms-transform': 'rotate(' + degrees + 'deg)',
        'transform': 'rotate(' + degrees + 'deg)'
      };
    }
  },
  methods: {
    setYear: function setYear(value) {
      if (this.disable) {
        return;
      }
      this.date.year(this.__parseTypeValue('year', value));
      this.__updateModel();
    },
    setMonth: function setMonth(value, force) {
      if (this.disable) {
        return;
      }
      this.date.month((force ? value : this.__parseTypeValue('month', value)) - 1);
      this.__updateModel();
    },
    setDay: function setDay(value) {
      if (this.disable) {
        return;
      }
      this.date.date(this.__parseTypeValue('date', value));
      this.__updateModel();
    },
    toggleAmPm: function toggleAmPm() {
      if (this.disable) {
        return;
      }
      var hour = this.date.hour(),
          offset = this.am ? 12 : -12;

      this.date.hour(hour + offset);
      this.__updateModel();
    },
    setHour: function setHour(value) {
      if (this.disable) {
        return;
      }
      value = this.__parseTypeValue('hour', value) % 12;

      if (!this.am) {
        value += 12;
      }

      this.date.hour(value);
      this.__updateModel();
    },
    setMinute: function setMinute(value) {
      if (this.disable) {
        return;
      }
      this.date.minute(this.__parseTypeValue('minute', value));
      this.__updateModel();
    },
    __pad: function __pad(unit, filler) {
      return (unit < 10 ? filler || '0' : '') + unit;
    },
    __dragStart: function __dragStart(ev) {
      ev.stopPropagation();
      ev.preventDefault();

      var clock = this.$els.clock,
          clockOffset = Utils.dom.offset(clock);

      this.centerClockPosition = {
        top: clockOffset.top + Utils.dom.height(clock) / 2,
        left: clockOffset.left + Utils.dom.width(clock) / 2
      };

      this.dragging = true;
      this.__updateClock(ev);
    },
    __dragMove: function __dragMove(ev) {
      if (!this.dragging) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();
      this.__updateClock(ev);
    },
    __dragStop: function __dragStop(ev) {
      ev.stopPropagation();
      ev.preventDefault();
      this.dragging = false;
    },
    __updateClock: function __updateClock(ev) {
      var position = Utils.event.position(ev),
          height = Math.abs(position.top - this.centerClockPosition.top),
          distance = Math.sqrt(Math.pow(Math.abs(position.top - this.centerClockPosition.top), 2) + Math.pow(Math.abs(position.left - this.centerClockPosition.left), 2)),
          angle = Math.asin(height / distance) * (180 / Math.PI);

      if (position.top < this.centerClockPosition.top) {
        angle = this.centerClockPosition.left < position.left ? 90 - angle : 270 + angle;
      } else {
        angle = this.centerClockPosition.left < position.left ? angle + 90 : 270 - angle;
      }

      if (this.view === 'hour') {
        this.setHour(Math.round(angle / 30));
      } else {
        this.setMinute(Math.round(angle / 6));
      }
    },
    __parseTypeValue: function __parseTypeValue(type, value) {
      if (type === 'month') {
        return Math.max(1, Math.min(12, value));
      }
      if (type === 'date') {
        return Math.max(1, Math.min(this.daysInMonth, value));
      }
      if (type === 'year') {
        return Math.max(1950, Math.min(2050, value));
      }
      if (type === 'hour') {
        return Math.max(0, Math.min(23, value));
      }
      if (type === 'minute') {
        return Math.max(0, Math.min(59, value));
      }
    },
    __updateModel: function __updateModel() {
      this.model = this.date.toISOString();
    }
  }
};

var iOSInlineDatetime = { template: "<div class=\"quasar-datetime\" :class=\"['type-' + type, disabled ? 'disable' : '']\"><slot></slot><div class=\"quasar-datetime-content non-selectable\"><div class=\"quasar-datetime-inner full-height flex justify-center\"><div class=\"quasar-datetime-col quasar-datetime-col-month\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'month')\" @touchmove=\"__dragMove($event, 'month')\" @touchend=\"__dragStop($event, 'month')\"><div v-el:month class=\"quasar-datetime-col-wrapper\" :style=\"__monthStyle\"><div v-for=\"monthName in monthsList\" class=\"quasar-datetime-item\" @click=\"setMonth($index + 1)\">{{ monthName }}</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-day\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'date')\" @touchmove=\"__dragMove($event, 'date')\" @touchend=\"__dragStop($event, 'date')\"><div v-el:date class=\"quasar-datetime-col-wrapper\" :style=\"__dayStyle\"><div v-for=\"monthDay in daysInMonth\" class=\"quasar-datetime-item\" @click=\"setDay(monthDay + 1)\">{{ monthDay + 1 }}</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-year\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'year')\" @touchmove=\"__dragMove($event, 'year')\" @touchend=\"__dragStop($event, 'year')\"><div v-el:year class=\"quasar-datetime-col-wrapper\" :style=\"__yearStyle\"><div v-for=\"n in 101\" class=\"quasar-datetime-item\" @click=\"setYear(n + 1950)\">{{ n + 1950 }}</div></div></div><div v-el class=\"quasar-datetime-col quasar-datetime-col-hour\" v-if=\"type === 'time' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'hour')\" @touchmove=\"__dragMove($event, 'hour')\" @touchend=\"__dragStop($event, 'hour')\"><div v-el:hour class=\"quasar-datetime-col-wrapper\" :style=\"__hourStyle\"><div v-for=\"n in 24\" class=\"quasar-datetime-item\" @click=\"setHour(n)\">{{ n }}</div></div></div><div class=\"quasar-datetime-col-divider\" v-if=\"type === 'time' || type === 'datetime'\"><div class=\"quasar-datetime-col-wrapper full-height row items-center justify-center\"><div>:</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-minute\" v-if=\"type === 'time' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'minute')\" @touchmove=\"__dragMove($event, 'minute')\" @touchend=\"__dragStop($event, 'minute')\"><div v-el:minute class=\"quasar-datetime-col-wrapper\" :style=\"__minuteStyle\"><div v-for=\"n in 60\" class=\"quasar-datetime-item\" @click=\"setMinute(n)\">{{ __pad(n) }}</div></div></div><div class=\"quasar-datetime-highlight\"></div></div><div class=\"quasar-datetime-mask\"></div></div></div>",
  props: {
    model: {
      type: String,
      twoWay: true,
      required: true
    },
    type: {
      type: String,
      default: 'date',
      validator: function validator(value) {
        return ['date', 'time', 'datetime'].includes(value);
      }
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      date: moment(this.model),
      monthDragOffset: 0,
      dateDragOffset: 0,
      yearDragOffset: 0,
      hourDragOffset: 0,
      minuteDragOffset: 0,
      monthsList: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    };
  },

  watch: {
    model: function model(value) {
      this.date = moment(value);
    }
  },
  computed: {
    year: function year() {
      var value = this.date.year();
      this.__updatePositions('year', value);
      this.__updatePositions('date', this.date.date());
      return value;
    },
    month: function month() {
      var value = this.date.month();
      this.__updatePositions('month', value);
      this.__updatePositions('date', this.date.date());
      return value + 1;
    },
    day: function day() {
      var value = this.date.date();
      this.__updatePositions('date', value);
      return value;
    },
    daysInMonth: function daysInMonth() {
      return this.date.daysInMonth();
    },
    hour: function hour() {
      var value = this.date.hour();
      this.__updatePositions('hour', value);
      return value;
    },
    minute: function minute() {
      var value = this.date.minute();
      this.__updatePositions('minute', value);
      return value;
    },
    __monthStyle: function __monthStyle() {
      return this.__colStyle(82 - (this.month - 1 + this.monthDragOffset) * 36);
    },
    __dayStyle: function __dayStyle() {
      return this.__colStyle(82 - (this.day + this.dateDragOffset) * 36);
    },
    __yearStyle: function __yearStyle() {
      return this.__colStyle(82 - (this.year + this.yearDragOffset) * 36);
    },
    __hourStyle: function __hourStyle() {
      return this.__colStyle(82 - (this.hour + this.hourDragOffset) * 36);
    },
    __minuteStyle: function __minuteStyle() {
      return this.__colStyle(82 - (this.minute + this.minuteDragOffset) * 36);
    }
  },
  methods: {
    setYear: function setYear(value) {
      if (this.disable) {
        return;
      }
      this.date.year(this.__parseTypeValue('year', value));
      this.__updateModel();
    },
    setMonth: function setMonth(value) {
      if (this.disable) {
        return;
      }
      this.date.month(this.__parseTypeValue('month', value) - 1);
      this.__updateModel();
    },
    setDay: function setDay(value) {
      if (this.disable) {
        return;
      }
      this.date.date(this.__parseTypeValue('date', value));
      this.__updateModel();
    },
    setHour: function setHour(value) {
      if (this.disable) {
        return;
      }
      this.date.hour(this.__parseTypeValue('hour', value));
      this.__updateModel();
    },
    setMinute: function setMinute(value) {
      if (this.disable) {
        return;
      }
      this.date.minute(this.__parseTypeValue('minute', value));
      this.__updateModel();
    },
    __pad: function __pad(unit, filler) {
      return (unit < 10 ? filler || '0' : '') + unit;
    },
    __parseTypeValue: function __parseTypeValue(type, value) {
      if (type === 'month') {
        return Math.max(1, Math.min(12, value));
      }
      if (type === 'date') {
        return Math.max(1, Math.min(this.daysInMonth, value));
      }
      if (type === 'year') {
        return Math.max(1950, Math.min(2050, value));
      }
      if (type === 'hour') {
        return Math.max(0, Math.min(23, value));
      }
      if (type === 'minute') {
        return Math.max(0, Math.min(59, value));
      }
    },
    __updatePositions: function __updatePositions(type, value) {
      var _this = this;

      var root = this.$els[type];

      if (!root) {
        return;
      }

      var delta = -value + (type === 'year' ? 1950 : type === 'date' ? 1 : 0);[].slice.call(root.children).forEach(function (item) {
        Utils.dom.css(item, _this.__itemStyle(value * 36, Math.max(-180, Math.min(180, delta * -18))));
        delta++;
      });
    },
    __colStyle: function __colStyle(value) {
      return {
        '-webkit-transform': 'translate3d(0,' + value + 'px,0)',
        '-ms-transform': 'translate3d(0,' + value + 'px,0)',
        'transform': 'translate3d(0,' + value + 'px,0)'
      };
    },
    __itemStyle: function __itemStyle(translation, rotation) {
      return {
        '-webkit-transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)',
        '-ms-transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)',
        'transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)'
      };
    },
    __updateModel: function __updateModel() {
      this.model = this.date.toISOString();
    },
    __dragStart: function __dragStart(ev, type) {
      var _this2 = this;

      if (this.disable) {
        return;
      }

      this.__dragCleanup();['month', 'date', 'year', 'hour', 'minute'].forEach(function (type) {
        _this2[type + 'DragOffset'] = 0;
      });
      ev.stopPropagation();
      ev.preventDefault();

      this.dragging = type;
      this.__dragPosition = Utils.event.position(ev).top;
    },
    __dragMove: function __dragMove(ev, type) {
      if (this.dragging !== type || this.disable) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();
      this[type + 'DragOffset'] = (this.__dragPosition - Utils.event.position(ev).top) / 36;
      this.__updatePositions(type, this.date[type]() + this[type + 'DragOffset']);
    },
    __dragStop: function __dragStop(ev, type) {
      var _this3 = this;

      if (this.dragging !== type || this.disable) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();
      this.dragging = false;

      var offset = Math.round(this[type + 'DragOffset']),
          newValue = this.__parseTypeValue(type, this[type === 'date' ? 'day' : type] + offset),
          actualType = type === 'date' ? 'day' : type;

      if (newValue !== this[actualType]) {
        this['set' + actualType.charAt(0).toUpperCase() + actualType.slice(1)](newValue);
        this[type + 'DragOffset'] = 0;
      } else {
        this.__updatePositions(type, this.date[type]());
        this.timeout = setTimeout(function () {
          _this3[type + 'DragOffset'] = 0;
        }, 150);
      }
    },
    __dragCleanup: function __dragCleanup() {
      if (this.timeout) {
        clearTimeout(this.timeout);
        this.timeout = null;
      }
    }
  },
  compiled: function compiled() {
    if (this.type === 'date' || this.type === 'datetime') {
      this.__updatePositions('month', this.date.month());
      this.__updatePositions('date', this.date.date());
      this.__updatePositions('year', this.date.year());
    }
    if (this.type === 'time' || this.type === 'datetime') {
      this.__updatePositions('hour', this.date.hour());
      this.__updatePositions('minute', this.date.minute());
    }
  },
  beforeDestroy: function beforeDestroy() {
    this.__dragCleanup();
  }
};

var drawerAnimationSpeed = 150;
var backdropOpacity = {
  mat: 0.7,
  ios: 0.2
};
var appContainer = document.getElementById('quasar-app');

var leftDrawer = void 0;
var rightDrawer = void 0;

function getCurrentPosition(node) {
  var transform = Utils.dom.style(node, 'transform');
  return transform !== 'none' ? parseInt(transform.split(/[()]/)[1].split(', ')[4], 10) : 0;
}

function getBetween(value, min, max) {
  if (value < min) {
    return min;
  }

  if (value > max) {
    return max;
  }

  return value;
}

function closeDrawers(done) {
  if (leftDrawer && leftDrawer.opened) {
    leftDrawer.setState(false, done);
    return;
  }
  if (rightDrawer && rightDrawer.opened) {
    rightDrawer.setState(false, done);
    return;
  }

  if (typeof done === 'function') {
    done();
  }
}

var Drawer = { template: "<div class=\"drawer\" :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><div class=\"drawer-opener touch-only mobile-only\" v-touch:pan=\"openByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\" :class=\"{'fixed-left': !rightSide, 'fixed-right': rightSide}\">&nbsp</div><div v-el:backdrop class=\"drawer-backdrop fullscreen\" style=\"background: rgba(0, 0, 0, 0.01)\" @click=\"setState(false)\" v-touch:pan=\"closeByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\"></div><div v-el:content v-touch:pan=\"closeByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\" class=\"drawer-content\" :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><slot></slot></div></div>",
  props: {
    'right-side': {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    'swipe-only': {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      opened: false
    };
  },

  methods: {
    __matToggleAnimate: function __matToggleAnimate(percentage, done) {
      var _this = this;

      var node = this.$els.content,
          backdrop = this.$els.backdrop,
          currentPosition = getCurrentPosition(node),
          closePosition = (this.rightSide ? 1 : -1) * this.width;

      Velocity(node, 'stop');
      Velocity(node, { translateX: this.opened ? [0, currentPosition] : [closePosition, currentPosition] }, { duration: !this.opened || currentPosition !== 0 ? drawerAnimationSpeed : 0 });

      if (this.opened) {
        backdrop.classList.add('active');
        if (!Platform.within.iframe) {
          if (!window.history.state) {
            window.history.replaceState({ __quasar_drawer: true }, '');
          } else {
            window.history.state.__quasar_drawer = true;
          }
          window.history.pushState({}, '');
          window.addEventListener('popstate', this.__popState);
        }
      } else {
        window.removeEventListener('resize', closeDrawers);
        if (!Platform.within.iframe) {
          window.removeEventListener('popstate', this.__popState);
          if (window.history.state && !window.history.state.__quasar_drawer) {
            window.history.go(-1);
          }
        }
      }

      Velocity(backdrop, 'stop');
      Velocity(backdrop, {
        'backgroundColor': '#000',
        'backgroundColorAlpha': this.opened ? backdropOpacity.mat : 0.01
      }, {
        duration: drawerAnimationSpeed,
        complete: function complete() {
          if (!_this.opened) {
            backdrop.classList.remove('active');
          } else {
            window.addEventListener('resize', closeDrawers);
          }
          if (typeof done === 'function') {
            done();
          }
        }
      });
    },
    __iosToggleAnimate: function __iosToggleAnimate(percentage, done) {
      var _this2 = this;

      var backdrop = this.$els.backdrop;

      if (this.opened) {
        backdrop.classList.add('active');
        document.body.classList.add('drawer-opened');
        if (!Platform.within.iframe) {
          if (!window.history.state) {
            window.history.replaceState({ __quasar_drawer: true }, '');
          } else {
            window.history.state.__quasar_drawer = true;
          }
          window.history.pushState({}, '');
          window.addEventListener('popstate', this.__popState);
        }
      } else {
        window.removeEventListener('resize', closeDrawers);
        if (!Platform.within.iframe) {
          window.removeEventListener('popstate', this.__popState);
          if (window.history.state && !window.history.state.__quasar_drawer) {
            window.history.go(-1);
          }
        }
      }

      var currentPosition = getCurrentPosition(appContainer),
          openPosition = (this.rightSide ? -1 : 1) * this.width;

      Velocity(appContainer, 'stop');
      Velocity(appContainer, { translateX: this.opened ? [openPosition, currentPosition] : [0, currentPosition] }, { duration: !this.opened || currentPosition !== openPosition ? drawerAnimationSpeed : 0 });

      Velocity(backdrop, 'stop');
      Velocity(backdrop, {
        'backgroundColor': '#000',
        'backgroundColorAlpha': this.opened ? backdropOpacity.ios : 0.01
      }, {
        duration: drawerAnimationSpeed,
        complete: function complete() {
          if (!_this2.opened) {
            backdrop.classList.remove('active');
            document.body.classList.remove('drawer-opened');
          } else {
            window.addEventListener('resize', closeDrawers);
          }
          if (typeof done === 'function') {
            done();
          }
        }
      });
    },
    openByTouch: function openByTouch(event) {
      var content = this.$els.content,
          backdrop = this.$els.backdrop;

      if (Utils.dom.style(content, 'position') !== 'fixed') {
        return;
      }

      var position = Math.abs(event.deltaX),
          target = void 0,
          fn = void 0,
          percentage = void 0;

      if (event.isFinal) {
        this.opened = position > 75;
      }

      if (current === 'ios') {
        position = Math.min(position, this.width);
        percentage = 1.0 - (this.width - Math.abs(position)) / this.width;
        fn = this.__iosToggleAnimate;
        target = appContainer;
        position = (this.rightSide ? -1 : 1) * position;
      } else {
        position = this.rightSide ? Math.max(this.width - position, 0) : Math.min(0, position - this.width);
        percentage = (this.width - Math.abs(position)) / this.width;
        fn = this.__matToggleAnimate;
        target = content;
      }

      if (event.isFinal) {
        fn(percentage, null);
        return;
      }

      target.style.transform = 'translateX(' + position + 'px)';
      backdrop.classList.add('active');
      backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[current] + ')';
    },
    closeByTouch: function closeByTouch(event) {
      var content = this.$els.content,
          backdrop = this.$els.backdrop;

      var target = void 0,
          fn = void 0,
          percentage = void 0,
          position = void 0,
          initialPosition = void 0;

      if (Utils.dom.style(content, 'position') !== 'fixed') {
        return;
      }

      position = this.rightSide ? getBetween(event.deltaX, 0, this.width) : getBetween(event.deltaX, -this.width, 0);
      initialPosition = (this.rightSide ? -1 : 1) * this.width;

      if (event.isFinal) {
        this.opened = Math.abs(position) <= 75;
      }

      if (current === 'ios') {
        position = initialPosition + position;
        percentage = (this.rightSide ? -1 : 1) * position / this.width;
        fn = this.__iosToggleAnimate;
        target = appContainer;
      } else {
        percentage = 1 + (this.rightSide ? -1 : 1) * position / this.width;
        fn = this.__matToggleAnimate;
        target = content;
      }

      if (event.isFinal) {
        fn(percentage, null);
        return;
      }

      target.style.transform = 'translateX(' + position + 'px)';
      backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[current] + ')';
    },
    setState: function setState(state, done) {
      if (!this.swipeOnly && Utils.dom.viewport().width > 600 || typeof state === 'boolean' && this.opened === state) {
        if (typeof done === 'function') {
          done();
        }
        return;
      }

      this.opened = !this.opened;
      var fn = current === 'ios' ? this.__iosToggleAnimate : this.__matToggleAnimate;

      fn(this.opened ? 0.01 : 1, done);
    },
    __popState: function __popState() {
      if (!Platform.within.iframe) {
        if (window.history.state && window.history.state.__quasar_drawer) {
          this.setState(false);
        }
      }
    },
    open: function open(done) {
      this.setState(true, done);
    },
    close: function close(done) {
      this.setState(false, done);
    }
  },
  ready: function ready() {
    var _this3 = this;

    var content = this.$els.content,
        toggles = this.$el.closest('.layout').getElementsByClassName((this.rightSide ? 'right' : 'left') + '-drawer-opener');

    this.width = Utils.dom.width(content);[].slice.call(toggles).forEach(function (el) {
      el.addEventListener('click', function () {
        _this3.setState(true);
      });
    });[].slice.call(content.getElementsByClassName('drawer-closer')).forEach(function (el) {
      el.addEventListener('click', function () {
        _this3.setState(false);
      });
    });

    if (this.swipeOnly) {
      [].slice.call(toggles).forEach(function (el) {
        el.classList.add('always-visible');
      });
      this.$el.classList.add('swipe-only');
    }

    if (this.rightSide) {
      rightDrawer = this;
    } else {
      leftDrawer = this;
    }
  },
  beforeDestroy: function beforeDestroy() {
    this.setState(false);

    if (this.rightSide) {
      rightDrawer = null;
    } else {
      leftDrawer = null;
    }
  }
};

var DrawerLink = { template: "<div class=\"item item-link drawer-closer\"><i v-if=\"icon\" class=\"item-primary\">{{icon}}</i><div class=\"item-content\"><slot></slot></div></div>",
  props: ['icon']
};

var Fab = { template: "<div class=\"quasar-fab flex inline justify-center\" :class=\"{opened: opened, 'with-backdrop': click || backdrop}\"><div v-if=\"click || backdrop\" class=\"backdrop\" @click=\"toggle(true)\"></div><button class=\"circular raised\" @click=\"toggle()\" :class=\"type\"><i class=\"quasar-fab-icon\">{{icon}}</i> <i class=\"quasar-fab-active-icon\">{{activeIcon}}</i></button><div class=\"quasar-fab-actions flex inline items-center\" :class=\"[direction]\"><slot></slot></div></div>",
  props: {
    type: {
      type: Array,
      default: function _default() {
        return ['primary'];
      },
      coerce: function coerce(value) {
        return Array.isArray(value) || typeof value === 'undefined' ? value : value.split(' ');
      }
    },
    icon: {
      type: String,
      default: 'add'
    },
    activeIcon: {
      type: String,
      default: 'close'
    },
    direction: {
      type: String,
      default: 'right'
    },
    click: {
      type: Function
    },
    backdrop: {
      type: Boolean,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      opened: false
    };
  },

  methods: {
    toggle: function toggle(fromBackdrop) {
      this.opened = !this.opened;

      if (!fromBackdrop && this.click && !this.opened) {
        this.click();
        return;
      }
    }
  },
  events: {
    closeFAB: function closeFAB() {
      this.toggle(true);
    }
  }
};

var SmallFab = { template: "<button class=\"circular small raised\" @click=\"closeFAB()\"><i><slot></slot></i></button>",
  methods: {
    closeFAB: function closeFAB() {
      this.$dispatch('closeFAB');
    }
  }
};

var Gallery = { template: "<div class=\"quasar-gallery\"><div v-for=\"img in src\" track-by=\"$index\" :style=\"{width: width}\"><img :src=\"img\"></div></div>",
  props: {
    src: {
      type: Array,
      required: true
    },
    width: {
      type: String,
      default: '150px'
    }
  }
};

var GallerySlider = { template: "<quasar-slider v-ref:slider arrows fullscreen class=\"text-white bg-black quasar-gallery-slider\"><div v-for=\"img in src\" track-by=\"$index\" slot=\"slide\" class=\"no-padding flex items-center justify-center\"><div class=\"full-width\"><img :src=\"img\"></div></div><div class=\"quasar-gallery-slider-overlay\" :class=\"{active: quickView}\" @click=\"toggleQuickView()\"></div><i slot=\"action\" @click=\"toggleQuickView()\">view_carousel</i><div class=\"quasar-gallery-slider-quickview\" :class=\"{active: quickView}\"><div v-for=\"img in src\" track-by=\"$index\"><img :src=\"img\" :class=\"{active: $refs.slider.slide === $index}\" @click=\"selectImage($index)\"></div></div></quasar-slider>",
  props: {
    src: {
      type: Array,
      required: true
    }
  },
  data: function data() {
    return {
      quickView: false
    };
  },

  methods: {
    toggleQuickView: function toggleQuickView() {
      this.quickView = !this.quickView;
    },
    selectImage: function selectImage(index) {
      this.$refs.slider.goToSlide(index, true);
      this.toggleQuickView();
    }
  }
};

var Grid = { template: "<quasar-grid-table v-ref:table class=\"quasar-grid\" :data=\"data | gridShowSelected showOnlySelected selectionMode singleSelection | filterBy searchQuery\" :columns=\"columns\" :rows-per-page=\"rowsPerPage\" :sortable=\"sortable\" :selection-mode=\"selectionMode\" :selection-actions=\"selectionActions\" :no-data-label=\"noDataLabel\" :id-property=\"idProperty\"></quasar-grid-table>",
  props: {
    columns: {
      type: Array,
      required: true
    },
    data: {
      type: Array,
      required: true
    },
    rowsPerPage: {
      type: Number,
      default: 5
    },
    sortable: {
      type: Boolean,
      default: true,
      coerce: Boolean
    },
    noDataLabel: {
      type: String,
      default: 'No data to display.'
    },
    idProperty: String,
    selectionMode: {
      type: String,
      default: 'none',
      coerce: function coerce(value) {
        return value === 'single' || value === 'multiple' ? value : 'none';
      }
    },
    selectionActions: Array
  },
  data: function data() {
    return {
      searchQuery: '',
      showOnlySelected: false,
      singleSelection: []
    };
  },

  watch: {
    searchQuery: function searchQuery() {
      this.$refs.table.page = 1;
    },
    showOnlySelected: function showOnlySelected() {
      this.$refs.table.page = 1;
    }
  },
  events: {
    'toggle-selection': function toggleSelection() {
      this.showOnlySelected = !this.showOnlySelected;
    },
    filter: function filter(value) {
      this.searchQuery = value;
    },
    'set-single-selection': function setSingleSelection(value) {
      this.singleSelection = value;
    }
  }
};

var defaultRowsPerPage = [{ label: '5', value: 5 }, { label: '10', value: 10 }, { label: '15', value: 15 }, { label: '25', value: 25 }, { label: '50', value: 50 }, { label: '100', value: 100 }, { label: 'No pagination', value: 0 }];

function getRowsPerPageOption(rowsPerPage) {
  if (defaultRowsPerPage.find(function (column) {
    return column.value === rowsPerPage;
  })) {
    return defaultRowsPerPage;
  }

  var options = defaultRowsPerPage.slice(0);

  options.unshift({
    label: '' + rowsPerPage,
    value: rowsPerPage
  });

  return options;
}

var GridTable = { template: "<div class=\"quasar-grid-table\"><div class=\"grid-top-controls sm-column gt-sm-row items-center justify-end\"><div class=\"auto sm-order-last self-center\"><div v-show=\"selectionMode !== 'none' && controls === ''\" transition=\"slide\">Selected {{selectedRows.length}} rows.</div><div v-show=\"selectionMode !== 'none' && controls === 'selection'\" transition=\"slide\"><button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=\"chooseAction()\"><i>menu</i></button> <button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=\"clearSelection()\"><i>cancel</i></button><label><quasar-checkbox :model.sync=\"showOnlySelected\"></quasar-checkbox>&nbsp;Show Selected</label></div><div v-show=\"controls === 'filter'\" transition=\"slide\">Filter: <input v-model=\"searchQuery\" type=\"text\" :debounce=\"350\"> <button class=\"primary clear small\" @click=\"clearFilter()\"><i>clear</i></button></div></div><div class=\"grid-control-panel row\"><button class=\"primary\" :class=\"{'clear': controls !== 'filter'}\" @click=\"toggleControls('filter')\"><i>search</i></button> <button v-if=\"selectionMode !== 'none'\" class=\"primary\" :class=\"{'clear': controls !== 'selection'}\" @click=\"toggleControls('selection')\"><i>playlist_add_check</i></button><quasar-select type=\"radio\" :model.sync=\"rowsPerPage\" :options=\"rowsPerPageOptions\" fixed-label=\"<i>format_list_numbered</i>\"></quasar-select><quasar-select type=\"toggle\" :model.sync=\"chosenColumnsModel\" :options=\"chosenColumnsOptions\" fixed-label=\"<i>view_column</i>\"></quasar-select></div></div><table class=\"quasar-table striped highlight bordered compact full-width\"><thead><tr><th v-if=\"selectionMode !== 'none'\" style=\"width: 30px; text-align: center\">&nbsp</th><th v-for=\"column in columns\" v-show=\"!column.hidden\" @click=\"sortBy(column.field)\" :class=\"{'sortable-column': sortable}\" style=\"text-align: left\">{{{column.label}}} <i v-show=\"sortField === column.field && sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field && sortOrder === 1\">keyboard_arrow_up</i></th></tr></thead><tbody><tr v-for=\"row in data | orderBy sortField sortOrder | limitBy computedRowsPerPage rowOffset\" :track-by=\"idProperty\"><td v-if=\"selectionMode !== 'none'\"><quasar-radio v-if=\"selectionMode === 'single'\" :model.sync=\"singleSelectedRow\" :value=\"row\"></quasar-radio><quasar-checkbox v-else :model.sync=\"row.__selected\"></quasar-checkbox></td><td v-for=\"column in columns\" v-if=\"!column.hidden\" :style=\"column.style\" :class=\"column.classes\" :data-th=\"column.label\">{{{column.formatter ? column.formatter(row[column.field]) : row[column.field]}}}</td></tr></tbody><tfoot v-show=\"computedRowsPerPage > 10\"><tr><th v-if=\"selectionMode !== 'none'\">&nbsp</th><th v-for=\"column in columns\" v-show=\"!column.hidden\" @click=\"sortBy(column.field)\" :class=\"{'sortable-column': sortable}\">{{{column.label}}} <i v-show=\"sortField === column.field && sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field && sortOrder === 1\">keyboard_arrow_up</i></th></tr></tfoot></table><div class=\"grid-bottom-controls sm-column gt-sm-row items-center\"><div class=\"auto\" v-show=\"data.length > 0\">Showing {{rowOffset + 1}} to {{Math.min(rowsNumber, rowsPerPage * page)}} of {{rowsNumber}} entries</div><div class=\"auto text-center\" v-else>{{noDataLabel}}</div><quasar-pagination :model.sync=\"page\" :max=\"pagesNumber\" v-show=\"rowsPerPage !== 0 && rowsNumber > 0\"></quasar-pagination></div></div>",
  props: ['data', 'columns', 'rowsPerPage', 'sortable', 'noDataLabel', 'idProperty', 'selectionMode', 'selectionActions'],
  data: function data() {
    var rowsPerPage = this.rowsPerPage,
        chosenColumns = this.getChosenColumn();

    return {
      page: 1,
      rowsPerPageOptions: getRowsPerPageOption(rowsPerPage),
      sortField: '',
      sortOrder: 1,
      chosenColumnsModel: chosenColumns,
      singleSelectedRow: null,
      searchQuery: '',
      controls: '',
      showOnlySelected: false
    };
  },

  computed: {
    rowsNumber: function rowsNumber() {
      return this.data.length;
    },
    pagesNumber: function pagesNumber() {
      return Math.ceil(this.data.length / this.rowsPerPage);
    },
    chosenColumnsOptions: function chosenColumnsOptions() {
      return this.columns.map(function (column) {
        return {
          label: column.label,
          value: column.field
        };
      });
    },
    computedRowsPerPage: function computedRowsPerPage() {
      return this.rowsPerPage ? this.rowsPerPage : Infinity;
    },
    rowOffset: function rowOffset() {
      return this.rowsPerPage * (this.page - 1);
    },
    selectedRows: function selectedRows() {
      if (this.selectionMode === 'single') {
        return this.singleSelectedRow ? [this.singleSelectedRow] : [];
      }
      return this.data.filter(function (row) {
        return row.__selected === true;
      });
    },
    actionsModel: function actionsModel() {
      var index = -1;

      return this.selectionActions.map(function (item) {
        return {
          label: item.label,
          value: ++index
        };
      });
    }
  },
  watch: {
    rowsPerPage: function rowsPerPage(value) {
      this.page = 1;
    },
    chosenColumnsModel: function chosenColumnsModel(options) {
      for (var i = 0; i < this.columns.length; i++) {
        this.columns.$set(i, Utils.extend({}, this.columns[i], {
          hidden: !options.includes(this.columns[i].field)
        }));
      }
    },
    searchQuery: function searchQuery(value) {
      this.$dispatch('filter', value);
    },
    showOnlySelected: function showOnlySelected(value) {
      this.$dispatch('toggle-selection');
    },
    singleSelectedRow: function singleSelectedRow(value) {
      this.$dispatch('set-single-selection', [value]);
    }
  },
  methods: {
    goToPageByOffset: function goToPageByOffset(pageOffset) {
      this.page = Math.min(this.pagesNumber, Math.max(1, this.page + pageOffset));
    },
    sortBy: function sortBy(field) {
      if (!this.sortable) {
        return;
      }

      if (this.sortField !== field) {
        this.sortOrder = 1;
        this.sortField = field;
        return;
      }

      if (this.sortOrder === -1) {
        this.sortField = '';
      } else {
        this.sortOrder = -1;
      }
    },
    getChosenColumn: function getChosenColumn() {
      return this.columns.filter(function (column) {
        return column.hidden !== true;
      }).map(function (column) {
        return column.field;
      });
    },
    clearSelection: function clearSelection() {
      if (this.selectionMode === 'single') {
        this.singleSelectedRow = null;
      } else {
        this.data.forEach(function (row) {
          if (row.hasOwnProperty('__selected')) {
            row.__selected = false;
          }
        });
      }

      this.showOnlySelected = false;
    },
    clearFilter: function clearFilter() {
      this.searchQuery = '';
      this.controls = '';
    },
    toggleControls: function toggleControls(mode) {
      this.controls = this.controls === mode ? '' : mode;
    },
    chooseAction: function chooseAction() {
      var options = this.actionsModel,
          selectedRows = this.selectedRows,
          actions = this.selectionActions;

      if (selectedRows.length === 0) {
        return;
      }

      Dialog.create({
        title: 'Actions',
        message: 'Apply action for the ' + selectedRows.length + ' selected row(s).',
        radios: options,
        buttons: ['Cancel', {
          label: 'Apply',
          handler: function handler(data) {
            actions[data].handler(selectedRows);
          }
        }]
      }).show();
    }
  }
};

var InfiniteScroll = { template: "<div class=\"quasar-infinite-scroll\"><div v-el:content class=\"quasar-infinite-scroll-content\"><slot></slot></div><br><div class=\"quasar-infinite-scroll-message\" v-show=\"fetching\"><slot name=\"message\"></slot></div></div>",
  props: {
    handler: {
      type: Function,
      required: true
    },
    inline: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    offset: {
      type: Number,
      default: 0
    },
    working: {
      type: Boolean,
      default: true,
      coerce: Boolean,
      twoWay: true
    }
  },
  data: function data() {
    return {
      index: 0,
      fetching: false
    };
  },

  watch: {
    working: function working(value) {
      this.scrollContainer[value ? 'addEventListener' : 'removeEventListener']('scroll', this.scroll);
      if (value) {
        this.scroll();
      }
    }
  },
  methods: {
    scroll: function scroll() {
      if (this.fetching || !this.working) {
        return;
      }

      var containerHeight = Utils.dom.height(this.scrollContainer),
          containerBottom = Utils.dom.offset(this.scrollContainer).top + containerHeight,
          triggerPosition = Utils.dom.offset(this.element).top + Utils.dom.height(this.element) - (this.offset || containerHeight);

      if (triggerPosition < containerBottom) {
        this.loadMore();
      }
    },
    loadMore: function loadMore() {
      var _this = this;

      if (this.fetching || !this.working) {
        return;
      }

      this.index++;
      this.fetching = true;
      this.handler(this.index, function (stopLoading) {
        _this.fetching = false;
        if (stopLoading) {
          _this.stop();
          return;
        }
        if (_this.element.closest('body')) {
          _this.scroll();
        }
      });
    },
    reset: function reset() {
      this.index = 0;
    },
    resume: function resume() {
      this.working = true;
    },
    stop: function stop() {
      this.working = false;
    }
  },
  ready: function ready() {
    this.scroll = Utils.debounce(this.scroll, 50);
    this.element = this.$els.content;

    this.scrollContainer = this.inline ? this.$el : this.element.closest('.layout-view');
    if (!this.scrollContainer) {
      this.scrollContainer = window;
    }
    if (this.working) {
      this.scrollContainer.addEventListener('scroll', this.scroll);
    }

    this.scroll();
  },
  beforeDestroy: function beforeDestroy() {
    this.scrollContainer.removeEventListener('scroll', this.scroll);
  }
};

var Knob = { template: "<div class=\"quasar-knob non-selectable cursor-pointer\" :class=\"{disabled: disable}\" :style=\"{width: size, height: size}\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><svg viewBox=\"0 0 100 100\"><path d=\"M 50,50 m 0,-47\n         a 47,47 0 1 1 0,94\n         a 47,47 0 1 1 0,-94\" :stroke=\"trackColor\" :stroke-width=\"lineWidth\" fill-opacity=\"0\"></path><path stroke-linecap=\"round\" fill-opacity=\"0\" d=\"M 50,50 m 0,-47\n         a 47,47 0 1 1 0,94\n         a 47,47 0 1 1 0,-94\" :stroke=\"color\" :stroke-width=\"lineWidth\" :style=\"svgStyle\"></path></svg><div class=\"quasar-knob-label row items-center justify-center content-center\" :style=\"{color: color}\">{{{ placeholder || model }}}</div></div>",
  props: {
    model: {
      type: Number,
      required: true,
      twoWay: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    min: {
      type: Number,
      default: 0
    },
    max: {
      type: Number,
      default: 100
    },
    color: {
      type: String,
      default: '#027be3'
    },
    trackColor: {
      type: String,
      default: '#ececec'
    },
    lineWidth: {
      type: String,
      default: '6px'
    },
    size: {
      type: String,
      default: '100px'
    },
    step: {
      type: Number,
      default: 1
    },
    placeholder: String
  },
  computed: {
    svgStyle: function svgStyle() {
      return {
        'stroke-dasharray': '295.31px, 295.31px',
        'stroke-dashoffset': 295.31 * (1.0 - (this.model - this.min) / (this.max - this.min)) + 'px',
        'transition': this.dragging ? '' : 'stroke-dashoffset 0.6s ease 0s, stroke 0.6s ease'
      };
    }
  },
  data: function data() {
    return {
      dragging: false
    };
  },

  watch: {
    model: function model(value) {
      if (value < this.min) {
        this.model = this.min;
      } else if (value > this.max) {
        this.model = this.max;
      }
    }
  },
  methods: {
    __dragStart: function __dragStart(ev) {
      if (this.disable) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();

      var knobOffset = Utils.dom.offset(this.$el);

      this.centerPosition = {
        top: knobOffset.top + Utils.dom.height(this.$el) / 2,
        left: knobOffset.left + Utils.dom.width(this.$el) / 2
      };

      this.dragging = true;
      this.__updateModel(ev);
    },
    __dragMove: function __dragMove(ev) {
      if (!this.dragging || this.disable) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();
      this.__updateModel(ev);
    },
    __dragStop: function __dragStop(ev) {
      if (this.disable) {
        return;
      }
      ev.stopPropagation();
      ev.preventDefault();
      this.dragging = false;
    },
    __updateModel: function __updateModel(ev) {
      var position = Utils.event.position(ev),
          height = Math.abs(position.top - this.centerPosition.top),
          distance = Math.sqrt(Math.pow(Math.abs(position.top - this.centerPosition.top), 2) + Math.pow(Math.abs(position.left - this.centerPosition.left), 2)),
          angle = Math.asin(height / distance) * (180 / Math.PI);

      if (position.top < this.centerPosition.top) {
        angle = this.centerPosition.left < position.left ? 90 - angle : 270 + angle;
      } else {
        angle = this.centerPosition.left < position.left ? angle + 90 : 270 - angle;
      }

      var model = this.min + angle / 360 * (this.max - this.min),
          modulo = model % this.step;

      this.model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)));
    }
  }
};

var Layout = { template: "<div class=\"layout\"><div class=\"layout-header\"><slot name=\"header\"></slot></div><slot name=\"navigation\"></slot><div class=\"layout-content\"><slot></slot></div><div class=\"layout-footer\"><slot name=\"footer\"></slot></div></div>" };

var ToolbarTitle = { template: "<div class=\"toolbar-content\"><div class=\"toolbar-title\" :class=\"['padding-' + padding]\"><div><slot></slot></div></div></div>",
  props: {
    padding: {
      type: Number,
      default: 1
    }
  }
};

var Modal$2 = { template: "<div class=\"modal hidden fullscreen flex items-center justify-center\"><div class=\"modal-backdrop backdrop\"></div><div class=\"modal-content\"><slot></slot></div></div>",
  props: {
    set: Object,
    css: Object
  },
  methods: {
    show: function show(onShow) {
      var _this = this;

      if (this.modal) {
        console.warn('Trying to show modal while it is being displayed.');
        return;
      }

      this.modal = Modal$1.create(this.$el).set(this.set || {}).css(this.css || {}).onClose(function () {
        _this.modal = null;
      }).show(onShow);
    },
    close: function close(onClose) {
      if (!this.modal) {
        console.warn('Trying to close modal but no modal exists.');
      }

      this.modal.close(onClose);
    }
  },
  beforeDestroy: function beforeDestroy() {
    if (this.modal) {
      this.modal.destroy();
    }
  }
};

var Numeric = { template: "<div class=\"quasar-numeric textfield row inline items-center\" :class=\"{disabled: disable}\"><i @click=\"setByOffset(-1)\">remove</i> <input class=\"no-style auto\" type=\"text\" v-model=\"model\" class=\"quasar-input-field\" :style=\"{width: (''+model).length * .7 + 'em'}\" v-attr=\"attrib\" number> <i @click=\"setByOffset(1)\">add</i></div>",
  props: {
    model: {
      type: Number,
      default: 0,
      coerce: function coerce(value) {
        return parseFloat(value, 10) || 0;
      }
    },
    step: {
      type: Number,
      default: 1,
      coerce: function coerce(value) {
        return parseFloat(value, 10);
      }
    },
    min: Number,
    max: Number,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  watch: {
    model: function model() {
      this.$nextTick(this.validate);
    }
  },
  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  },
  methods: {
    validate: function validate() {
      if (typeof this.min === 'number' && this.model < this.min && this.model !== 0) {
        this.model = this.min;
      } else if (typeof this.max === 'number' && this.model > this.max) {
        this.model = this.max;
      }
    },
    setByOffset: function setByOffset(direction) {
      if (!this.disable) {
        this.model += direction * this.step;
      }
    }
  }
};

var Pagination = { template: "<div class=\"quasar-pagination\" :class=\"{disabled: disable}\"><button :class=\"{disabled: model === min}\" class=\"primary clear small\" @click=\"changeModelTo(min)\"><i>first_page</i></button> <button :class=\"{disabled: model === min}\" class=\"primary clear small\" @click=\"changeModelByOffset(-1)\"><i>keyboard_arrow_left</i></button> <input v-el:input type=\"text\" v-model=\"newPage\" number lazy :style=\"{width: inputPlaceholder.length * 10 + 'px'}\" :placeholder=\"inputPlaceholder\" v-attr=\"attrib\"> <button :class=\"{disabled: model === max}\" class=\"primary clear small\" @click=\"changeModelByOffset(1)\"><i>keyboard_arrow_right</i></button> <button :class=\"{disabled: model === max}\" class=\"primary clear small\" @click=\"changeModelTo(max)\"><i>last_page</i></button></div>",
  props: {
    model: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    min: {
      type: Number,
      default: 1
    },
    max: {
      type: Number,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      rangeMode: false,
      newPage: ''
    };
  },

  methods: {
    changeModelTo: function changeModelTo(value) {
      if (!this.disable) {
        this.model = this.normalize(value);
      }
    },
    changeModelByOffset: function changeModelByOffset(offset) {
      if (!this.disable) {
        this.model = this.normalize(this.model + offset);
      }
    },
    normalize: function normalize(value) {
      return Math.min(this.max, Math.max(1, value));
    }
  },
  computed: {
    inputPlaceholder: function inputPlaceholder() {
      return this.model + ' / ' + this.max;
    },
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  },
  watch: {
    newPage: function newPage(value) {
      var parsed = parseInt(value, 10);

      if (parsed) {
        this.model = this.normalize(parsed);
        this.$els.input.blur();
      }

      this.newPage = '';
    }
  }
};

var Parallax = { template: "<div class=\"quasar-parallax column items-center justify-center\" :style=\"{height: height + 'px'}\"><div class=\"quasar-parallax-image\"><img v-el:img :src=\"src\" @load=\"processImage()\" :class=\"{ready: imageHasBeenLoaded}\" style=\"transform: translate3D(-50%, 0, 0)\"></div><div class=\"quasar-parallax-text\"><slot name=\"loading\" v-if=\"!imageHasBeenLoaded\"></slot><slot v-else></slot></div></div>",
  props: {
    src: {
      type: String,
      required: true
    },
    height: {
      type: Number,
      default: 500
    },
    speed: {
      type: Number,
      default: 1,
      validator: function validator(value) {
        return value >= 0 && value <= 1;
      }
    }
  },
  data: function data() {
    return {
      imageHasBeenLoaded: false
    };
  },

  watch: {
    src: function src() {
      this.imageHasBeenLoaded = false;
    },
    height: function height() {
      this.updatePosition();
    }
  },
  methods: {
    processImage: function processImage() {
      this.imageHasBeenLoaded = true;
      this.processResize();
    },
    processResize: function processResize() {
      if (!this.imageHasBeenLoaded || !this.scrollTarget) {
        return;
      }

      this.imageHeight = Utils.dom.height(this.image);
      this.updatePosition();
    },
    updatePosition: function updatePosition() {
      var _this = this;

      if (!this.imageHasBeenLoaded) {
        return;
      }

      var containerTop = void 0,
          containerHeight = void 0,
          containerBottom = void 0,
          top = void 0,
          bottom = void 0;

      if (this.scrollTarget === window) {
        containerTop = 0;
        containerHeight = Utils.dom.viewport().height;
        containerBottom = containerHeight;
      } else {
        containerTop = Utils.dom.offset(this.scrollTarget).top;
        containerHeight = Utils.dom.height(this.scrollTarget);
        containerBottom = containerTop + containerHeight;
      }
      top = Utils.dom.offset(this.container).top;
      bottom = top + this.height;

      if (bottom > containerTop && top < containerBottom) {
        (function () {
          var percentScrolled = (containerBottom - top) / (_this.height + containerHeight);
          var imageOffset = Math.round((_this.imageHeight - _this.height) * percentScrolled * _this.speed);
          requestAnimationFrame(function () {
            _this.$els.img.style.transform = 'translate3D(-50%,' + imageOffset + 'px, 0)';
          });
        })();
      }
    }
  },
  ready: function ready() {
    this.container = this.$el;
    this.image = this.$els.img;

    this.scrollTarget = Utils.dom.getScrollTarget(this.$el);
    this.resizeHandler = Utils.debounce(this.processResize, 50);

    window.addEventListener('resize', this.resizeHandler);
    this.scrollTarget.addEventListener('scroll', this.updatePosition);
    this.processResize();
  },
  beforeDestroy: function beforeDestroy() {
    window.removeEventListener('resize', this.resizeHandler);
    this.scrollTarget.removeEventListener('scroll', this.updatePosition);
  }
};

var offset$1 = 20;
var cssReset = {
  top: '',
  bottom: '',
  left: '',
  right: '',
  minWidth: '',
  maxHeight: '',
  maxWidth: '',
  transformOrigin: ''
};

var Popover = { template: "<span class=\"quasar-popover-target\"><slot name=\"target\"></slot><div v-el:content class=\"quasar-popover-content\" :class=\"{active: active}\"><slot></slot></div></span>",
  data: function data() {
    return {
      active: false
    };
  },

  props: {
    touchPosition: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    position: String,
    cover: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    toggle: function toggle(event) {
      this[this.active ? 'close' : 'open'](event);
    },
    open: function open(event) {
      var _this = this;

      if (this.disable || this.active || this.inProgress) {
        return;
      }

      event.preventDefault();

      var content = this.$els.content,
          target = this.$el.children[0],
          targetWidth = Utils.dom.width(target),
          targetHeight = Utils.dom.height(target),
          targetPosition = target.getBoundingClientRect(),
          position = void 0,
          css = Utils.extend({}, cssReset);

      if (this.cover) {
        css.minWidth = targetWidth + 'px';
      }
      Utils.dom.css(content, css);

      content.classList.add('check');
      content.scrollTop = 0;

      var viewport = Utils.dom.viewport(),
          windowWidth = viewport.width,
          windowHeight = viewport.height,
          contentWidth = Utils.dom.width(content),
          contentHeight = Utils.dom.height(content);

      if (this.touchPosition) {
        var touchPosition = Utils.event.position(event);
        position = {
          top: touchPosition.top,
          left: touchPosition.left
        };
      } else {
        position = {
          top: targetPosition.top,
          left: targetPosition.left
        };
      }

      var toRight = position.left + contentWidth < windowWidth || 2 * position.left < windowWidth,
          toBottom = position.top + contentHeight < windowHeight || 2 * position.top < windowHeight;

      content.classList.remove('check', 'left', 'right', 'bottom', 'top');

      if (this.position) {
        var _position = this.position.split(' ');

        if (_position.includes('left')) {
          toRight = false;
        } else if (_position.includes('right')) {
          toRight = true;
        }

        if (_position.includes('top')) {
          toBottom = false;
        } else if (_position.includes('bottom')) {
          toBottom = true;
        }
      }

      if (this.touchPosition) {
        if (!toRight) {
          position.left -= contentWidth;
        }
      } else {
        if (!toBottom) {
          position.top += targetHeight;
        }
        if (!toRight) {
          position.left += targetWidth - contentWidth;
        }
      }

      if (toRight) {
        content.classList.add('left');
        css.left = position.left + 'px';
        if (windowWidth - position.left < contentWidth) {
          css.maxWidth = windowWidth - position.left - offset$1 + 'px';
        }
      } else {
        content.classList.add('right');
        css.left = position.left + 'px';
        if (position.left < contentWidth) {
          css.maxWidth = position.left - offset$1 + 'px';
        }
      }

      if (toBottom) {
        content.classList.add('top');
        css.top = position.top + 'px';
        if (windowHeight - position.top < contentHeight) {
          css.maxHeight = windowHeight - position.top - offset$1 + 'px';
        }
      } else {
        content.classList.add('bottom');
        css.bottom = windowHeight - position.top + 'px';
        if (position.top < contentHeight) {
          css.maxHeight = position.top - offset$1 + 'px';
        }
      }

      Utils.dom.css(content, css);
      this.active = true;
      this.inProgress = true;

      setTimeout(function () {
        document.addEventListener('click', _this.closeFromOutside);
        _this.scrollTarget = Utils.dom.getScrollTarget(target);
        _this.scrollTarget.addEventListener('scroll', _this.close);
        EscapeKey.register(function () {
          _this.close();
        });
        _this.inProgress = false;
      }, 210);
    },
    close: function close() {
      var _this2 = this;

      if (this.active && !this.inProgress) {
        this.active = false;
        this.inProgress = true;
        setTimeout(function () {
          if (_this2.$els.content) {
            Utils.dom.css(_this2.$els.content, cssReset);
          }
          _this2.inProgress = false;
        }, 200);

        if (this.scrollTarget) {
          this.scrollTarget.removeEventListener('scroll', this.close);
          this.scrollTarget = null;
        }
        document.removeEventListener('click', this.closeFromOutside);
        EscapeKey.pop();
      }
    },
    closeFromOutside: function closeFromOutside(event) {
      if (!this.active || this.$els.content === event.target.closest('.quasar-popover-content')) {
        return;
      }
      this.close();
    }
  },
  ready: function ready() {
    this.$el.children[0].addEventListener('click', this.toggle);
  },
  beforeDestroy: function beforeDestroy() {
    this.$el.children[0].removeEventListener('click', this.toggle);
    if (this.active) {
      this.close();
    }
  }
};

var Progress = { template: "<div class=\"quasar-progress\"><div :style=\"{width: model + '%'}\"></div></div>",
  props: {
    model: {
      type: Number,
      default: 0
    }
  }
};

var ProgressButton = { template: "<button class=\"quasar-progress-button\" :class=\"{active: active, indeterminate: indeterminate}\"><span v-if=\"!indeterminate\" class=\"quasar-progress-button-filler\" :class=\"{'quasar-progress-button-dark-filler': darkFiller}\" :style=\"{width: computedPercentage}\"></span><div class=\"quasar-progress-button-content\" :class=\"state\"><div class=\"quasar-progress-button-error\"><i>{{ errorIcon }}</i></div><div class=\"quasar-progress-button-label\"><slot></slot></div><div class=\"quasar-progress-button-success\"><i>{{ successIcon }}</i></div></div></button>",
  props: {
    percentage: {
      type: Number,
      required: true
    },
    errorIcon: {
      type: String,
      default: 'warning'
    },
    successIcon: {
      type: String,
      default: 'done'
    },
    darkFiller: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    indeterminate: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    active: function active() {
      return this.percentage > 0 && this.percentage < 100;
    },
    state: function state() {
      if (this.percentage >= 100) {
        return 'quasar-progress-button-complete';
      }
      if (this.percentage < 0) {
        return 'quasar-progress-button-incomplete';
      }
      return 'quasar-progress-button-default';
    },
    computedPercentage: function computedPercentage() {
      if (this.percentage >= 100) {
        return '0%';
      }

      return Math.max(0, this.percentage) + '%';
    }
  }
};

var PullToRefresh = { template: "<div class=\"pull-to-refresh\"><div class=\"pull-to-refresh-container\" :style=\"{transform: 'translateY(' + pullPosition + 'px)'}\" v-touch:pan=\"pull\" v-touch-options:pan=\"{ direction: 'vertical' }\"><div class=\"pull-to-refresh-message row items-center justify-center\"><i v-show=\"state !== 'refreshing'\" :class=\"{'rotate-180': state === 'pulled'}\">arrow_downward</i> <i v-else class=\"spin\">{{refreshIcon}}</i> &nbsp;&nbsp; <span v-show=\"state === 'pull'\">{{pullMessage}} </span><span v-show=\"state === 'pulled'\">{{releaseMessage}} </span><span v-show=\"state === 'refreshing'\">{{refreshMessage}}</span></div><slot></slot></div></div>",
  props: {
    handler: {
      type: Function,
      required: true
    },
    distance: {
      type: Number,
      default: 35
    },
    pullMessage: {
      type: String,
      default: 'Pull down to refresh'
    },
    releaseMessage: {
      type: String,
      default: 'Release to refresh'
    },
    refreshMessage: {
      type: String,
      default: 'Refreshing...'
    },
    refreshIcon: {
      type: String,
      default: 'refresh'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    var height = 65;

    return {
      state: 'pull',
      pullPosition: -height,
      height: height,
      animating: false,
      pulling: false,
      scrolling: false
    };
  },

  methods: {
    pull: function pull(hammer) {
      if (this.scrolling) {
        if (hammer.isFinal) {
          this.scrolling = false;
        }
        return;
      }
      if (this.animating) {
        return;
      }
      if (this.disable) {
        this.scrolling = false;
        this.pulling = false;
        this.animating = false;
        this.state = 'pull';
        return;
      }

      if (!this.pulling) {
        if (this.state === 'refreshing') {
          return;
        }
        if (this.pullPosition === -this.height && hammer.direction === Hammer.DIRECTION_UP) {
          return;
        }

        var containerTop = Utils.dom.offset(this.scrollContainer).top,
            thisContainerTop = Utils.dom.offset(this.$el).top;

        if (containerTop > thisContainerTop) {
          this.scrolling = true;
          return;
        }

        this.originalScrollOverflow = this.scrollContainer.style.overflow;
        this.scrollContainer.style.overflow = 'hidden';
      }

      this.pulling = true;
      this.pullPosition = -this.height + Math.max(0, Math.pow(hammer.deltaY, 0.85));

      if (this.pullPosition > this.distance) {
        if (hammer.isFinal) {
          this.state = 'refreshing';
          this.pulling = false;
          this.scrollContainer.style.overflow = this.originalScrollOverflow;
          this.animateTo(0);
          this.trigger();
        } else {
          this.state = 'pulled';
        }
      } else {
        this.state = 'pull';
        if (hammer.isFinal) {
          this.pulling = false;
          this.scrollContainer.style.overflow = this.originalScrollOverflow;
          this.animateTo(-this.height);
        }
      }
    },
    animateTo: function animateTo(target, done, previousCall) {
      var _this = this;

      if (!previousCall && this.animationId) {
        cancelAnimationFrame(this.animating);
      }

      this.pullPosition -= (this.pullPosition - target) / 7;

      if (this.pullPosition - target > 1) {
        this.animating = requestAnimationFrame(function () {
          _this.animateTo(target, done, true);
        });
      } else {
        this.animating = requestAnimationFrame(function () {
          _this.pullPosition = target;
          _this.animating = false;
          done && done();
        });
      }
    },
    trigger: function trigger() {
      var _this2 = this;

      this.handler(function () {
        _this2.animateTo(-_this2.height, function () {
          _this2.state = 'pull';
        });
      });
    }
  },
  ready: function ready() {
    this.scrollContainer = this.$el.parentNode;
  }
};

var Radio = { template: "<label class=\"quasar-radio\" :class=\"{disabled: disable}\"><input type=\"radio\" v-model=\"model\" :value=\"value\" v-attr=\"attrib\"><div></div></label>",
  props: {
    model: {
      twoWay: true,
      required: true
    },
    value: {
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  }
};

var Range = { template: "<div class=\"quasar-range non-selectable\" :class=\"{disabled: disable}\" @mousedown.prevent=\"setActive\" @touchstart.prevent=\"setActive\" @touchend.prevent=\"end\" @touchmove.prevent=\"update\"><div v-el:handle class=\"quasar-range-handle-container\"><div class=\"quasar-range-track\"></div><div v-if=\"markers\" class=\"quasar-range-mark\" v-for=\"n in ((this.max - this.min) / this.step + 1)\" :style=\"{left: n * 100 * this.step / (this.max - this.min) + '%'}\"></div><div class=\"quasar-range-track active-track\" :style=\"{width: percentage}\" :class=\"{'no-transition': dragging, 'handle-at-minimum': model === min}\"></div><div class=\"quasar-range-handle\" :style=\"{left: percentage}\" :class=\"{dragging: dragging, 'handle-at-minimum': model === min}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ model }}</div></div></div></div>",
  props: {
    model: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    min: {
      type: Number,
      default: 1,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    max: {
      type: Number,
      default: 5,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    step: {
      type: Number,
      default: 1,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    snap: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    markers: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    label: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      dragging: false,
      currentPercentage: (this.model - this.min) / (this.max - this.min)
    };
  },

  computed: {
    percentage: function percentage() {
      if (this.snap) {
        return (this.model - this.min) / (this.max - this.min) * 100 + '%';
      }
      return 100 * this.currentPercentage + '%';
    }
  },
  watch: {
    model: function model(value) {
      if (this.dragging) {
        return;
      }
      this.currentPercentage = (value - this.min) / (this.max - this.min);
    },
    min: function min(value) {
      if (this.model < value) {
        this.model = value;
        return;
      }
      this.$nextTick(this.validateProps);
    },
    max: function max(value) {
      if (this.model > value) {
        this.model = value;
        return;
      }
      this.$nextTick(this.validateProps);
    },
    step: function step() {
      this.$nextTick(this.validateProps);
    }
  },
  methods: {
    setActive: function setActive(event) {
      if (this.disable) {
        return;
      }

      var container = this.$els.handle;

      this.dragging = {
        left: container.getBoundingClientRect().left,
        width: container.offsetWidth
      };
      this.update(event);
    },
    update: function update(event) {
      if (!this.dragging) {
        return;
      }

      var percentage = Math.min(1, Math.max(0, (Utils.event.position(event).left - this.dragging.left) / this.dragging.width)),
          model = this.min + percentage * (this.max - this.min),
          modulo = model % this.step;

      this.currentPercentage = percentage;
      this.model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)));
    },
    end: function end() {
      this.dragging = false;
      this.currentPercentage = (this.model - this.min) / (this.max - this.min);
    },
    validateProps: function validateProps() {
      if (this.min >= this.max) {
        console.error('Range error: min >= max', this.$el, this.min, this.max);
      } else if ((this.max - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of max - min', this.$el, this.min, this.max, this.step);
      }
    }
  },
  beforeCompile: function beforeCompile() {
    this.validateProps();
    if (Platform.is.desktop) {
      document.body.addEventListener('mousemove', this.update);
      document.body.addEventListener('mouseup', this.end);
    }
  },
  beforeDestroy: function beforeDestroy() {
    if (Platform.is.dekstop) {
      document.body.removeEventListener('mousemove', this.update);
      document.body.removeEventListener('mouseup', this.end);
    }
  }
};

var DoubleRange = { template: "<div class=\"quasar-range non-selectable\" :class=\"{disabled: disable}\" @mousedown.prevent=\"setActive\" @touchstart.prevent=\"setActive\" @touchend.prevent=\"end\" @touchmove.prevent=\"update\"><div v-el:handle class=\"quasar-range-handle-container\"><div class=\"quasar-range-track\"></div><div v-if=\"markers\" class=\"quasar-range-mark\" v-for=\"n in ((this.max - this.min) / this.step + 1)\" :style=\"{left: n * 100 * this.step / (this.max - this.min) + '%'}\"></div><div class=\"quasar-range-track active-track no-transition\" :style=\"{left: percentageMin * 100 + '%', width: activeTrackWidth}\"></div><div class=\"quasar-range-handle no-transition\" :style=\"{left: percentageMin * 100 + '%'}\" :class=\"{dragging: dragging, 'handle-at-minimum': modelMin === min}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ modelMin }}</div></div><div class=\"quasar-range-handle no-transition\" :style=\"{left: percentageMax * 100 + '%'}\" :class=\"{dragging: dragging}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ modelMax }}</div></div></div></div>",
  props: {
    modelMin: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    modelMax: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    min: {
      type: Number,
      default: 0,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    max: {
      type: Number,
      default: 100,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    step: {
      type: Number,
      default: 1,
      coerce: function coerce(value) {
        return parseInt(value, 10);
      }
    },
    snap: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    markers: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    label: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      dragging: false,
      currentMinPercentage: (this.modelMin - this.min) / (this.max - this.min),
      currentMaxPercentage: (this.modelMax - this.min) / (this.max - this.min)
    };
  },

  computed: {
    percentageMin: function percentageMin() {
      if (this.snap) {
        return (this.modelMin - this.min) / (this.max - this.min);
      }
      return this.currentMinPercentage;
    },
    percentageMax: function percentageMax() {
      if (this.snap) {
        return (this.modelMax - this.min) / (this.max - this.min);
      }
      return this.currentMaxPercentage;
    },
    activeTrackWidth: function activeTrackWidth() {
      return 100 * (this.percentageMax - this.percentageMin) + '%';
    }
  },
  watch: {
    modelMin: function modelMin(value) {
      if (this.dragging) {
        return;
      }
      if (value > this.modelMax) {
        value = this.modelMax;
      }
      this.currentMinPercentage = (value - this.min) / (this.max - this.min);
    },
    modelMax: function modelMax(value) {
      if (this.dragging) {
        return;
      }
      if (value < this.modelMin) {
        value = this.modelMin;
      }
      this.currentMaxPercentage = (value - this.min) / (this.max - this.min);
    },
    min: function min(value) {
      if (this.modelMin < value) {
        this.modelMin = value;
      }
      if (this.modelMax < value) {
        this.modelMax = value;
      }
      this.$nextTick(this.validateProps);
    },
    max: function max(value) {
      if (this.modelMin > value) {
        this.modelMin = value;
      }
      if (this.modelMax > value) {
        this.modelMax = value;
      }
      this.$nextTick(this.validateProps);
    },
    step: function step() {
      this.$nextTick(this.validateProps);
    }
  },
  methods: {
    setActive: function setActive(event) {
      if (this.disable) {
        return;
      }

      var container = this.$els.handle;

      this.dragging = {
        left: container.getBoundingClientRect().left,
        width: container.offsetWidth,
        modelMin: this.modelMin,
        percentageMin: this.currentMinPercentage,
        modelMax: this.modelMax,
        percentageMax: this.currentMaxPercentage
      };

      var offset = Utils.event.position(event).left - this.dragging.left,
          percentage = Math.min(1, Math.max(0, offset / this.dragging.width));

      this.dragging.onLeft = Math.abs(percentage - this.currentMinPercentage) <= Math.abs(percentage - this.currentMaxPercentage);
      this.update(event);
    },
    update: function update(event) {
      if (!this.dragging) {
        return;
      }

      var percentage = Math.min(1, Math.max(0, (Utils.event.position(event).left - this.dragging.left) / this.dragging.width)),
          model = this.min + percentage * (this.max - this.min),
          modulo = model % this.step;

      model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)));

      if (this.dragging.onLeft) {
        if (percentage <= this.dragging.percentageMax) {
          this.currentMinPercentage = percentage;
          this.modelMin = model;

          this.currentMaxPercentage = this.dragging.percentageMax;
          this.modelMax = this.dragging.modelMax;
        } else {
          this.currentMinPercentage = this.dragging.percentageMax;
          this.modelMin = this.dragging.modelMax;

          this.currentMaxPercentage = percentage;
          this.modelMax = model;
        }
      } else {
        if (percentage >= this.dragging.percentageMin) {
          this.currentMaxPercentage = percentage;
          this.modelMax = model;

          this.currentMinPercentage = this.dragging.percentageMin;
          this.modelMin = this.dragging.modelMin;
        } else {
          this.currentMaxPercentage = this.dragging.percentageMin;
          this.modelMax = this.dragging.modelMin;

          this.currentMinPercentage = percentage;
          this.modelMin = model;
        }
      }
    },
    end: function end() {
      this.dragging = false;
      this.currentMinPercentage = (this.modelMin - this.min) / (this.max - this.min);
      this.currentMaxPercentage = (this.modelMax - this.min) / (this.max - this.min);
    },
    validateProps: function validateProps() {
      if (this.min >= this.max) {
        console.error('Range error: min >= max', this.$el, this.min, this.max);
      } else if ((this.max - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of max - min', this.$el, this.min, this.max, this.step);
      } else if ((this.modelMin - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of initial modelMin - min', this.$el, this.modelMin, this.min, this.step);
      } else if ((this.modelMax - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of initial modelMax - min', this.$el, this.modelMax, this.max, this.step);
      }
    }
  },
  beforeCompile: function beforeCompile() {
    this.validateProps();
    if (Platform.is.desktop) {
      document.body.addEventListener('mousemove', this.update);
      document.body.addEventListener('mouseup', this.end);
    }
  },
  beforeDestroy: function beforeDestroy() {
    if (Platform.is.dekstop) {
      document.body.removeEventListener('mousemove', this.update);
      document.body.removeEventListener('mouseup', this.end);
    }
  }
};

var Rating = { template: "<div class=\"quasar-rating\" :class=\"{disabled: disable}\"><i v-for=\"index in maxGrade\" :class=\"{active: (!mouseModel && model > index) || (mouseModel && mouseModel > index)}\" @click=\"set(index + 1)\" @mouseover=\"setHoverValue(index + 1)\" @mouseout=\"mouseModel = 0\">{{icon}}</i></div>",
  props: {
    model: {
      type: Number,
      default: 0,
      required: true
    },
    maxGrade: {
      type: Number,
      required: true
    },
    icon: {
      type: String,
      default: 'grade'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      mouseModel: 0
    };
  },

  methods: {
    set: function set(value) {
      if (!this.disable) {
        this.model = this.normalize(value);
      }
    },
    setHoverValue: function setHoverValue(value) {
      if (!this.disable) {
        this.mouseModel = value;
      }
    },
    normalize: function normalize(value) {
      return Math.min(this.maxGrade, Math.max(1, value));
    }
  }
};

var Search = { template: "<div class=\"quasar-search\" :class=\"{'quasar-search-centered': !this.focused && this.model === '', disabled: disable}\"><div class=\"quasar-search-input-container\"><button class=\"quasar-search-icon\"><i>{{ icon }}</i></button> <input type=\"text\" class=\"quasar-search-input no-style\" :placeholder=\"placeholder\" v-model=\"model\" :debounce=\"debounce\" @focus=\"focused = true\" @blur=\"focused = false\" v-attr=\"attrib\"> <button class=\"quasar-search-clear\" @click=\"clear()\" :class=\"{hidden: this.model === ''}\"><i class=\"mat-only\">clear</i> <i class=\"ios-only\">cancel</i></button></div></div>",
  props: {
    model: {
      type: String,
      default: ''
    },
    debounce: {
      type: Number,
      default: 300
    },
    icon: {
      type: String,
      default: 'search'
    },
    placeholder: {
      type: String,
      default: 'Search'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      focused: false
    };
  },

  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  },
  methods: {
    clear: function clear() {
      if (!this.disable) {
        this.model = '';
      }
    }
  }
};

var Select = { template: "<div class=\"quasar-select-container\"><quasar-popover v-ref:popover :disable=\"disable\" cover><div slot=\"target\" class=\"cursor-pointer textfield\" @click=\"__parseOptions\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div><div class=\"list highlight\"><label v-if=\"type === 'radio'\" v-for=\"radio in options\" class=\"item\" @click=\"close\"><div class=\"item-primary\"><quasar-radio :model.sync=\"model\" :value.once=\"radio.value\"></quasar-radio></div><div class=\"item-content\">{{{* radio.label}}}</div></label><button v-if=\"type === 'checkbox' || type === 'toggle'\" class=\"primary clear small full-width\" @click=\"$refs.popover.close()\">Close</button><label v-if=\"type === 'checkbox'\" v-for=\"checkbox in options\" class=\"item\"><div class=\"item-primary\"><quasar-checkbox :model.sync=\"multipleOptions[$index]\"></quasar-checkbox></div><div class=\"item-content\">{{{* checkbox.label}}}</div></label><label v-if=\"type === 'toggle'\" v-for=\"toggle in options\" class=\"item\"><div class=\"item-content has-secondary\">{{{* toggle.label}}}</div><div class=\"item-secondary\"><quasar-toggle :model.sync=\"multipleOptions[$index]\"></quasar-toggle></div></label></div></quasar-popover></div>",
  data: function data() {
    return {
      multipleOptions: [],
      skipModelUpdate: false
    };
  },

  props: {
    model: {
      required: true,
      twoWay: true
    },
    options: {
      type: Array,
      required: true,
      validator: function validator(options) {
        return !options.some(function (option) {
          return typeof option.label === 'undefined' || typeof option.value === 'undefined';
        });
      }
    },
    type: {
      type: String,
      required: true,
      validator: function validator(value) {
        return ['radio', 'checkbox', 'toggle'].includes(value);
      }
    },
    placeholder: String,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label: function label() {
      return this.placeholder || (this.type === 'radio' ? this.__getSingleLabel() : this.__getMultipleLabel());
    },
    multiple: function multiple() {
      return this.type !== 'radio';
    }
  },
  watch: {
    multipleOptions: {
      deep: true,
      handler: function handler(options) {
        var _this = this;

        if (!this.multiple || this.skipModelUpdate) {
          this.skipModelUpdate = false;
          return;
        }

        var index = 0;
        var model = [];

        options.forEach(function (option) {
          if (option) {
            model.push(_this.options[index].value);
          }
          index++;
        });

        this.model = model;
      }
    }
  },
  methods: {
    __getSingleLabel: function __getSingleLabel() {
      var _this2 = this;

      var option = this.options.find(function (option) {
        return option.value === _this2.model;
      });
      return option ? option.label : 'Select';
    },
    __getMultipleLabel: function __getMultipleLabel() {
      var _this3 = this;

      var options = this.options.filter(function (option) {
        return _this3.model.includes(option.value);
      }).map(function (option) {
        return option.label;
      });

      if (options.length === 0) {
        return 'Select';
      } else if (options.length > 1) {
        return options[0] + ' and ' + (options.length - 1) + ' more';
      }
      return options[0];
    },
    __parseOptions: function __parseOptions() {
      var _this4 = this;

      if (!Array.isArray(this.options)) {
        throw new Error('Select options parameter must be an array.');
      }
      if (this.options.some(function (option) {
        return typeof option.label === 'undefined' || typeof option.value === 'undefined';
      })) {
        throw new Error('One of Select\'s option is missing either label or value');
      }

      if (this.multiple) {
        this.skipModelUpdate = true;
        this.multipleOptions = this.options.map(function (option) {
          return _this4.model.includes(option.value) || false;
        });
      }
    },
    open: function open(event) {
      if (this.disable) {
        return;
      }
      this.parseOptions();
      this.$refs.popover.open(event);
    },
    close: function close(event) {
      this.$refs.popover.close(event);
    }
  }
};

var mapTypeConfig = {
  radio: 'radios',
  checkbox: 'checkboxes',
  toggle: 'toggles'
};

var DialogSelect = { template: "<div class=\"quasar-select cursor-pointer textfield\" @click=\"pick\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div>",
  props: {
    model: {
      required: true,
      twoWay: true
    },
    options: {
      type: Array,
      required: true,
      validator: function validator(options) {
        return !options.some(function (option) {
          return typeof option.label === 'undefined' || typeof option.value === 'undefined';
        });
      }
    },
    type: {
      type: String,
      required: true,
      validator: function validator(value) {
        return ['radio', 'checkbox', 'toggle'].includes(value);
      }
    },
    okLabel: {
      type: String,
      default: 'OK'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    title: {
      type: String,
      default: 'Select'
    },
    message: String,
    placeholder: String,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label: function label() {
      return this.placeholder || (this.type === 'radio' ? this.__getSingleLabel() : this.__getMultipleLabel());
    }
  },
  methods: {
    __getSingleLabel: function __getSingleLabel() {
      var _this = this;

      var option = this.options.find(function (option) {
        return option.value === _this.model;
      });
      return option ? option.label : 'Select';
    },
    __getMultipleLabel: function __getMultipleLabel() {
      var _this2 = this;

      var options = this.options.filter(function (option) {
        return _this2.model.includes(option.value);
      }).map(function (option) {
        return option.label;
      });

      if (options.length === 0) {
        return 'Select';
      } else if (options.length > 1) {
        return options[0] + ' and ' + (options.length - 1) + ' more';
      }
      return options[0];
    },
    mapSingle: function mapSingle(option) {
      option.selected = option.value === this.model;
      return option;
    },
    mapMultiple: function mapMultiple(option) {
      option.checked = this.model.includes(option.value);
      return option;
    },
    pick: function pick() {
      if (this.disable) {
        return;
      }

      var self = this,
          mapHandler = this.type === 'radio' ? this.mapSingle : this.mapMultiple,
          options = this.options.map(mapHandler.bind(this)),
          config = {
        title: self.title,
        message: self.message,
        buttons: [self.cancelLabel, {
          label: self.okLabel,
          handler: function handler(data) {
            self.model = data;
          }
        }]
      };

      config[mapTypeConfig[this.type]] = options;

      Dialog.create(config).show();
    }
  }
};

var Slider = { template: "<div class=\"quasar-slider\" :class=\"{fullscreen: inFullscreen}\"><div class=\"quasar-slider-inner\"><div v-el:track class=\"quasar-slider-track\" :class=\"{'with-arrows': arrows, 'with-toolbar': toolbar}\" v-touch:pan=\"pan\" v-touch-options:pan=\"{ direction: 'horizontal' }\"><slot name=\"slide\"></slot></div><div v-if=\"arrows\" class=\"quasar-slider-left-button row items-center justify-center\" :class=\"{hidden: slide === 0}\"><i @click=\"goToSlide(slide - 1)\">keyboard_arrow_left</i></div><div v-if=\"arrows\" class=\"quasar-slider-right-button row items-center justify-center\" :class=\"{hidden: slide === slidesNumber - 1}\" @click=\"goToSlide(slide + 1)\"><i>keyboard_arrow_right</i></div><div v-if=\"toolbar\" class=\"quasar-slider-toolbar row items-center justify-end\"><div class=\"quasar-slider-dots auto row items-center justify-center\"><i v-if=\"dots\" v-for=\"n in slidesNumber\" @click=\"goToSlide(n)\"><span v-show=\"n !== slide\">panorama_fish_eye</span> <span v-else>lens</span></i></div><div class=\"row items-center\"><slot name=\"action\"></slot><i v-if=\"fullscreen\" @click=\"toggleFullscreen()\"><span v-show=\"!inFullscreen\">fullscreen</span> <span v-else>fullscreen_exit</span></i></div></div><slot></slot></div></div>",
  props: {
    arrows: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    dots: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    fullscreen: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    actions: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data: function data() {
    return {
      position: 0,
      slide: 0,
      slidesNumber: 0,
      inFullscreen: false
    };
  },

  computed: {
    toolbar: function toolbar() {
      return this.dots || this.fullscreen || this.actions;
    }
  },
  methods: {
    pan: function pan(event) {
      if (!this.hasOwnProperty('initialPosition')) {
        this.initialPosition = this.position;
        Velocity(this.$els.track, 'stop');
      }

      var delta = event.deltaX;

      if (this.slide === 0 && event.deltaX > 0 || this.slide === this.slidesNumber - 1 && event.deltaX < 0) {
        delta = delta / 10;
      }

      this.position = this.initialPosition + delta / this.$els.track.offsetWidth * 100;
      this.$els.track.style.transform = 'translateX(' + this.position + '%)';

      if (event.isFinal) {
        if (event.distance < 100) {
          this.goToSlide(this.slide);
        } else {
          this.goToSlide(event.deltaX < 0 ? this.slide + 1 : this.slide - 1);
        }
        delete this.initialPosition;
      }
    },
    goToSlide: function goToSlide(slide, noAnimation) {
      this.slide = Math.min(this.slidesNumber - 1, Math.max(0, slide));

      Velocity(this.$els.track, 'stop');
      Velocity(this.$els.track, {
        translateX: [-this.slide * 100 + '%', this.position + '%']
      }, noAnimation ? { duration: 0 } : undefined);

      this.position = -this.slide * 100;
    },
    toggleFullscreen: function toggleFullscreen() {
      if (this.inFullscreen) {
        if (Platform.within.iframe) {
          this.inFullscreen = false;
        } else {
          window.history.go(-1);
        }
        return;
      }

      this.inFullscreen = true;
      if (!Platform.within.iframe) {
        window.history.pushState({}, '');
        window.addEventListener('popstate', this.__popState);
      }
    },
    __popState: function __popState() {
      if (this.inFullscreen) {
        this.inFullscreen = false;
      }
      window.removeEventListener('popstate', this.__popState);
    }
  },
  ready: function ready() {
    this.slidesNumber = this.$els.track.children.length;
  }
};

var audio = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 55 80\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"matrix(1 0 0 -1 0 80)\"><rect width=\"10\" height=\"20\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"4.3s\" values=\"20;45;57;80;64;32;66;45;64;23;66;13;64;56;34;34;2;23;76;79;20\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"15\" width=\"10\" height=\"80\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"80;55;33;5;75;23;73;33;12;14;60;80\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" width=\"10\" height=\"50\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1.4s\" values=\"50;34;78;23;56;23;34;76;80;54;21;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"45\" width=\"10\" height=\"30\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"30;45;13;80;56;72;45;76;34;23;67;30\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></g></svg>\n";

var ball = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 57 57\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle cx=\"5\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;5;50;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" values=\"5;27;49;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"27\" cy=\"5\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" from=\"5\" to=\"5\" values=\"5;50;50;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" from=\"27\" to=\"27\" values=\"27;49;5;27\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"49\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;50;5;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" from=\"49\" to=\"49\" begin=\"0s\" dur=\"2.2s\" values=\"49;5;27;49\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var bars = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 140\" xmlns=\"http://www.w3.org/2000/svg\"><rect y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"60\" width=\"15\" height=\"140\" rx=\"6\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"90\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"120\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></svg>\n";

var circles = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 135\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M67.447 58c5.523 0 10-4.477 10-10s-4.477-10-10-10-10 4.477-10 10 4.477 10 10 10zm9.448 9.447c0 5.523 4.477 10 10 10 5.522 0 10-4.477 10-10s-4.478-10-10-10c-5.523 0-10 4.477-10 10zm-9.448 9.448c-5.523 0-10 4.477-10 10 0 5.522 4.477 10 10 10s10-4.478 10-10c0-5.523-4.477-10-10-10zM58 67.447c0-5.523-4.477-10-10-10s-10 4.477-10 10 4.477 10 10 10 10-4.477 10-10z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"-360 67 67\" dur=\"2.5s\" repeatCount=\"indefinite\"/></path><path d=\"M28.19 40.31c6.627 0 12-5.374 12-12 0-6.628-5.373-12-12-12-6.628 0-12 5.372-12 12 0 6.626 5.372 12 12 12zm30.72-19.825c4.686 4.687 12.284 4.687 16.97 0 4.686-4.686 4.686-12.284 0-16.97-4.686-4.687-12.284-4.687-16.97 0-4.687 4.686-4.687 12.284 0 16.97zm35.74 7.705c0 6.627 5.37 12 12 12 6.626 0 12-5.373 12-12 0-6.628-5.374-12-12-12-6.63 0-12 5.372-12 12zm19.822 30.72c-4.686 4.686-4.686 12.284 0 16.97 4.687 4.686 12.285 4.686 16.97 0 4.687-4.686 4.687-12.284 0-16.97-4.685-4.687-12.283-4.687-16.97 0zm-7.704 35.74c-6.627 0-12 5.37-12 12 0 6.626 5.373 12 12 12s12-5.374 12-12c0-6.63-5.373-12-12-12zm-30.72 19.822c-4.686-4.686-12.284-4.686-16.97 0-4.686 4.687-4.686 12.285 0 16.97 4.686 4.687 12.284 4.687 16.97 0 4.687-4.685 4.687-12.283 0-16.97zm-35.74-7.704c0-6.627-5.372-12-12-12-6.626 0-12 5.373-12 12s5.374 12 12 12c6.628 0 12-5.373 12-12zm-19.823-30.72c4.687-4.686 4.687-12.284 0-16.97-4.686-4.686-12.284-4.686-16.97 0-4.687 4.686-4.687 12.284 0 16.97 4.686 4.687 12.284 4.687 16.97 0z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"360 67 67\" dur=\"8s\" repeatCount=\"indefinite\"/></path></svg>\n";

var dots = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 120 30\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"15\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"60\" cy=\"15\" r=\"9\" fill-opacity=\".3\"><animate attributeName=\"r\" from=\"9\" to=\"9\" begin=\"0s\" dur=\"0.8s\" values=\"9;15;9\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\".5\" to=\".5\" begin=\"0s\" dur=\"0.8s\" values=\".5;1;.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"105\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

var facebook = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" xmlns=\"http://www.w3.org/2000/svg\" preserveAspectRatio=\"xMidYMid\"><g transform=\"translate(20 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.6\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(50 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.8\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.1s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(80 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.9\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.2s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g></svg>\n";

var gears = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(-20,-20)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"90 50 50\" to=\"0 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g><g transform=\"translate(20,20) rotate(15 50 50)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"90 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g></svg>\n";

var grid = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 105 105\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"12.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"52.5\" r=\"12.5\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"100ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"300ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"600ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"800ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"400ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"700ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"500ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"200ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

var hearts = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 140 64\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M30.262 57.02L7.195 40.723c-5.84-3.976-7.56-12.06-3.842-18.063 3.715-6 11.467-7.65 17.306-3.68l4.52 3.76 2.6-5.274c3.716-6.002 11.47-7.65 17.304-3.68 5.84 3.97 7.56 12.054 3.842 18.062L34.49 56.118c-.897 1.512-2.793 1.915-4.228.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M105.512 56.12l-14.44-24.272c-3.716-6.008-1.996-14.093 3.843-18.062 5.835-3.97 13.588-2.322 17.306 3.68l2.6 5.274 4.52-3.76c5.84-3.97 13.593-2.32 17.308 3.68 3.718 6.003 1.998 14.088-3.842 18.064L109.74 57.02c-1.434 1.014-3.33.61-4.228-.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0.7s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M67.408 57.834l-23.01-24.98c-5.864-6.15-5.864-16.108 0-22.248 5.86-6.14 15.37-6.14 21.234 0L70 16.168l4.368-5.562c5.863-6.14 15.375-6.14 21.235 0 5.863 6.14 5.863 16.098 0 22.247l-23.007 24.98c-1.43 1.556-3.757 1.556-5.188 0z\"/></svg>\n";

var hourglass = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\"  viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g><path fill=\"none\" :stroke=\"color\" stroke-width=\"5\" stroke-miterlimit=\"10\" d=\"M58.4,51.7c-0.9-0.9-1.4-2-1.4-2.3s0.5-0.4,1.4-1.4 C70.8,43.8,79.8,30.5,80,15.5H70H30H20c0.2,15,9.2,28.1,21.6,32.3c0.9,0.9,1.4,1.2,1.4,1.5s-0.5,1.6-1.4,2.5 C29.2,56.1,20.2,69.5,20,85.5h10h40h10C79.8,69.5,70.8,55.9,58.4,51.7z\" class=\"glass\"></path><clipPath id=\"uil-hourglass-clip1\"><rect x=\"15\" y=\"20\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"25\" to=\"0\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"25;0;0\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"20\" to=\"45\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"20;45;45\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><clipPath id=\"uil-hourglass-clip2\"><rect x=\"15\" y=\"55\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"0\" to=\"25\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"0;25;25\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"80\" to=\"55\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"80;55;55\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><path d=\"M29,23c3.1,11.4,11.3,19.5,21,19.5S67.9,34.4,71,23H29z\" clip-path=\"url(#uil-hourglass-clip1)\" :fill=\"color\" class=\"sand\"></path><path d=\"M71.6,78c-3-11.6-11.5-20-21.5-20s-18.5,8.4-21.5,20H71.6z\" clip-path=\"url(#uil-hourglass-clip2)\" :fill=\"color\" class=\"sand\"></path><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"180 50 50\" repeatCount=\"indefinite\" dur=\"1s\" values=\"0 50 50;0 50 50;180 50 50\" keyTimes=\"0;0.7;1\"></animateTransform></g></svg>\n";

var infinity = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\"><path d=\"M24.3,30C11.4,30,5,43.3,5,50s6.4,20,19.3,20c19.3,0,32.1-40,51.4-40C88.6,30,95,43.3,95,50s-6.4,20-19.3,20C56.4,70,43.6,30,24.3,30z\" fill=\"none\" :stroke=\"color\" stroke-width=\"8\" stroke-dasharray='10.691205342610678 10.691205342610678' stroke-dashoffset=\"0\"><animate attributeName=\"stroke-dashoffset\" from=\"0\" to=\"21.382410685221355\" begin=\"0\" dur=\"2s\" repeatCount=\"indefinite\" fill=\"freeze\"></animate></path></svg>\n";

var ios = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(0 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(30 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.08333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(60 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.16666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(90 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.25s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(120 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.3333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(150 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.4166666666666667s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(180 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(210 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5833333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(240 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.6666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(270 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.75s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(300 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.8333333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(330 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.9166666666666666s' repeatCount='indefinite'/></rect></svg>\n";

var oval = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle stroke-opacity=\".5\" cx=\"18\" cy=\"18\" r=\"18\"/><path d=\"M36 18c0-9.94-8.06-18-18-18\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"1s\" repeatCount=\"indefinite\"/></path></g></svg>\n";

var pie = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M0 50A50 50 0 0 1 50 0L50 50L0 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"0.8s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 0A50 50 0 0 1 100 50L50 50L50 0\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"1.6s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M100 50A50 50 0 0 1 50 100L50 50L100 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"2.4s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 100A50 50 0 0 1 0 50L50 50L50 100\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"3.2s\" repeatCount=\"indefinite\"></animateTransform></path></svg>\n";

var puff = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 44 44\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"0s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var radio = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"scale(0.55)\"><circle cx=\"30\" cy=\"150\" r=\"30\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></circle><path d=\"M90,150h30c0-49.7-40.3-90-90-90v30C63.1,90,90,116.9,90,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.1\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path><path d=\"M150,150h30C180,67.2,112.8,0,30,0v30C96.3,30,150,83.7,150,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.2\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path></g></svg>\n";

var rings = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 45 45\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(1 1)\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"1.5s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"1.5s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"1.5s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"3s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"3s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"3s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"8\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.5s\" values=\"6;1;2;3;4;5;6\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var tail = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><defs><linearGradient x1=\"8.042%\" y1=\"0%\" x2=\"65.682%\" y2=\"23.865%\" id=\"a\"><stop :stop-color=\"color\" stop-opacity=\"0\" offset=\"0%\"/><stop :stop-color=\"color\" stop-opacity=\".631\" offset=\"63.146%\"/><stop :stop-color=\"color\" offset=\"100%\"/></linearGradient></defs><g transform=\"translate(1 1)\" fill=\"none\" fill-rule=\"evenodd\"><path d=\"M36 18c0-9.94-8.06-18-18-18\" stroke=\"url(#a)\" stroke-width=\"2\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></path><circle :fill=\"color\" cx=\"36\" cy=\"18\" r=\"1\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var templates = {
  audio: audio,
  ball: ball,
  bars: bars,
  circles: circles,
  dots: dots,
  facebook: facebook,
  gears: gears,
  grid: grid,
  hearts: hearts,
  hourglass: hourglass,
  infinity: infinity,
  ios: ios,
  oval: oval,
  pie: pie,
  puff: puff,
  radio: radio,
  rings: rings,
  tail: tail
};

var registerSpinners = (function (_Vue) {
  Object.keys(templates).forEach(function (spinner) {
    _Vue.partial('quasar-partial-' + spinner, templates[spinner]);
  });

  _Vue.component('spinner', {
    template: '<span><partial :name="partialName"></partial></span>',
    props: {
      name: {
        type: String,
        default: current === 'ios' ? 'ios' : 'tail'
      },
      size: {
        type: Number,
        default: 64
      },
      color: {
        type: String,
        default: '#000'
      }
    },
    computed: {
      partialName: function partialName() {
        return 'quasar-partial-' + this.name;
      }
    }
  });
});

var State = { template: "<span><slot v-if=\"!model\"></slot><slot v-else name=\"active\"></slot></span>",
  props: {
    model: {
      type: Boolean,
      required: true,
      twoWay: true
    }
  }
};

var Stepper = { template: "<div class=\"quasar-stepper timeline primary\"><slot></slot></div>",
  events: {
    'stepper::reset': function stepperReset() {
      this.redraw();
    },
    'stepper::nextStep': function stepperNextStep() {
      this.nextStep();
    },
    'stepper::previousStep': function stepperPreviousStep() {
      this.previousStep();
    },
    'stepper::finish': function stepperFinish() {
      this.finish();
    }
  },
  data: function data() {
    return {
      config: {
        steps: 0,
        currentStep: 0
      }
    };
  },

  methods: {
    reset: function reset() {
      this.redraw();
      this.config.currentStep = 1;
    },
    nextStep: function nextStep() {
      this.config.currentStep++;
      if (this.config.currentStep > this.config.steps) {
        this.$emit('finish');
      }
    },
    previousStep: function previousStep() {
      this.config.currentStep--;
    },
    finish: function finish() {
      this.config.currentStep = this.config.steps + 1;
      this.$emit('finish');
    },
    redraw: function redraw() {
      var _this = this;

      var step = 1;

      this.config.currentStep = this.config.currentStep || 1;
      this.config.steps = this.$children.length;
      this.$children.forEach(function (child) {
        child.$set('stepper', _this.config);
        child.step = step;
        step++;
      });
    }
  },
  beforeCompile: function beforeCompile() {
    this.reset = Utils.debounce(this.reset, 50);
  }
};

var Step = { template: "<div class=\"timeline-item\" :class=\"{incomplete: step > stepper.currentStep}\"><div class=\"timeline-badge\"><i v-if=\"step < stepper.currentStep\">done </i><span v-else>{{ step }}</span></div><div class=\"timeline-title text-bold\">{{{ title }}}</div><div class=\"timeline-content\" v-show=\"stepper && step === stepper.currentStep\" transition=\"slide\"><slot></slot><div class=\"group\" style=\"margin-top: 1rem; margin-left: -5px\"><button class=\"primary\" :class=\"{disabled: !ready}\" @click=\"nextStep()\">{{ stepper && step === stepper.steps ? 'Finish' : 'Continue' }}</button> <button class=\"primary clear\" v-if=\"step > 1\" @click=\"previousStep()\">Back</button></div></div></div>",
  props: {
    title: {
      type: String,
      required: true
    },
    ready: {
      type: Boolean,
      default: true
    }
  },
  data: function data() {
    return {
      step: 0,
      stepper: {}
    };
  },

  watch: {
    visible: function visible() {
      this.__notify('reset');
    },
    disabled: function disabled() {
      this.__notify('reset');
    }
  },
  methods: {
    nextStep: function nextStep() {
      if (this.ready) {
        this.__notify('nextStep');
      }
    },
    previousStep: function previousStep() {
      this.__notify('previousStep');
    },
    finish: function finish() {
      this.__notify('finish');
    },
    __notify: function __notify(event) {
      this.$dispatch('stepper::' + event);
    }
  },
  ready: function ready() {
    this.__notify('reset');
  },
  destroyed: function destroyed() {
    this.__notify('reset');
  }
};

var Tab = { template: "<div class=\"quasar-tab items-center justify-center\" :class=\"{'v-link-active': active, hidden: hidden, disabled: disable, hideIcon: hide === 'icon', hideLabel: hide === 'label'}\" @click=\"activate()\"><i v-if=\"icon\" class=\"quasar-tabs-icon\">{{icon}}</i> <span class=\"quasar-tab-label\"><slot></slot></span></div>",
  props: ['active', 'hidden', 'disable', 'hide', 'icon', 'label', 'target'],
  methods: {
    activate: function activate() {
      if (this.disable) {
        return;
      }
      this.active = true;
    },
    setTargetVisibility: function setTargetVisibility(visible) {
      if (this.targetElement) {
        this.targetElement.style.display = visible ? '' : 'none';
      }
    }
  },
  computed: {
    targetElement: function targetElement() {
      if (!this.target) {
        return;
      }

      return document.querySelector(this.target);
    }
  },
  events: {
    tabSelected: function tabSelected(tab) {
      var targetIsMe = tab === this;

      if (!targetIsMe) {
        this.active = false;
      }

      this.setTargetVisibility(tab === this);
    }
  },
  watch: {
    active: function active(value) {
      if (this.disable) {
        return;
      }
      if (value) {
        this.$dispatch('selected', this);
      }
    },
    hidden: function hidden(value) {
      this.$dispatch('hidden');
    },
    target: function target(value, oldValue) {
      var _this = this;

      if (oldValue) {
        var oldTab = document.querySelector(oldValue);
        if (oldTab) {
          oldTab.style.display = 'none';
        }
      }
      this.$nextTick(function () {
        _this.setTargetVisibility(_this.active);
      });
    },
    '$route': function $route(value) {
      var _this2 = this;

      this.$nextTick(function () {
        if (_this2.$el.classList.contains('v-link-active')) {
          _this2.$dispatch('selected', _this2);
        }
      });
    }
  },
  ready: function ready() {
    var _this3 = this;

    if (this.active && this.target || this.$el.classList.contains('v-link-active')) {
      this.$nextTick(function () {
        _this3.$dispatch('selected', _this3);
      });
    } else {
      this.setTargetVisibility(false);
    }
  }
};

var scrollNavigationSpeed = 5;
var debounceDelay = 50;

var Tabs = { template: "<div class=\"quasar-tabs row\"><div v-el:left-scroll class=\"row items-center justify-center left-scroll\"><i>chevron_left</i></div><div v-el:scroller class=\"quasar-tabs-scroller row\"><slot></slot></div><div v-el:right-scroll class=\"row items-center justify-center right-scroll\"><i>chevron_right</i></div></div>",
  methods: {
    redraw: function redraw() {
      if (!Platform.is.desktop) {
        return;
      }
      if (Utils.dom.width(this.$els.scroller) === 0 && this.$els.scroller.scrollWidth === 0) {
        return;
      }
      if (Utils.dom.width(this.$els.scroller) + 5 < this.$els.scroller.scrollWidth) {
        this.$el.classList.add('scrollable');
        this.scrollable = true;
        this.updateScrollIndicator();
      } else {
        this.$el.classList.remove('scrollable');
        this.scrollable = false;
      }
    },
    updateScrollIndicator: function updateScrollIndicator() {
      if (!Platform.is.desktop || !this.scrollable) {
        return;
      }

      var action = this.$els.scroller.scrollLeft + Utils.dom.width(this.$els.scroller) + 5 >= this.$els.scroller.scrollWidth ? 'add' : 'remove';

      this.$els.leftScroll.classList[this.$els.scroller.scrollLeft <= 0 ? 'add' : 'remove']('disabled');
      this.$els.rightScroll.classList[action]('disabled');
    },
    scrollToSelectedIfNeeded: function scrollToSelectedIfNeeded(tab) {
      if (tab.length === 0 || !this.scrollable) {
        return;
      }

      var contentRect = this.$els.scroller.getBoundingClientRect(),
          tabRect = tab.getBoundingClientRect(),
          tabWidth = tabRect.width,
          offset = tabRect.left - contentRect.left;

      if (offset < 0) {
        this.animScrollTo(this.$els.scroller.scrollLeft + offset);
      } else {
        offset += tabWidth - this.$els.scroller.offsetWidth;

        if (offset > 0) {
          this.animScrollTo(this.$els.scroller.scrollLeft + offset);
        }
      }
    },
    animScrollTo: function animScrollTo(value) {
      var _this = this;

      if (this.scrollTimer) {
        clearInterval(this.scrollTimer);
      }

      this.scrollTowards(value);
      this.scrollTimer = setInterval(function () {
        if (_this.scrollTowards(value)) {
          clearInterval(_this.scrollTimer);
        }
      }, 5);
    },
    scrollTowards: function scrollTowards(value) {
      var scrollPosition = this.$els.scroller.scrollLeft,
          direction = value < scrollPosition ? -1 : 1,
          done = false;

      scrollPosition += direction * scrollNavigationSpeed;

      if (scrollPosition < 0) {
        done = true;
        scrollPosition = 0;
      } else if (direction === -1 && scrollPosition <= value || direction === 1 && scrollPosition >= value) {
        done = true;
        scrollPosition = value;
      }

      this.$els.scroller.scrollLeft = scrollPosition;
      return done;
    }
  },
  events: {
    selected: function selected(tab) {
      var _this2 = this;

      this.$broadcast('tabSelected', tab);

      setTimeout(function () {
        _this2.scrollToSelectedIfNeeded(tab.$el);
      }, debounceDelay * 4);
    },
    hidden: function hidden() {
      this.redraw();
    }
  },
  watch: {
    '$children': function $children() {
      this.redraw();
    }
  },
  ready: function ready() {
    var _this3 = this;

    this.scrollTimer = null;
    this.scrollable = !Platform.is.desktop;

    this.redraw = Utils.debounce(this.redraw, debounceDelay);
    this.updateScrollIndicator = Utils.debounce(this.updateScrollIndicator, debounceDelay);

    this.$els.scroller.addEventListener('scroll', this.updateScrollIndicator);
    window.addEventListener('resize', this.redraw);

    setTimeout(function () {
      _this3.redraw();
    }, debounceDelay);

    if (Platform.is.desktop) {
      var scrollEvents = {
        start: [],
        stop: []
      };

      scrollEvents.start.push('mousedown');
      scrollEvents.stop.push('mouseup');

      if (Platform.has.touch) {
        scrollEvents.start.push('touchstart');
        scrollEvents.stop.push('touchend');
      }

      scrollEvents.start.forEach(function (evt) {
        _this3.$els.leftScroll.addEventListener(evt, function () {
          _this3.animScrollTo(0);
        });
        _this3.$els.rightScroll.addEventListener(evt, function () {
          _this3.animScrollTo(9999);
        });
      });
      scrollEvents.stop.forEach(function (evt) {
        _this3.$els.leftScroll.addEventListener(evt, function () {
          clearInterval(_this3.scrollTimer);
        });
        _this3.$els.rightScroll.addEventListener(evt, function () {
          clearInterval(_this3.scrollTimer);
        });
      });
    }
  },
  beforeDestroy: function beforeDestroy() {
    if (this.scrollTimer) {
      clearInterval(this.scrollTimer);
    }
    this.$els.scroller.removeEventListener('scroll', this.updateScrollIndicator);
    window.removeEventListener('resize', this.redraw);
  }
};

var Toggle = { template: "<label class=\"quasar-toggle\" :class=\"{disabled: disable}\" v-touch:pan=\"toggle\" v-touch-options:pan=\"{ direction: 'horizontal' }\"><input type=\"checkbox\" v-model=\"model\" v-attr=\"attrib\"><div></div><i v-if=\"icon\">{{ icon }}</i></label>",
  props: {
    model: {
      type: Boolean,
      twoWay: true,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    icon: String
  },
  computed: {
    attrib: function attrib() {
      return this.disable ? 'disabled' : [];
    }
  },
  methods: {
    toggle: function toggle(event) {
      if (!this.disable && event.isFinal && (this.model && event.deltaX < 0 || !this.model && event.deltaX > 0)) {
        this.model = !this.model;
      }
    }
  }
};

var Tree = { template: "<div class=\"quasar-tree\"><ul><quasar-tree-item v-for=\"item in model\" :model=\"item\" :contract-html=\"contractHtml\" :expand-html=\"expandHtml\"></quasar-tree-item></ul></div>",
  props: {
    model: {
      type: Array,
      required: true
    },
    contractHtml: {
      type: String,
      required: true
    },
    expandHtml: {
      type: String,
      required: true
    }
  }
};

var TreeItem = { template: "<li class=\"quasar-tree-item\"><div :class=\"{'quasar-tree-expandable-item': isExpandable, 'quasar-tree-link': model.handler}\" @click=\"toggle\"><i v-if=\"model.icon\">{{model.icon}}</i> <span class=\"quasar-tree-label\">{{model.title}}</span> <span v-if=\"isExpandable\">{{{model.expanded ? contractHtml : expandHtml}}}</span></div><ul v-show=\"model.expanded\" v-if=\"isExpandable\" transition=\"slide\"><quasar-tree-item v-for=\"item in model.children\" :model=\"item\" :contract-html=\"contractHtml\" :expand-html=\"expandHtml\"></quasar-tree-item></ul></li>",
  props: ['model', 'contract-html', 'expand-html'],
  methods: {
    toggle: function toggle() {
      if (this.isExpandable) {
        this.model.expanded = !this.model.expanded;
        return;
      }

      if (typeof this.model.handler === 'function') {
        this.model.handler(this.model);
      }
    }
  },
  computed: {
    isExpandable: function isExpandable() {
      return this.model.children && this.model.children.length;
    }
  }
};

var Video = { template: "<div class=\"video\"><iframe :src=\"src\" frameborder=\"0\" allowfullscreen></iframe></div>",
  props: ['src']
};

function registerTransitions(_Vue) {
  _Vue.transition('slide', transitionSlide);
}

function registerFilters(_Vue) {
  _Vue.filter('gridShowSelected', GridSelectedFilter);
}

function registerDirectives(_Vue) {
  _Vue.directive('attr', directiveAttr);
  _Vue.directive('go-back', directiveGoBack);
  _Vue.directive('scroll-fire', directiveScrollFire);
  _Vue.directive('scroll', directiveScroll);
  _Vue.directive('tooltip', directiveTooltip);
}

function registerComponents(_Vue) {
  _Vue.component('quasar-checkbox', Checkbox);
  _Vue.component('quasar-chips', Chips);
  _Vue.component('quasar-collapsible', Collapsible);
  _Vue.component('quasar-context-menu', Platform.is.desktop ? ContextMenuDesktop : ContextMenuMobile);
  _Vue.component('quasar-inline-datetime', current === 'ios' ? iOSInlineDatetime : MaterialInlineDatetime);
  _Vue.component('quasar-datetime', Platform.is.desktop && !Platform.within.iframe ? InputDatetimeDesktop : InputDatetimeMobile);
  _Vue.component('quasar-drawer', Drawer);
  _Vue.component('quasar-drawer-link', DrawerLink);
  _Vue.component('quasar-fab', Fab);
  _Vue.component('quasar-small-fab', SmallFab);
  _Vue.component('quasar-gallery', Gallery);
  _Vue.component('quasar-gallery-slider', GallerySlider);
  _Vue.component('quasar-grid', Grid);
  _Vue.component('quasar-grid-table', GridTable);
  _Vue.component('quasar-infinite-scroll', InfiniteScroll);
  _Vue.component('quasar-knob', Knob);
  _Vue.component('quasar-layout', Layout);
  _Vue.component('quasar-toolbar-title', ToolbarTitle);
  _Vue.component('quasar-modal', Modal$2);
  _Vue.component('quasar-numeric', Numeric);
  _Vue.component('quasar-pagination', Pagination);
  _Vue.component('quasar-parallax', Parallax);
  _Vue.component('quasar-popover', Popover);
  _Vue.component('quasar-progress', Progress);
  _Vue.component('quasar-progress-button', ProgressButton);
  _Vue.component('quasar-pull-to-refresh', PullToRefresh);
  _Vue.component('quasar-radio', Radio);
  _Vue.component('quasar-range', Range);
  _Vue.component('quasar-double-range', DoubleRange);
  _Vue.component('quasar-rating', Rating);
  _Vue.component('quasar-search', Search);
  _Vue.component('quasar-select', Select);
  _Vue.component('quasar-dialog-select', DialogSelect);
  _Vue.component('quasar-slider', Slider);
  _Vue.component('quasar-state', State);
  _Vue.component('quasar-stepper', Stepper);
  _Vue.component('quasar-step', Step);
  _Vue.component('quasar-tab', Tab);
  _Vue.component('quasar-tabs', Tabs);
  _Vue.component('quasar-toggle', Toggle);
  _Vue.component('quasar-tree', Tree);
  _Vue.component('quasar-tree-item', TreeItem);
  _Vue.component('quasar-video', Video);
}

var Vue;

var install = function (_Vue) {
  if (this.installed) {
    console.warn('Quasar already installed in Vue.');
    return;
  }

  Vue = _Vue;

  registerTransitions(_Vue);
  registerFilters(_Vue);
  registerDirectives(_Vue);
  registerComponents(_Vue);
  registerSpinners(_Vue);

  Events.trigger('app:vue-ready', Vue);
}

function addClass(className) {
  document.body.classList.add(className);
}

addClass(Platform.is.desktop ? 'desktop' : 'mobile');
addClass(Platform.has.touch ? 'touch' : 'no-touch');

if (Platform.within.iframe) {
  addClass('within-iframe');
}

if (Platform.is.cordova) {
  addClass('cordova');
}

var start = function () {
  var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : function () {};

  if (!current) {
    set$1(Platform.is.ios ? 'ios' : 'mat');
  }

  if (Platform.is.cordova && !Platform.within.iframe) {
    var tag = document.createElement('script');

    document.addEventListener('deviceready', callback, false);

    tag.type = 'text/javascript';
    document.body.appendChild(tag);
    tag.src = 'cordova.js';

    return;
  }

  callback();
}

var init = function (Quasar) {
  if (typeof window !== 'undefined' && window.Vue) {
    window.Quasar = Quasar;
    window.Vue.use(Quasar);
  }
}

if (!Array.prototype.includes) {
  Array.prototype.includes = function (searchElement, startFrom) {
    'use strict';

    var O = Object(this);
    var len = parseInt(O.length, 10) || 0;
    if (len === 0) {
      return false;
    }
    var n = parseInt(startFrom, 10) || 0;
    var k = void 0;
    if (n >= 0) {
      k = n;
    } else {
      k = len + n;
      if (k < 0) {
        k = 0;
      }
    }
    var currentElement = void 0;
    while (k < len) {
      currentElement = O[k];
      if (searchElement === currentElement || searchElement !== searchElement && currentElement !== currentElement) {
        return true;
      }
      k++;
    }
    return false;
  };
}

if (!String.prototype.startsWith) {
  String.prototype.startsWith = function (searchString, position) {
    position = position || 0;
    return this.substr(position, searchString.length) === searchString;
  };
}

if (!String.prototype.endsWith) {
  String.prototype.endsWith = function (searchString, position) {
    var subjectString = this.toString();

    if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
      position = subjectString.length;
    }
    position -= searchString.length;

    var lastIndex = subjectString.indexOf(searchString, position);

    return lastIndex !== -1 && lastIndex === position;
  };
}

if (typeof Element.prototype.matches !== 'function') {
  Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.mozMatchesSelector || Element.prototype.webkitMatchesSelector || function matches(selector) {
    var element = this,
        elements = (element.document || element.ownerDocument).querySelectorAll(selector),
        index = 0;

    while (elements[index] && elements[index] !== element) {
      ++index;
    }

    return Boolean(elements[index]);
  };
}

if (typeof Element.prototype.closest !== 'function') {
  Element.prototype.closest = function closest(selector) {
    var element = this;

    while (element && element.nodeType === 1) {
      if (element.matches(selector)) {
        return element;
      }

      element = element.parentNode;
    }

    return null;
  };
}

window.onerror = function (message, source, lineno, colno, error) {
  Events.trigger('app:error', {
    message: message,
    source: source,
    lineno: lineno,
    colno: colno,
    error: error
  });
};

if (Platform.has.touch) {
  FastClick.attach(document.body);
}

var matTemplate = "<div>\n  <div v-if=\"title\" class=\"modal-header\">\n    {{{* title}}}\n  </div>\n\n  <div class=\"modal-scroll\">\n    <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"cursor-pointer column inline items-center justify-center\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n        <span>{{* button.label}}</span>\n      </div>\n    </div>\n    <div v-else class=\"list no-border\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"item item-link\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\" class=\"item-primary\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"item-primary\">\n        <div class=\"item-content inset\">\n          {{* button.label}}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"list no-border\">\n    <div\n      class=\"item item-link\"\n      @click=\"close(dismissButton.handler)\"\n      :class=\"dismissButton.classes\"\n    >\n      <i v-if=\"dismissButton.icon\" class=\"item-primary\">{{* dismissButton.icon}}</i>\n      <div class=\"item-content inset\">\n        {{* dismissButton.label}}\n      </div>\n    </div>\n  </div>\n</div>\n";

var iosTemplate = "<div>\n  <div class=\"quasar-action-sheet\">\n    <div v-if=\"title\" class=\"modal-header\">\n      {{{* title}}}\n    </div>\n\n    <div class=\"modal-scroll\">\n      <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n        <div\n          v-for=\"button in buttons\"\n          class=\"cursor-pointer column inline items-center justify-center\"\n          @click=\"close(button.handler)\"\n          :class=\"button.classes\"\n        >\n          <i v-if=\"button.icon\">{{* button.icon}}</i>\n          <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n          <span>{{* button.label}}</span>\n        </div>\n      </div>\n      <div v-else class=\"list no-border\">\n        <div\n          v-for=\"button in buttons\"\n          class=\"item item-link\"\n          @click=\"close(button.handler)\"\n          :class=\"button.classes\"\n        >\n          <i v-if=\"button.icon\" class=\"item-primary\">{{* button.icon}}</i>\n          <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"item-primary\">\n          <div class=\"item-content inset\">\n            {{* button.label}}\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"quasar-action-sheet\">\n    <div\n      class=\"item item-link\"\n      @click=\"close(dismissButton.handler)\"\n      :class=\"dismissButton.classes\"\n    >\n      <div class=\"item-content row justify-center\">\n        {{* dismissButton.label}}\n      </div>\n    </div>\n  </div>\n</div>\n";

var css$2 = {
  mat: {
    maxHeight: '80vh',
    height: 'auto'
  },
  ios: {
    maxHeight: '80vh',
    height: 'auto',
    backgroundColor: 'transparent',
    boxShadow: 'none'
  }
};

function parseButtons$1(buttons) {
  if (!Array.isArray(buttons)) {
    throw new Error('Action Sheet buttons parameter must be an array.');
  }

  if (buttons.length <= 1) {
    throw new Error('Action Sheet requires at least one button');
  }

  if (buttons.some(function (button) {
    return Object(button) !== button || !button.label || !button.handler;
  })) {
    throw new Error('At least one of Action Sheet\'s button parameter is not an object or missing label and/or handler.');
  }

  return buttons.map(function (button) {
    if (button.classes) {
      if (Array.isArray(button.classes)) {
        button.classes = button.classes.split(' ');
      } else if (typeof button.classes !== 'string') {
        throw new Error('Action Sheet button "classes" parameter must be either an array or string');
      }
    }
    return button;
  });
}

var ActionSheet = {
  create: function create(data) {
    data.buttons = parseButtons$1(data.buttons);
    data.dismissButton = data.buttons.pop();

    var modal = Modal$1.create({
      template: current === 'ios' ? iosTemplate : matTemplate,
      data: data
    }).css(css$2[current]).set({
      transitionIn: { translateY: [0, '101%'] },
      transitionOut: { translateY: ['101%', 0] },
      onBackButton: data.dismissButton.handler,
      onEscapeKey: data.dismissButton.handler
    });

    modal.$el.classList.remove('items-center');
    modal.$el.classList.add('items-end');
    modal.$backdrop.addEventListener('click', function () {
      modal.close(data.dismissButton.handler);
    });

    return modal;
  }
};

var transitionDuration = 300;
var displayDuration = 2500;

function parseOptions(opts, defaults) {
  if (!opts) {
    throw new Error('Missing toast options.');
  }

  var options = Utils.extend(true, {}, defaults, typeof opts === 'string' ? { html: opts } : opts);

  if (!options.html) {
    throw new Error('Missing toast content/HTML.');
  }

  return options;
}

var Toast$1 = { template: "<div class=\"quasar-toast-container\" :class=\"{active: active}\"><div class=\"quasar-toast row no-wrap items-center non-selectable\" v-if=\"stack[0]\" :style=\"{color: stack[0].color, background: stack[0].bgColor}\" :class=\"classes\"><i v-if=\"stack[0].icon\">{{ stack[0].icon }}</i> <img v-if=\"stack[0].image\" :src=\"stack[0].image\"><div class=\"quasar-toast-message auto\">{{{ stack[0].html }}}</div><a v-if=\"stack[0].button && stack[0].button.label\" @click=\"dismiss(stack[0].button.handler)\" :style=\"{color: stack[0].button.color}\">{{ stack[0].button.label }} </a><a @click=\"dismiss()\" :style=\"{color: stack[0].button.color}\"><i>close</i></a></div></div>",
  data: function data() {
    return {
      active: false,
      inTransition: false,
      stack: [],
      timer: null,
      defaults: {
        color: 'white',
        bgColor: '#323232',
        button: {
          color: 'yellow'
        }
      }
    };
  },

  computed: {
    classes: function classes() {
      if (!this.stack.length || !this.stack[0].classes) {
        return {};
      }

      return this.stack[0].classes.split(' ');
    }
  },
  methods: {
    create: function create(options) {
      this.stack.push(parseOptions(options, this.defaults));

      if (this.active || this.inTransition) {
        return;
      }

      this.active = true;
      this.inTransition = true;

      this.__show();
    },
    __show: function __show() {
      var _this = this;

      Events.trigger('app:toast', this.stack[0].html);

      this.timer = setTimeout(function () {
        if (_this.stack.length > 0) {
          _this.dismiss();
        } else {
          _this.inTransition = false;
        }
      }, transitionDuration + (this.stack[0].timeout || displayDuration));
    },
    dismiss: function dismiss(done) {
      var _this2 = this;

      this.active = false;

      if (this.timer) {
        clearTimeout(this.timer);
        this.timer = null;
      }

      setTimeout(function () {
        if (typeof _this2.stack[0].onDismiss === 'function') {
          _this2.stack[0].onDismiss();
        }

        _this2.stack.shift();
        done && done();

        if (_this2.stack.length > 0) {
          _this2.active = true;
          _this2.__show();
          return;
        }

        _this2.inTransition = false;
      }, transitionDuration + 50);
    },
    setDefaults: function setDefaults(opts) {
      Utils.extend(true, this.defaults, opts);
    }
  }
};

var toast = void 0;
var types = [{
  name: 'positive',
  defaults: { icon: 'check', classes: 'bg-positive' }
}, {
  name: 'negative',
  defaults: { icon: 'whatshot', classes: 'bg-negative' }
}, {
  name: 'info',
  defaults: { icon: 'info', classes: 'bg-info' }
}, {
  name: 'warning',
  defaults: { icon: 'warning', classes: 'bg-warning' }
}];

Events.on('app:vue-ready', function (_Vue) {
  toast = new _Vue(Toast$1);
  toast.$mount().$appendTo(document.body);
});

function create$2(opts, defaults) {
  if (!opts) {
    throw new Error('Missing toast options.');
  }

  if (defaults) {
    opts = Utils.extend(true, typeof opts === 'string' ? { html: opts } : opts, defaults);
  }

  toast.create(opts);
}

types.forEach(function (type) {
  create$2[type.name] = function (opts) {
    return create$2(opts, type.defaults);
  };
});

var Toast = {
  create: create$2,
  setDefaults: function setDefaults(opts) {
    toast.setDefaults(opts);
  }
};

function isActive() {
  return document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
}

function request(target) {
  target = target || document.documentElement;

  if (isActive()) {
    return;
  }

  if (target.requestFullscreen) {
    target.requestFullscreen();
  } else if (target.msRequestFullscreen) {
    target.msRequestFullscreen();
  } else if (target.mozRequestFullScreen) {
    target.mozRequestFullScreen();
  } else if (target.webkitRequestFullscreen) {
    target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
  }
}

function exit() {
  if (document.exitFullscreen) {
    document.exitFullscreen();
  } else if (document.msExitFullscreen) {
    document.msExitFullscreen();
  } else if (document.mozCancelFullScreen) {
    document.mozCancelFullScreen();
  } else if (document.webkitExitFullscreen) {
    document.webkitExitFullscreen();
  }
}

function toggle$1(target) {
  if (isActive()) {
    exit();
  } else {
    request(target);
  }
}

var AppFullscreen = {
  isActive: isActive,
  request: request,
  exit: exit,
  toggle: toggle$1
};

var hidden$1 = 'hidden';
var appVisibility = 'visible';

function onchange(evt) {
  var v = 'visible',
      h = 'hidden',
      state = void 0,
      evtMap = {
    focus: v,
    focusin: v,
    pageshow: v,
    blur: h,
    focusout: h,
    pagehide: h
  };

  evt = evt || window.event;

  if (evt.type in evtMap) {
    state = evtMap[evt.type];
  } else {
    state = this[hidden$1] ? h : v;
  }

  appVisibility = state;
  Events.trigger('app:visibility', state);
}

Utils.dom.ready(function () {
  if (hidden$1 in document) {
    document.addEventListener('visibilitychange', onchange);
  } else if ((hidden$1 = 'mozHidden') in document) {
    document.addEventListener('mozvisibilitychange', onchange);
  } else if ((hidden$1 = 'webkitHidden') in document) {
    document.addEventListener('webkitvisibilitychange', onchange);
  } else if ((hidden$1 = 'msHidden') in document) {
    document.addEventListener('msvisibilitychange', onchange);
  } else if ('onfocusin' in document) {
      document.onfocusin = document.onfocusout = onchange;
    } else {
        window.onpageshow = window.onpagehide = window.onfocus = window.onblur = onchange;
      }

  if (document[hidden$1] !== undefined) {
    onchange({ type: document[hidden$1] ? 'blur' : 'focus' });
  }
});

var AppVisibility = {
  isVisible: function isVisible() {
    return appVisibility === 'visible';
  }
};

function encode(string) {
  return encodeURIComponent(string);
}

function decode(string) {
  return decodeURIComponent(string);
}

function stringifyCookieValue(value) {
  return encode(value === Object(value) ? JSON.stringify(value) : '' + value);
}

function read(string) {
  if (string === '') {
    return string;
  }

  if (string.indexOf('"') === 0) {
    string = string.slice(1, -1).replace(/\\"/g, '"').replace(/\\\\/g, '\\');
  }

  string = decode(string.replace(/\+/g, ' '));

  try {
    string = JSON.parse(string);
  } catch (e) {}

  return string;
}

function set$3(key, value) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var days = options.expires,
      time = options.expires = new Date();

  if (typeof options.expires === 'number') {
    time.setMilliseconds(time.getMilliseconds() + days * 864e+5);
  }

  document.cookie = [encode(key), '=', stringifyCookieValue(value), options.expires ? ' expires=' + options.expires.toUTCString() : '', options.path ? ' path=' + options.path : '', options.domain ? ' domain=' + options.domain : '', options.secure ? ' secure' : ''].join('');
}

function get$1(key) {
  var result = key ? undefined : {},
      cookies = document.cookie ? document.cookie.split(' ') : [],
      i = 0,
      l = cookies.length,
      parts = void 0,
      name = void 0,
      cookie = void 0;

  for (; i < l; i++) {
    parts = cookies[i].split('=');
    name = decode(parts.shift());
    cookie = parts.join('=');

    if (!key) {
      result[name] = cookie;
    } else if (key === name) {
      result = read(cookie);
      break;
    }
  }

  return result;
}

function remove$2(key, options) {
  set$3(key, '', Utils.extend(true, {}, options, {
    expires: -1
  }));
}

function has(key) {
  return get$1(key) !== undefined;
}

var Cookies = {
  get: get$1,
  set: set$3,
  has: has,
  remove: remove$2,
  all: function all() {
    return get$1();
  }
};

var vm = void 0;
var appIsInProgress = false;
var timeout = void 0;

var template$1 = '\n    <div class="quasar-loading fullscreen column items-center justify-center z-absolute">\n      <spinner :name="spinner" color="#fff" :size="80"></spinner>\n      <div v-if="message" style="margin: 40px 20px 0 20px; max-width: 450px; text-align: center; color: white; text-shadow: 0 0 7px black">{{ message }}</div>\n    </div>\n  ';

function isActive$1() {
  return appIsInProgress;
}

function show$1() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$delay = _ref.delay,
      delay = _ref$delay === undefined ? 500 : _ref$delay,
      _ref$spinner = _ref.spinner,
      spinner = _ref$spinner === undefined ? current === 'ios' ? 'ios' : 'tail' : _ref$spinner,
      _ref$message = _ref.message,
      message = _ref$message === undefined ? false : _ref$message;

  if (appIsInProgress) {
    vm.$data = { spinner: spinner, message: message };
    return;
  }

  timeout = setTimeout(function () {
    document.body.classList.add('dimmed');

    vm = new Vue({
      template: template$1,
      data: {
        spinner: spinner,
        message: message
      }
    });

    vm.$mount().$appendTo(document.body);

    timeout = null;
  }, delay);

  appIsInProgress = true;
  Events.trigger('app:loading', true);
}

function hide() {
  if (!appIsInProgress) {
    return;
  }

  if (timeout) {
    clearTimeout(timeout);
    timeout = null;
  } else {
    document.body.classList.remove('dimmed');
    vm.$destroy(true);
  }

  appIsInProgress = false;
  Events.trigger('app:loading', false);
}

var Loading = {
  isActive: isActive$1,
  show: show$1,
  hide: hide
};

function encode$1(value) {
  if (Object.prototype.toString.call(value) === '[object Date]') {
    return '__q_date|' + value.toUTCString();
  }
  if (Object.prototype.toString.call(value) === '[object RegExp]') {
    return '__q_expr|' + value.source;
  }
  if (typeof value === 'number') {
    return '__q_numb|' + value;
  }
  if (typeof value === 'boolean') {
    return '__q_bool|' + (value ? '1' : '0');
  }
  if (typeof value === 'string') {
    return '__q_strn|' + value;
  }
  if (typeof value === 'function') {
    return '__q_strn|' + value.toString();
  }
  if (value === Object(value)) {
    return '__q_objt|' + JSON.stringify(value);
  }

  return value;
}

function decode$1(value) {
  var type = void 0,
      length = void 0,
      source = void 0;

  length = value.length;
  if (length < 10) {
    return value;
  }

  type = value.substr(0, 8);
  source = value.substring(9);

  switch (type) {
    case '__q_date':
      return new Date(source);

    case '__q_expr':
      return new RegExp(source);

    case '__q_numb':
      return Number(source);

    case '__q_bool':
      return Boolean(source === '1');

    case '__q_strn':
      return '' + source;

    case '__q_objt':
      return JSON.parse(source);

    default:
      return value;
  }
}

function generateFunctions(fn) {
  return {
    local: fn('local'),
    session: fn('session')
  };
}

var hasStorageItem = generateFunctions(function (type) {
  return function (key) {
    return window[type + 'Storage'].getItem(key) !== null;
  };
});
var getStorageLength = generateFunctions(function (type) {
  return function () {
    return window[type + 'Storage'].length;
  };
});
var getStorageItem = generateFunctions(function (type) {
  var hasFn = hasStorageItem[type],
      storage = window[type + 'Storage'];

  return function (key) {
    if (hasFn(key)) {
      return decode$1(storage.getItem(key));
    }
    return null;
  };
});
var getStorageAtIndex = generateFunctions(function (type) {
  var lengthFn = getStorageLength[type],
      getItemFn = getStorageItem[type],
      storage = window[type + 'Storage'];

  return function (index) {
    if (index < lengthFn()) {
      return getItemFn(storage.key(index));
    }
  };
});
var getAllStorageItems = generateFunctions(function (type) {
  var lengthFn = getStorageLength[type],
      storage = window[type + 'Storage'],
      getItemFn = getStorageItem[type];

  return function () {
    var result = {},
        key = void 0,
        length = lengthFn();

    for (var i = 0; i < length; i++) {
      key = storage.key(i);
      result[key] = getItemFn(key);
    }

    return result;
  };
});
var setStorageItem = generateFunctions(function (type) {
  var storage = window[type + 'Storage'];
  return function (key, value) {
    storage.setItem(key, encode$1(value));
  };
});
var removeStorageItem = generateFunctions(function (type) {
  var storage = window[type + 'Storage'];
  return function (key) {
    storage.removeItem(key);
  };
});
var clearStorage = generateFunctions(function (type) {
  var storage = window[type + 'Storage'];
  return function () {
    storage.clear();
  };
});
var storageIsEmpty = generateFunctions(function (type) {
  var getLengthFn = getStorageLength[type];
  return function () {
    return getLengthFn() === 0;
  };
});

var LocalStorage = {
  has: hasStorageItem.local,
  get: {
    length: getStorageLength.local,
    item: getStorageItem.local,
    index: getStorageAtIndex.local,
    all: getAllStorageItems.local
  },
  set: setStorageItem.local,
  remove: removeStorageItem.local,
  clear: clearStorage.local,
  isEmpty: storageIsEmpty.local
};

var SessionStorage = {
  has: hasStorageItem.session,
  get: {
    length: getStorageLength.session,
    item: getStorageItem.session,
    index: getStorageAtIndex.session,
    all: getAllStorageItems.session
  },
  set: setStorageItem.session,
  remove: removeStorageItem.session,
  clear: clearStorage.session,
  isEmpty: storageIsEmpty.session
};

window.Velocity = Velocity$1;
var Quasar = {
  version: '0.7.1',
  install: install,
  start: start,
  theme: theme,

  ActionSheet: ActionSheet,
  Dialog: Dialog,
  AppFullscreen: AppFullscreen,
  AppVisibility: AppVisibility,
  Cookies: Cookies,
  Platform: Platform,
  Events: Events,
  Loading: Loading,
  Modal: Modal$1,
  Toast: Toast,
  Utils: Utils,
  LocalStorage: LocalStorage,
  SessionStorage: SessionStorage
};

init(Quasar);

module.exports = Quasar;
