/*!
 * Quasar Framework v0.7.1
 * (c) 2016 Razvan Stoenescu
 * Released under the MIT License.
 */
import Velocity$1 from 'velocity-animate';
import 'velocity-animate/velocity.ui';
import moment from 'moment';
import Hammer from 'hammerjs';
import FastClick from 'fastclick';

/* istanbul ignore next */
function getUserAgent () {
  return (navigator.userAgent || navigator.vendor || window.opera).toLowerCase()
}

/* istanbul ignore next */
function getMatch (userAgent, platformMatch) {
  var match = /(edge)\/([\w.]+)/.exec(userAgent) ||
    /(opr)[\/]([\w.]+)/.exec(userAgent) ||
    /(chrome)[\/]([\w.]+)/.exec(userAgent) ||
    /(iemobile)[\/]([\w.]+)/.exec(userAgent) ||
    /(version)(applewebkit)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) ||
    /(webkit)[\/]([\w.]+).*(version)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) ||
    /(webkit)[\/]([\w.]+)/.exec(userAgent) ||
    /(opera)(?:.*version|)[\/]([\w.]+)/.exec(userAgent) ||
    /(msie) ([\w.]+)/.exec(userAgent) ||
    userAgent.indexOf('trident') >= 0 && /(rv)(?::| )([\w.]+)/.exec(userAgent) ||
    userAgent.indexOf('compatible') < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(userAgent) ||
    []

  return {
    browser: match[5] || match[3] || match[1] || '',
    version: match[2] || match[4] || '0',
    versionNumber: match[4] || match[2] || '0',
    platform: platformMatch[0] || ''
  }
}

/* istanbul ignore next */
function getPlatformMatch (userAgent) {
  return /(ipad)/.exec(userAgent) ||
    /(ipod)/.exec(userAgent) ||
    /(windows phone)/.exec(userAgent) ||
    /(iphone)/.exec(userAgent) ||
    /(kindle)/.exec(userAgent) ||
    /(silk)/.exec(userAgent) ||
    /(android)/.exec(userAgent) ||
    /(win)/.exec(userAgent) ||
    /(mac)/.exec(userAgent) ||
    /(linux)/.exec(userAgent) ||
    /(cros)/.exec(userAgent) ||
    /(playbook)/.exec(userAgent) ||
    /(bb)/.exec(userAgent) ||
    /(blackberry)/.exec(userAgent) ||
    []
}

/* istanbul ignore next */
function getPlatform () {
  let
    userAgent = getUserAgent(),
    platformMatch = getPlatformMatch(userAgent),
    matched = getMatch(userAgent, platformMatch),
    browser = {}

  if (matched.browser) {
    browser[matched.browser] = true
    browser.version = matched.version
    browser.versionNumber = parseInt(matched.versionNumber, 10)
  }

  if (matched.platform) {
    browser[matched.platform] = true
  }

  // These are all considered mobile platforms, meaning they run a mobile browser
  if (browser.android || browser.bb || browser.blackberry || browser.ipad || browser.iphone ||
    browser.ipod || browser.kindle || browser.playbook || browser.silk || browser['windows phone']) {
    browser.mobile = true
  }

  // Set iOS if on iPod, iPad or iPhone
  if (browser.ipod || browser.ipad || browser.iphone) {
    browser.ios = true
  }

  if (browser['windows phone']) {
    browser.winphone = true
    delete browser['windows phone']
  }

  // These are all considered desktop platforms, meaning they run a desktop browser
  if (browser.cros || browser.mac || browser.linux || browser.win) {
    browser.desktop = true
  }

  // Chrome, Opera 15+ and Safari are webkit based browsers
  if (browser.chrome || browser.opr || browser.safari) {
    browser.webkit = true
  }

  // IE11 has a new token so we will assign it msie to avoid breaking changes
  if (browser.rv || browser.iemobile) {
    matched.browser = 'ie'
    browser.ie = true
  }

  // Edge is officially known as Microsoft Edge, so rewrite the key to match
  if (browser.edge) {
    matched.browser = 'edge'
    browser.edge = true
  }

  // Blackberry browsers are marked as Safari on BlackBerry
  if (browser.safari && browser.blackberry || browser.bb) {
    matched.browser = 'blackberry'
    browser.blackberry = true
  }

  // Playbook browsers are marked as Safari on Playbook
  if (browser.safari && browser.playbook) {
    matched.browser = 'playbook'
    browser.playbook = true
  }

  // Opera 15+ are identified as opr
  if (browser.opr) {
    matched.browser = 'opera'
    browser.opera = true
  }

  // Stock Android browsers are marked as Safari on Android.
  if (browser.safari && browser.android) {
    matched.browser = 'android'
    browser.android = true
  }

  // Kindle browsers are marked as Safari on Kindle
  if (browser.safari && browser.kindle) {
    matched.browser = 'kindle'
    browser.kindle = true
  }

   // Kindle Silk browsers are marked as Safari on Kindle
  if (browser.safari && browser.silk) {
    matched.browser = 'silk'
    browser.silk = true
  }

  // Assign the name and platform variable
  browser.name = matched.browser
  browser.platform = matched.platform

  if (window._cordovaNative) {
    browser.cordova = true
  }

  return browser
}

var Platform = {
  is: getPlatform(),
  has: {
    touch: (() => !!('ontouchstart' in document.documentElement) || /* istanbul ignore next */ window.navigator.msMaxTouchPoints > 0)()
  },
  within: {
    iframe: window.self !== window.top
  }
}

function parseEventNames (eventNames) {
  return eventNames.trim().replace(/\s\s+/g, ' ').split(' ')
}

function remove (events, eventName, filterFn) {
  events[eventName] = events[eventName].filter(filterFn)
  if (events[eventName].length === 0) {
    delete events[eventName]
  }
}

function on (eventNames, callback, context, once) {
  if (!eventNames) {
    throw new Error('Missing event(s) name(s)')
  }
  if (!callback) {
    throw new Error('Missing callback')
  }
  if (typeof callback !== 'function') {
    throw new Error('Callback is not a function')
  }

  parseEventNames(eventNames).forEach((eventName) => {
    if (!this.events.hasOwnProperty(eventName)) {
      this.events[eventName] = []
    }

    if (this.events[eventName].some(function (item) {
      return item.cb === callback
    })) {
      // Event name already has specified callback
      return
    }

    this.events[eventName].push({
      cb: callback,
      context: context,
      once: once
    })
  })
}

function off (eventNames, callback) {
  if (!eventNames) {
    this.events = {}
    return
  }

  if (callback && typeof callback !== 'function') {
    throw new Error('Callback is not a function')
  }

  parseEventNames(eventNames).forEach((eventName) => {
    if (!this.events.hasOwnProperty(eventName)) {
      // Unregistered event name
      return
    }

    if (!callback) {
      delete this.events[eventName]
      return
    }

    remove(this.events, eventName, function (ev) {
      return ev.cb !== callback
    })
  })
}

function once (eventNames, callback, context) {
  on.call(this, eventNames, callback, context, true)
}

function trigger (eventNames, ...args) {
  if (!eventNames) {
    eventNames = getList.call(this).join(' ')
  }

  parseEventNames(eventNames).forEach((eventName) => {
    if (!this.events.hasOwnProperty(eventName)) {
      // Nothing to trigger
      return
    }

    var onceList = []

    this.events[eventName].forEach(function (ev) {
      ev.cb.apply(ev.context, args)
      if (ev.once) {
        onceList.push(ev)
      }
    })

    remove(this.events, eventName, function (ev) {
      return !onceList.includes(ev)
    })
  })
}

function hasSubscriber (eventNames, callback) {
  if (!eventNames) {
    return Object.keys(this.events).length !== 0
  }

  if (typeof eventNames === 'function') {
    callback = eventNames
    eventNames = getList.call(this).join(' ')
  }

  if (callback && typeof callback !== 'function') {
    throw new Error('Callback is not a function')
  }

  var foundSubscriber = false

  parseEventNames(eventNames).forEach((eventName) => {
    var result = this.events.hasOwnProperty(eventName)

    if (!result) {
      return
    }

    if (callback) {
      result = this.events[eventName].some(function (item) {
        return item.cb === callback
      })

      if (result) {
        foundSubscriber = true
      }
      return
    }

    foundSubscriber = true
  })

  return foundSubscriber
}

function getList () {
  return Object.keys(this.events)
}

function createEmitter () {
  var props = {
    events: {}
  }

  return {
    on: on.bind(props),
    off: off.bind(props),
    once: once.bind(props),
    trigger: trigger.bind(props),

    hasSubscriber: hasSubscriber.bind(props),
    getList: getList.bind(props)
  }
}

var Events = createEmitter()

function set (theme) {
  if (current) {
    document.body.classList.remove(current)
  }

  current = theme
  document.body.classList.add(theme)
}

var current


var theme = Object.freeze({
	set: set,
	get current () { return current; }
});

var transitionSlide = {
  css: false,

  enter (el, done) {
    Velocity(el, 'stop')
    Velocity(el, 'slideDown', done)
  },
  enterCancelled (el) {
    Velocity(el, 'stop')
    el.removeAttribute('style')
  },

  leave (el, done) {
    Velocity(el, 'stop')
    Velocity(el, 'slideUp', done)
  },
  leaveCancelled (el) {
    Velocity(el, 'stop')
    el.removeAttribute('style')
  }
}

var GridSelectedFilter = function (data, filter, selectionMode, singleSelection) {
  if (!filter || selectionMode === 'none') {
    return data
  }

  if (selectionMode === 'single') {
    return singleSelection
  }

  return data.filter(row => row.__selected)
}

var directiveAttr = function (attribs, oldAttribs) {
  if (typeof attribs === 'undefined') {
    console.error('v-attr received empty new value from "' + oldAttribs + '"', this.el)
    return
  }

  let values = Array.isArray(attribs) ? attribs : [attribs]

  if (typeof oldAttribs !== 'undefined') {
    var oldValues = Array.isArray(oldAttribs) ? oldAttribs : [oldAttribs]

    oldValues = oldValues.filter((val) => !values.includes(val))
    oldValues.forEach((val) => { this.el.removeAttribute(val) })
  }

  values.forEach(value => { this.el.setAttribute(value, '') })
}

var directiveGoBack = {
  bind () {
    if (Platform.is.cordova) {
      this.goBack = () => {
        window.history.go(-1)
      }
    }
    else {
      this.goBack = () => {
        this.vm.$router.go(this.route)
      }
    }

    this.el.addEventListener('click', this.goBack)
  },
  update (route) {
    this.route = route
  },
  unbind () {
    this.el.removeEventListener('click', this.goBack)
  }
}

var template = "<div>\n  <div class=\"modal-header\">\n    {{{* title || ''}}}\n  </div>\n  <div v-if=\"message\" class=\"modal-body modal-scroll\">\n    {{{* message}}}\n  </div>\n  <div v-if=\"inputs\" class=\"modal-body modal-scroll\">\n    <div v-for=\"input in inputs\" class=\"floating-label\" style=\"margin-bottom: 10px\">\n      <input type=\"text\" class=\"full-width\" v-model=\"input.model\" required>\n      <label>{{ input.label }}</label>\n    </div>\n  </div>\n  <div v-if=\"radios\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"radio in radios\" class=\"item\">\n      <div class=\"item-primary\">\n        <quasar-radio :model.sync=\"radioModel\" :value.once=\"radio.value\"></quasar-radio>\n      </div>\n      <div class=\"item-content\">\n        {{{* radio.label}}}\n      </div>\n    </label>\n  </div>\n  <div v-if=\"checkboxes\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"checkbox in checkboxes\" class=\"item\">\n      <div class=\"item-primary\">\n        <quasar-checkbox :model.sync=\"checkbox.checked\"></quasar-checkbox>\n      </div>\n      <div class=\"item-content\">\n        {{{* checkbox.label}}}\n      </div>\n    </label>\n  </div>\n  <div v-if=\"toggles\" class=\"modal-controls modal-scroll\">\n    <label v-for=\"toggle in toggles\" class=\"item\">\n      <div class=\"item-content has-secondary\">\n        {{{* toggle.label}}}\n      </div>\n      <div class=\"item-secondary\">\n        <quasar-toggle :model.sync=\"toggle.checked\"></quasar-toggle>\n      </div>\n    </label>\n  </div>\n  <div v-if=\"progress\" class=\"modal-slim-body\">\n    <quasar-progress\n      :model=\"progress.model\"\n      class=\"primary stripe\"\n      :class=\"{indeterminate: progress.indeterminate}\"\n    ></quasar-progress>\n    <span v-if=\"!progress.indeterminate\">\n      {{progress.model}} %\n    </span>\n  </div>\n  <div\n    v-if=\"buttons\"\n    class=\"modal-buttons\"\n    :class=\"{row: !stackButtons, column: stackButtons}\"\n  >\n    <button\n      v-for=\"button in buttons\"\n      class=\"primary clear\"\n      @click=\"trigger(button.handler)\"\n    >\n      {{{* button.label}}}\n    </button>\n  </div>\n</div>\n";

let handlers = []

if (Platform.is.desktop) {
  window.addEventListener('keyup', evt => {
    if (handlers.length === 0) {
      return
    }

    if (evt.which === 27 || evt.keyCode === 27) {
      handlers[handlers.length - 1]()
    }
  })
}

var EscapeKey = {
  register (handler) {
    if (Platform.is.desktop) {
      handlers.push(handler)
    }
  },
  pop () {
    if (Platform.is.desktop) {
      handlers.pop()
    }
  }
}

const duration = 300
let openedModalNumber = 0

class Modal {
  constructor (userVm) {
    if (!userVm) {
      throw new Error('Modal needs a VueModel.')
    }

    if (userVm.nodeType) {
      this.__customElement = userVm
    }
    else if (!userVm.template) {
      console.error('Error in Modal create object:', userVm)
      throw new Error('Modal needs a template.')
    }
    else if (userVm.el) {
      console.error('Error in Modal create object:', userVm)
      throw new Error('Specifying "el" property for VM in a Modal is forbidden')
    }

    let vm

    if (this.__customElement) {
      vm = {el: this.__customElement}
    }
    else {
      vm = Utils.extend(true, userVm)
      vm.template = `<div class="modal hidden fullscreen flex items-center justify-center">
            <div v-el:backdrop class="modal-backdrop backdrop"></div>
            <div v-el:content class="modal-content">${userVm.template}</div></div>`

      // preserve data bindings
      vm.data = userVm.data
      vm.methods = vm.methods || {}
      vm.methods.close = onClose => {
        this.close(onClose)
      }
    }

    this.vm = new Vue(vm)
    if (!this.__customElement) {
      this.vm.$mount().$appendTo(document.body)
      this.$content = this.vm.$els.content
      this.$backdrop = this.vm.$els.backdrop
    }
    else {
      this.$content = this.vm.$el.getElementsByClassName('modal-content')[0]
      this.$backdrop = this.vm.$el.getElementsByClassName('modal-backdrop')[0]
    }

    this.$el = this.vm.$el
    this.__onShowHandlers = []
    this.__onCloseHandlers = []
    this.selfDestroy = true
  }

  show (onShow) {
    if (this.active) {
      console.warn('Modal is already displayed')
      return
    }

    if (!this.$el.closest('body')) {
      throw new Error('Modal was previously destroyed. Create another one.')
    }

    if (this.minimized && this.maximized) {
      throw new Error('Modal cannot be minimized & maximized simultaneous.')
    }

    this.$content.classList.remove('minimized', 'maximized')
    if (this.minimized) {
      this.$content.classList.add('minimized')
    }
    if (this.maximized) {
      this.$content.classList.add('maximized')
    }

    if (this.closeWithBackdrop) {
      this.$backdrop.addEventListener('click', this.close)
    }

    document.body.classList.add('with-modal')

    let
      effect,
      options = {
        duration,
        complete: () => {
          EscapeKey.register(() => { this.close(this.onEscapeKey) })
          this.__onShowHandlers.forEach(
            handler => { handler() }
          )
          if (typeof onShow === 'function') {
            onShow()
          }
          this.active = true
        }
      }

    if (this.transitionIn) {
      effect = this.transitionIn
    }
    else if (current === 'mat') {
      effect = 'transition.slideUpIn'
    }
    else if (!this.minimized && (this.maximized || Utils.dom.viewport().width <= 600)) {
      effect = {translateX: [0, '101%']}
    }
    else {
      effect = 'transition.shrinkIn'
    }

    this.$el.classList.remove('hidden')
    setTimeout(() => {
      [].slice.call(this.$el.getElementsByClassName('modal-scroll')).forEach(el => {
        el.scrollTop = 0
      })
    }, 10)
    if (!this.maximized) {
      this.$backdrop.classList.add('active')
    }

    this.__popstate = () => {
      if (
        !Platform.within.iframe &&
        window.history.state &&
        window.history.state.modalId &&
        window.history.state.modalId >= this.__modalId
      ) {
        return
      }
      openedModalNumber--
      this.active = false

      let
        effect,
        options = {
          duration,
          complete: () => {
            this.$el.classList.add('hidden')
            if (!openedModalNumber) {
              document.body.classList.remove('with-modal')
            }

            if (this.selfDestroy) {
              this.destroy()
            }
            if (this.__closedByBackButton && this.onBackButton) {
              this.onBackButton()
            }
            this.__onCloseHandlers.forEach(
              handler => { handler() }
            )
            if (typeof this.__onClose === 'function') {
              this.__onClose()
              delete this.__onClose
            }
          }
        }

      if (this.transitionOut) {
        effect = this.transitionOut
      }
      else if (!this.minimized && (this.maximized || Utils.dom.viewport().width <= 600)) {
        effect = current === 'ios' ? {translateX: ['101%', 0]} : 'transition.slideDownOut'
      }
      else {
        effect = current === 'ios' ? 'transition.shrinkOut' : 'transition.expandOut'
      }

      this.$backdrop.classList.remove('active')
      if (this.closeWithBackdrop) {
        this.$backdrop.removeEventListener('click', this.close)
      }
      if (!Platform.within.iframe) {
        window.removeEventListener('popstate', this.__popstate)
      }
      EscapeKey.pop()
      Velocity(this.$content, effect, options)
    }
    this.__modalId = ++openedModalNumber
    this.__closedByBackButton = true
    if (!Platform.within.iframe) {
      window.history.pushState({modalId: this.__modalId}, '')
      window.addEventListener('popstate', this.__popstate)
    }

    // finally show it
    Velocity(this.$content, effect, options)

    return this
  }

  close (onClose) {
    this.__onClose = onClose
    this.__closedByBackButton = false
    if (Platform.within.iframe) {
      this.__popstate()
    }
    else {
      window.history.go(-1)
    }
    return this
  }

  onShow (handler) {
    this.__registerTrigger('onShow', handler)
    return this
  }

  onClose (handler) {
    this.__registerTrigger('onClose', handler)
    return this
  }

  __registerTrigger (event, handler) {
    if (typeof handler !== 'function') {
      throw new Error('Modal ' + event + ' handler must be a function.')
    }

    this['__' + event + 'Handlers'].push(handler)
    return this
  }

  set (properties) {
    if (properties !== Object(properties)) {
      throw new Error('Modal.set() needs an object as parameter.')
    }

    Object.keys(properties).forEach(property => {
      this[property] = properties[property]
    })

    return this
  }

  css (properties) {
    if (properties !== Object(properties)) {
      throw new Error('Modal.css() needs an object as parameter.')
    }

    Utils.dom.css(this.$content, properties)
    return this
  }

  destroy () {
    this.vm.$destroy(!this.__customElement)
  }
}

var Modal$1 = {
  create (vm) {
    return new Modal(vm)
  }
}

function parseButtons (buttons) {
  if (buttons === false) {
    return false
  }

  if (!Array.isArray(buttons)) {
    throw new Error('Dialog buttons parameter must be an array.')
  }

  if (buttons.some(
    button => typeof button !== 'string' && (Object(button) !== button || typeof button.label === 'undefined' || typeof button.handler !== 'function')
  )) {
    throw new Error('At least one of Dialog\'s button parameter is neither a string nor an object with both label handler.')
  }

  return buttons.map(button => {
    if (typeof button === 'string') {
      return {
        label: button,
        handler () {}
      }
    }
    return button
  })
}

function parseInputs (inputs) {
  if (!Array.isArray(inputs)) {
    throw new Error('Dialog inputs parameter must be an array.')
  }

  return inputs.map(input => {
    input.model = input.model || ''
    return input
  })
}

function parseRadios (radios) {
  if (!Array.isArray(radios)) {
    throw new Error('Dialog radios parameter must be an array.')
  }

  if (radios.some(
    radio => typeof radio.label === 'undefined' || typeof radio.value === 'undefined'
  )) {
    throw new Error('One of Dialog\'s radio parameter is missing either label or value')
  }

  var selectedValue = radios.filter(radio => radio.selected)

  if (selectedValue.length === 0) {
    return radios[0].value
  }

  if (selectedValue.length > 1) {
    throw new Error('Multiple Dialog radio parameters are selected.')
  }

  return selectedValue[0].value
}

function parseCheckboxes (checkboxes) {
  if (!Array.isArray(checkboxes)) {
    throw new Error('Dialog checkboxes parameter must be an array.')
  }

  if (checkboxes.some(
    checkbox => typeof checkbox.label === 'undefined' || typeof checkbox.value === 'undefined'
  )) {
    throw new Error('One of Dialog\'s checkbox parameter is missing either label or value')
  }

  return checkboxes.map(checkbox => {
    checkbox.checked = checkbox.checked || false
    return checkbox
  })
}

function parseProgress (progress) {
  if (progress !== Object(progress)) {
    throw new Error('Progress property is not an Object.')
  }

  if (!progress.hasOwnProperty('model') && !progress.indeterminate) {
    throw new Error('Specify either a model or set as indeterminate.')
  }

  return progress
}

function create (options) {
  var data = Utils.extend({}, options)

  if (typeof data.buttons === 'undefined') {
    data.buttons = [{label: 'Ok', handler () {}}]
  }
  else {
    data.buttons = parseButtons(data.buttons)
  }

  if (data.inputs) {
    data.inputs = parseInputs(data.inputs)
  }
  else if (data.radios) {
    data.radioModel = parseRadios(data.radios)
  }
  else if (data.checkboxes) {
    data.checkboxes = parseCheckboxes(data.checkboxes)
  }
  else if (data.toggles) {
    data.toggles = parseCheckboxes(data.toggles)
  }
  else if (data.progress) {
    data.progress = parseProgress(data.progress)
  }

  return Modal$1.create({
    template: template,
    data: data,
    methods: {
      trigger (handler) {
        let data = this.getData()
        function fn () {
          handler(data)
        }
        this.close(fn)
      },
      getData () {
        if (this.inputs) {
          return this.inputs.map(input => {
            return {
              name: input.name,
              value: input.model
            }
          })
        }
        if (this.radios) {
          return this.radioModel
        }
        if (this.checkboxes || this.toggles) {
          return (this.checkboxes || this.toggles).filter(
            checkbox => checkbox.checked
          ).map(checkbox => checkbox.value)
        }
        if (this.progress && !this.progress.indeterminate) {
          return this.progress.model
        }
      }
    }
  }).set({
    minimized: true
  })
}

var Dialog = {
  create
}

/* istanbul ignore next */
var openURL = (url) => {
  if (Platform.is.cordova) {
    navigator.app.loadUrl(url, {
      openExternal: true
    })

    return
  }

  let win = window.open(url, '_blank')

  if (win) {
    win.focus()
  }
  else {
    Dialog.create({
      title: 'Cannot Open Window',
      message: 'Please allow popups first, then please try again.'
    }).show()
  }
}

let now = Date.now

var debounce = function (fn, wait = 250, immediate) {
  let
    timeout, args, context, timestamp, result,
    later = () => {
      let last = now() - timestamp

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last)
      }
      else {
        timeout = null
        if (!immediate) {
          result = fn.apply(context, args)
          if (!timeout) {
            context = args = null
          }
        }
      }
    }

  return function (...args) {
    var callNow = immediate && !timeout

    context = this
    timestamp = now()

    if (!timeout) {
      timeout = setTimeout(later, wait)
    }
    if (callNow) {
      result = fn.apply(context, args)
      context = args = null
    }

    return result
  }
}

var throttle = function (fn, limit = 250) {
  let wait = false

  return function (...args) {
    if (wait) {
      return
    }

    wait = true
    fn.apply(this, args)
    setTimeout(() => {
      wait = false
    }, limit)
  }
}

function offset (el) {
  let rect = el.getBoundingClientRect()

  return {
    top: rect.top,
    left: rect.left
  }
}

function style (el, property) {
  return window.getComputedStyle(el).getPropertyValue(property)
}

function height (el) {
  return parseFloat(window.getComputedStyle(el).getPropertyValue('height'), 10)
}

function width (el) {
  return parseFloat(window.getComputedStyle(el).getPropertyValue('width'), 10)
}

function css (element, css) {
  let style = element.style

  Object.keys(css).forEach(prop => {
    style[prop] = css[prop]
  })
}

function viewport () {
  let
    e = window,
    a = 'inner'

  if (!('innerWidth' in window)) {
    a = 'client'
    e = document.documentElement || document.body
  }

  return {
    width: e[a + 'Width'],
    height: e[a + 'Height']
  }
}

function ready (fn) {
  if (typeof fn !== 'function') {
    return
  }

  if (document.readyState === 'complete') {
    return fn()
  }

  document.addEventListener('DOMContentLoaded', fn, false)
}

function childOf (target, parent) {
  let element = target

  while (element && element.nodeType) {
    if (element === parent) {
      return true
    }

    element = element.parentNode
  }

  return false
}

function getScrollTarget (el) {
  return el.closest('.layout-view') || window
}

function getScrollPosition (scrollTarget) {
  if (scrollTarget === window) {
    return window.pageYOffset || window.scrollY || document.body.scrollTop || 0
  }
  return scrollTarget.scrollTop
}


var dom = Object.freeze({
	offset: offset,
	style: style,
	height: height,
	width: width,
	css: css,
	viewport: viewport,
	ready: ready,
	childOf: childOf,
	getScrollTarget: getScrollTarget,
	getScrollPosition: getScrollPosition
});

function rightClick (e) {
  if (!e) {
    e = window.event
  }

  if (e.which) {
    return e.which == 3 // eslint-disable-line
  }
  if (e.button) {
    return e.button == 2 // eslint-disable-line
  }

  return false
}

function position (e) {
  let posx, posy

  if (!e) {
    e = window.event
  }
  if (e.touches && e.touches[0]) {
    e = e.touches[0]
  }

  if (e.clientX || e.clientY) {
    posx = e.clientX
    posy = e.clientY
  }
  else if (e.pageX || e.pageY) {
    posx = e.pageX - document.body.scrollLeft - document.documentElement.scrollLeft
    posy = e.pageY - document.body.scrollTop - document.documentElement.scrollTop
  }

  return {
    top: posy,
    left: posx
  }
}

function targetElement (e) {
  let target

  if (!e) {
    e = window.event
  }

  if (e.target) {
    target = e.target
  }
  else if (e.srcElement) {
    target = e.srcElement
  }

  // defeat Safari bug
  if (target.nodeType === 3) {
    target = target.parentNode
  }

  return target
}


var event = Object.freeze({
	rightClick: rightClick,
	position: position,
	targetElement: targetElement
});

let toString = Object.prototype.toString;
let hasOwn = Object.prototype.hasOwnProperty;
let class2type = {}

'Boolean Number String Function Array Date RegExp Object'.split(' ').forEach(name => {
  class2type['[object ' + name + ']'] = name.toLowerCase()
})

function type (obj) {
  return obj == null ? String(obj) : class2type[toString.call(obj)] || 'object'
}

function isPlainObject (obj) {
  if (!obj || type(obj) !== 'object') {
    return false
  }

  if (obj.constructor &&
    !hasOwn.call(obj, 'constructor') &&
    !hasOwn.call(obj.constructor.prototype, 'isPrototypeOf')) {
    return false
  }

  let key
  for (key in obj) {}

  return key === undefined || hasOwn.call(obj, key)
}

function extend () {
  let
    options, name, src, copy, copyIsArray, clone,
    target = arguments[0] || {},
    i = 1,
    length = arguments.length,
    deep = false

  if (typeof target === 'boolean') {
    deep = target
    target = arguments[1] || {}
    i = 2
  }

  if (typeof target !== 'object' && type(target) !== 'function') {
    target = {}
  }

  if (length === i) {
    target = this
    i--
  }

  for (; i < length; i++) {
    if ((options = arguments[i]) != null) {
      for (name in options) {
        src = target[name]
        copy = options[name]

        if (target === copy) {
          continue
        }

        if (deep && copy && (isPlainObject(copy) || (copyIsArray = type(copy) === 'array'))) {
          if (copyIsArray) {
            copyIsArray = false
            clone = src && type(src) === 'array' ? src : []
          }
          else {
            clone = src && isPlainObject(src) ? src : {}
          }

          target[name] = extend(deep, clone, copy)
        }
        else if (copy !== undefined) {
          target[name] = copy
        }
      }
    }
  }

  return target
}

function s4 () {
  return Math.floor((1 + Math.random()) * 0x10000)
    .toString(16)
    .substring(1)
}

var uid = function () {
  return s4() + s4() + '-' + s4() + '-' + s4() + '-' +
    s4() + '-' + s4() + s4() + s4()
}

var Utils = {
  openURL,
  debounce,
  throttle,
  extend,
  dom,
  uid,
  event
}

var directiveScrollFire = {
  bind () {
    this.scrollTarget = Utils.dom.getScrollTarget(this.el)
  },
  update (handler) {
    this.scrollTarget.removeEventListener('scroll', this.scroll)

    if (typeof handler !== 'function') {
      this.scroll = function () {}
      console.error('v-scroll-fire requires a function as parameter', this.el)
      return
    }

    this.scroll = Utils.debounce(() => {
      let containerBottom, elementBottom, fire

      if (this.scrollTarget === window) {
        elementBottom = this.el.getBoundingClientRect().bottom
        fire = elementBottom < Utils.dom.viewport().height
      }
      else {
        containerBottom = Utils.dom.offset(this.scrollTarget).top + Utils.dom.height(this.scrollTarget)
        elementBottom = Utils.dom.offset(this.el).top + Utils.dom.height(this.el)
        fire = elementBottom < containerBottom
      }

      if (fire) {
        this.scrollTarget.removeEventListener('scroll', this.scroll)
        handler(this.el)
      }
    }, 25)

    this.scrollTarget.addEventListener('scroll', this.scroll)
    this.scroll()
  },
  unbind () {
    this.scrollTarget.removeEventListener('scroll', this.scroll)
  }
}

var directiveScroll = {
  bind () {
    this.scrollTarget = Utils.dom.getScrollTarget(this.el)
    this.scroll = () => {
      this.handler(Utils.dom.getScrollPosition(this.scrollTarget))
    }
  },
  update (handler) {
    this.scrollTarget.removeEventListener('scroll', this.scroll)

    if (typeof handler !== 'function') {
      console.error('v-scroll requires a function as parameter', this.el)
      return
    }

    this.handler = handler
    this.scrollTarget.addEventListener('scroll', this.scroll)
  },
  unbind () {
    this.scrollTarget.removeEventListener('scroll', this.scroll)
  }
}

var directiveTooltip = {
  bind () {
    if (this.modifiers.wrap) {
      this.target = document.createElement('div')

      this.el.parentNode.insertBefore(this.target, this.el)
      this.target.appendChild(this.el)
    }
    else {
      this.target = this.el
    }

    this.target.classList.add('quasar-tooltip')

    if (this.modifiers.inline) {
      this.target.classList.add('flex', 'inline')
    }
  },
  update (value) {
    this.target.setAttribute('quasar-tooltip', value)
  }
}

var Checkbox = { template: "<label class=\"quasar-checkbox\" :class=\"{disabled: disable}\"><input type=\"checkbox\" v-model=\"model\" v-attr=\"attrib\"><div></div></label>",
  props: {
    model: {
      type: Boolean,
      twoWay: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  }
}

var Chips = { template: "<div class=\"quasar-chips group\" @click=\"focus\" :class=\"{active: active, disabled: disable}\"><span class=\"chip label bg-light text-grey-9\" v-for=\"label in model\" track-by=\"$index\">{{ label }} <i class=\"on-right\" @click=\"remove($index)\">close</i></span><div class=\"quasar-chips-input chip label text-grey-9\"><input type=\"text\" class=\"no-style\" v-el:input v-model=\"input\" @keyup.enter=\"add()\" @focus=\"active = true\" @blur=\"active = false\" v-attr=\"attrib\" :placeholder=\"placeholder\"> <button class=\"small\" @click=\"add()\" :class=\"{invisible: !input.length}\"><i>send</i></button></div></div>",
  props: {
    model: {
      type: Array,
      twoWay: true,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    placeholder: String
  },
  data () {
    return {
      active: false,
      input: ''
    }
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  },
  methods: {
    add () {
      if (!this.disable && this.input) {
        this.model.push(this.input)
        this.input = ''
      }
    },
    remove (index) {
      if (!this.disable && index >= 0 && index < this.model.length) {
        this.model.splice(index, 1)
      }
    },
    focus () {
      this.$els.input.focus()
    }
  }
}

var Collapsible = { template: "<div class=\"quasar-collapsible\"><div class=\"item item-link non-selectable item-collapsible\" @click=\"toggle()\"><i class=\"item-primary\" v-if=\"icon\" v-text=\"icon\"></i> <img class=\"item-primary thumbnail\" v-if=\"img\" :src=\"img\"><img class=\"item-primary\" v-if=\"avatar\" :src=\"avatar\"><div class=\"item-content has-secondary\">{{ label }}</div><i class=\"item-secondary\" :class=\"{'rotate-180': active}\">keyboard_arrow_down</i></div><div class=\"quasar-collapsible-sub-item\" v-show=\"active\" transition=\"slide\"><slot></slot></div></div>",
  props: {
    active: {
      type: Boolean,
      default: false,
      twoWay: true,
      coerce: Boolean
    },
    icon: String,
    img: String,
    avatar: String,
    label: String
  },
  methods: {
    toggle () {
      this.active = !this.active
    }
  }
}

var ContextMenuDesktop = { template: "<div><quasar-popover v-ref:popover touch-position><slot></slot></quasar-popover></div>",
  props: {
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    open () {
      this.$refs.popover.open()
    },
    close () {
      this.$refs.popover.close()
    },
    toggle () {
      this.$refs.popover.toggle()
    }
  },
  ready () {
    this.target = this.$el.parentNode

    this.handler = event => {
      if (this.disable) {
        return
      }
      event.preventDefault()
      event.stopPropagation()
      if (Utils.dom.childOf(Utils.event.targetElement(event), this.target)) {
        this.$refs.popover.toggle(event)
      }
    }

    this.target.addEventListener('contextmenu', this.handler)
  },
  beforeDestroy () {
    this.target.removeEventListener('contexmenu', this.handler)
  }
}

var ContextMenuMobile = { template: "<div class=\"modal hidden fullscreen flex items-center justify-center\"><div class=\"modal-backdrop backdrop\"></div><div class=\"modal-content\"><div class=\"modal-scroll\"><slot></slot></div></div></div>",
  props: {
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    open () {
      this.handler()
    },
    close () {
      this.target.classList.remove('non-selectable')
      this.modal.close()
    },
    toggle () {
      if (this.modal.active) {
        this.close()
      }
      else {
        this.open()
      }
    }
  },
  ready () {
    this.target = this.$el.parentNode

    this.handler = () => {
      if (this.disable) {
        return
      }
      this.modal = Modal$1.create(this.$el)
        .set({
          minimized: true,
          closeWithBackdrop: true
        })
        .show()
    }

    this.touchStartHandler = (event) => {
      this.target.classList.add('non-selectable')
      this.touchTimer = setTimeout(() => {
        event.preventDefault()
        event.stopPropagation()
        this.cleanup()
        setTimeout(() => {
          this.handler()
        }, 10)
      }, 600)
    }
    this.cleanup = () => {
      this.target.classList.remove('non-selectable')
      if (this.touchTimer) {
        clearTimeout(this.touchTimer)
        this.touchTimer = null
      }
    }
    this.target.addEventListener('touchstart', this.touchStartHandler)
    this.target.addEventListener('touchcancel', this.cleanup)
    this.target.addEventListener('touchmove', this.cleanup)
    this.target.addEventListener('touchend', this.cleanup)
  },
  beforeDestroy () {
    this.target.removeEventListener('touchstart', this.touchStartHandler)
    this.target.removeEventListener('touchcancel', this.cleanup)
    this.target.removeEventListener('touchmove', this.cleanup)
    this.target.removeEventListener('touchend', this.cleanup)
  }
}

var PickerModal = { template: "<div><quasar-inline-datetime :model.sync=\"model\" :type=\"type\" class=\"no-border\" style=\"width: 100%\"><div class=\"modal-buttons row full-width\"><button @click=\"close()\" class=\"primary clear\">{{ cancelLabel }}</button> <button @click=\"set(model)\" class=\"primary clear\">{{ okLabel }}</button></div></quasar-inline-datetime></div>",
  methods: {}
}

var InputDatetimeMobile = { template: "<div class=\"cursor-pointer textfield\" @click=\"pick\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div>",
  props: {
    type: {
      type: String,
      default: 'date',
      twoWay: true
    },
    model: {
      type: String,
      required: true
    },
    format: {
      type: String
    },
    okLabel: {
      type: String,
      default: 'Set'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label () {
      let format

      if (this.format) {
        format = this.format
      }
      else if (this.type === 'date') {
        format = 'YYYY/MM/DD'
      }
      else if (this.type === 'time') {
        format = 'HH:mm'
      }
      else {
        format = 'YYYY/MM/DD HH:mm:ss'
      }

      return moment(this.model).format(format)
    }
  },
  methods: {
    pick () {
      if (this.disable) {
        return
      }

      let modal

      PickerModal.data = {
        model: this.model,
        type: this.type,
        okLabel: this.okLabel,
        cancelLabel: this.cancelLabel
      }
      PickerModal.methods.set = model => {
        this.model = model
        modal.close()
      }

      modal = Modal$1.create(PickerModal)

      if (current === 'ios') {
        modal.$el.classList.remove('items-center')
        modal.$el.classList.add('items-end')
        modal.css({
          maxHeight: '80vh',
          height: 'auto',
          boxShadow: 'none',
          backgroundColor: '#e4e4e4'
        })
        .set({
          transitionIn: {translateY: [0, '101%']},
          transitionOut: {translateY: ['101%', 0]},
          closeWithBackdrop: true
        }).show()
      }
      else {
        modal.set({
          minimized: true,
          closeWithBackdrop: true
        })
        .css({
          maxWidth: '95vw',
          maxHeight: '98vh'
        })
        .show()
      }
    }
  }
}

var InputDatetimeDesktop = { template: "<div class=\"quasar-datetime-desktop\"><quasar-popover :disable=\"disable\"><div slot=\"target\" class=\"cursor-pointer textfield\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div><quasar-inline-datetime :model.sync=\"model\" :type=\"type\"></quasar-inline-datetime></quasar-popover></div>",
  props: {
    type: {
      type: String,
      default: 'date',
      twoWay: true
    },
    model: {
      type: String,
      required: true
    },
    format: {
      type: String
    },
    okLabel: {
      type: String,
      default: 'Set'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label () {
      let format

      if (this.format) {
        format = this.format
      }
      else if (this.type === 'date') {
        format = 'YYYY-MM-DD'
      }
      else if (this.type === 'time') {
        format = 'HH:mm'
      }
      else {
        format = 'YYYY-MM-DD HH:mm:ss'
      }

      return moment(this.model).format(format)
    }
  }
}

var MaterialInlineDatetime = { template: "<div class=\"quasar-datetime inline column gt-md-row\" :class=\"{disabled: disable}\"><div class=\"quasar-datetime-header column justify-center\"><div v-if=\"type === 'date' || type === 'datetime'\"><div class=\"quasar-datetime-weekdaystring\">{{ weekDayString }}</div><div class=\"quasar-datetime-datestring row gt-md-column items-center justify-center\"><span :class=\"{active: view === 'month'}\" class=\"quasar-datetime-link small\" @click=\"view = 'month'\">{{ monthString }} </span><span :class=\"{active: view === 'day'}\" class=\"quasar-datetime-link\" @click=\"view = 'day'\">{{ dayString }} </span><span :class=\"{active: view === 'year'}\" class=\"quasar-datetime-link small\" @click=\"view = 'year'\">{{ year }}</span></div></div><div v-if=\"type === 'time' || type === 'datetime'\" class=\"quasar-datetime-time row gt-md-column items-center justify-center\"><div class=\"quasar-datetime-clockstring\"><span :class=\"{active: view === 'hour'}\" class=\"quasar-datetime-link\" @click=\"view = 'hour'\">{{ __pad(hour, '&nbsp;&nbsp;') }} </span><span style=\"opacity: 0.6\">:</span> <span :class=\"{active: view === 'minute'}\" class=\"quasar-datetime-link\" @click=\"view = 'minute'\">{{ __pad(minute) }}</span></div><div class=\"quasar-datetime-ampm column justify-around\"><div :class=\"{active: am}\" class=\"quasar-datetime-link\" @click=\"toggleAmPm()\">AM</div><div :class=\"{active: !am}\" class=\"quasar-datetime-link\" @click=\"toggleAmPm()\">PM</div></div></div></div><div class=\"quasar-datetime-content auto column\"><div v-el:selector class=\"quasar-datetime-selector auto row items-center justify-center\"><div v-if=\"view === 'year'\" class=\"quasar-datetime-view-year full-width full-height\"><button v-for=\"n in 101\" class=\"primary clear full-width\" :class=\"{active: n + 1950 === year}\" @click=\"setYear(n + 1950)\">{{ n + 1950 }}</button></div><div v-if=\"view === 'month'\" class=\"quasar-datetime-view-month full-width full-height\"><button v-for=\"monthName in monthsList\" class=\"primary clear full-width\" :class=\"{active: month === $index + 1}\" @click=\"setMonth($index + 1, true)\">{{ monthName }}</button></div><div v-if=\"view === 'day'\" class=\"quasar-datetime-view-day quasar-datetime-animate\"><div class=\"row items-center content-center\"><button class=\"primary clear\" @click=\"setMonth(month - 1, true)\"><i>keyboard_arrow_left</i></button><div class=\"auto\">{{ monthStamp }}</div><button class=\"primary clear\" @click=\"setMonth(month + 1, true)\"><i>keyboard_arrow_right</i></button></div><div class=\"quasar-datetime-weekdays row items-center justify-start\"><div>Mo</div><div>Tu</div><div>We</div><div>Th</div><div>Fr</div><div>Sa</div><div>Su</div></div><div class=\"quasar-datetime-days row wrap items-center justify-start content-center\"><div v-for=\"fillerDay in fillerDays\" class=\"quasar-datetime-fillerday\"></div><div v-for=\"monthDay in daysInMonth\" class=\"flex items-center content-center justify-center cursor-pointer\" :class=\"{active: monthDay + 1 === day}\" @click=\"setDay(monthDay + 1)\">{{ monthDay + 1 }}</div></div></div><div v-if=\"view === 'hour' || view === 'minute'\" v-el:clock class=\"column items-center content-center justify-center\"><div v-if=\"view === 'hour'\" class=\"quasar-datetime-clock cursor-pointer\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><div class=\"quasar-datetime-clock-circle full-width full-height\"><div class=\"quasar-datetime-clock-center\"></div><div class=\"quasar-datetime-clock-pointer\" :style=\"clockPointerStyle\"><span></span></div><div v-for=\"n in 12\" class=\"quasar-datetime-clock-position\" :class=\"['quasar-datetime-clock-pos-' + (n + 1), n + 1 === hour ? 'active' : '']\">{{ n + 1 }}</div></div></div><div v-if=\"view === 'minute'\" class=\"quasar-datetime-clock cursor-pointer\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><div class=\"quasar-datetime-clock-circle full-width full-height\"><div class=\"quasar-datetime-clock-center\"></div><div class=\"quasar-datetime-clock-pointer\" :style=\"clockPointerStyle\"><span></span></div><div v-for=\"n in 12\" class=\"quasar-datetime-clock-position\" :class=\"['quasar-datetime-clock-pos-' + n, n * 5 === minute ? 'active' : '']\">{{ n * 5 }}</div></div></div></div></div><slot></slot></div></div>",
  props: {
    model: {
      type: String,
      twoWay: true,
      required: true
    },
    type: {
      type: String,
      default: 'date',
      validator (value) {
        return ['date', 'time', 'datetime'].includes(value)
      }
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    let view

    switch (this.type) {
      case 'time':
        view = 'hour'
        break
      case 'date':
      default:
        view = 'day'
        break
    }

    return {
      view,
      date: moment(this.model),
      dragging: false,
      centerClockPosition: 0,
      monthsList: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    }
  },
  watch: {
    model (value) {
      this.date = moment(value)
    },
    view (value) {
      if (value !== 'year' && value !== 'month') {
        return
      }

      let
        view = this.$els.selector,
        rows = value === 'year' ? this.year - 1950 : this.month

      this.$nextTick(() => {
        view.scrollTop = rows * Utils.dom.height(view.children[0].children[0]) - Utils.dom.height(view) / 2.5
      })
    }
  },
  computed: {
    year () {
      return this.date.year()
    },
    month () {
      return this.date.month() + 1
    },
    day () {
      return this.date.date()
    },
    dayString () {
      return this.date.format('Do')
    },
    monthString () {
      return this.date.format('MMM')
    },
    monthStamp () {
      return this.date.format('MMMM YYYY')
    },
    weekDayString () {
      return this.date.format('dddd')
    },
    fillerDays () {
      return Math.max(0, this.date.clone().date(1).day() - 1)
    },
    daysInMonth () {
      return this.date.daysInMonth()
    },
    hour () {
      let hour = this.date.hour()
      return hour === 0 ? 12 : (hour >= 13 ? hour - 12 : hour)
    },
    minute () {
      return this.date.minute()
    },
    am () {
      return this.date.hour() <= 11
    },
    clockPointerStyle () {
      let
        divider = this.view === 'minute' ? 60 : 12,
        degrees = Math.round((this.view === 'minute' ? this.minute : this.hour) * (360 / divider)) - 180

      return {
        '-webkit-transform': 'rotate(' + degrees + 'deg)',
        '-ms-transform': 'rotate(' + degrees + 'deg)',
        'transform': 'rotate(' + degrees + 'deg)'
      }
    }
  },
  methods: {
    /* date */
    setYear (value) {
      if (this.disable) {
        return
      }
      this.date.year(this.__parseTypeValue('year', value))
      this.__updateModel()
    },
    setMonth (value, force) {
      if (this.disable) {
        return
      }
      this.date.month((force ? value : this.__parseTypeValue('month', value)) - 1)
      this.__updateModel()
    },
    setDay (value) {
      if (this.disable) {
        return
      }
      this.date.date(this.__parseTypeValue('date', value))
      this.__updateModel()
    },

    /* time */
    toggleAmPm () {
      if (this.disable) {
        return
      }
      let
        hour = this.date.hour(),
        offset = this.am ? 12 : -12

      this.date.hour(hour + offset)
      this.__updateModel()
    },
    setHour (value) {
      if (this.disable) {
        return
      }
      value = this.__parseTypeValue('hour', value) % 12

      if (!this.am) {
        value += 12
      }

      this.date.hour(value)
      this.__updateModel()
    },
    setMinute (value) {
      if (this.disable) {
        return
      }
      this.date.minute(this.__parseTypeValue('minute', value))
      this.__updateModel()
    },

    /* helpers */
    __pad (unit, filler) {
      return (unit < 10 ? filler || '0' : '') + unit
    },
    __dragStart (ev) {
      ev.stopPropagation()
      ev.preventDefault()

      let
        clock = this.$els.clock,
        clockOffset = Utils.dom.offset(clock)

      this.centerClockPosition = {
        top: clockOffset.top + Utils.dom.height(clock) / 2,
        left: clockOffset.left + Utils.dom.width(clock) / 2
      }

      this.dragging = true
      this.__updateClock(ev)
    },
    __dragMove (ev) {
      if (!this.dragging) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()
      this.__updateClock(ev)
    },
    __dragStop (ev) {
      ev.stopPropagation()
      ev.preventDefault()
      this.dragging = false
    },
    __updateClock (ev) {
      let
        position = Utils.event.position(ev),
        height = Math.abs(position.top - this.centerClockPosition.top),
        distance = Math.sqrt(
          Math.pow(Math.abs(position.top - this.centerClockPosition.top), 2) +
          Math.pow(Math.abs(position.left - this.centerClockPosition.left), 2)
        ),
        angle = Math.asin(height / distance) * (180 / Math.PI)

      if (position.top < this.centerClockPosition.top) {
        angle = this.centerClockPosition.left < position.left ? 90 - angle : 270 + angle
      }
      else {
        angle = this.centerClockPosition.left < position.left ? angle + 90 : 270 - angle
      }

      if (this.view === 'hour') {
        this.setHour(Math.round(angle / 30))
      }
      else {
        this.setMinute(Math.round(angle / 6))
      }
    },
    __parseTypeValue (type, value) {
      if (type === 'month') {
        return Math.max(1, Math.min(12, value))
      }
      if (type === 'date') {
        return Math.max(1, Math.min(this.daysInMonth, value))
      }
      if (type === 'year') {
        return Math.max(1950, Math.min(2050, value))
      }
      if (type === 'hour') {
        return Math.max(0, Math.min(23, value))
      }
      if (type === 'minute') {
        return Math.max(0, Math.min(59, value))
      }
    },

    /* common */
    __updateModel () {
      this.model = this.date.toISOString()
    }
  }
}

var iOSInlineDatetime = { template: "<div class=\"quasar-datetime\" :class=\"['type-' + type, disabled ? 'disable' : '']\"><slot></slot><div class=\"quasar-datetime-content non-selectable\"><div class=\"quasar-datetime-inner full-height flex justify-center\"><div class=\"quasar-datetime-col quasar-datetime-col-month\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'month')\" @touchmove=\"__dragMove($event, 'month')\" @touchend=\"__dragStop($event, 'month')\"><div v-el:month class=\"quasar-datetime-col-wrapper\" :style=\"__monthStyle\"><div v-for=\"monthName in monthsList\" class=\"quasar-datetime-item\" @click=\"setMonth($index + 1)\">{{ monthName }}</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-day\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'date')\" @touchmove=\"__dragMove($event, 'date')\" @touchend=\"__dragStop($event, 'date')\"><div v-el:date class=\"quasar-datetime-col-wrapper\" :style=\"__dayStyle\"><div v-for=\"monthDay in daysInMonth\" class=\"quasar-datetime-item\" @click=\"setDay(monthDay + 1)\">{{ monthDay + 1 }}</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-year\" v-if=\"type === 'date' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'year')\" @touchmove=\"__dragMove($event, 'year')\" @touchend=\"__dragStop($event, 'year')\"><div v-el:year class=\"quasar-datetime-col-wrapper\" :style=\"__yearStyle\"><div v-for=\"n in 101\" class=\"quasar-datetime-item\" @click=\"setYear(n + 1950)\">{{ n + 1950 }}</div></div></div><div v-el class=\"quasar-datetime-col quasar-datetime-col-hour\" v-if=\"type === 'time' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'hour')\" @touchmove=\"__dragMove($event, 'hour')\" @touchend=\"__dragStop($event, 'hour')\"><div v-el:hour class=\"quasar-datetime-col-wrapper\" :style=\"__hourStyle\"><div v-for=\"n in 24\" class=\"quasar-datetime-item\" @click=\"setHour(n)\">{{ n }}</div></div></div><div class=\"quasar-datetime-col-divider\" v-if=\"type === 'time' || type === 'datetime'\"><div class=\"quasar-datetime-col-wrapper full-height row items-center justify-center\"><div>:</div></div></div><div class=\"quasar-datetime-col quasar-datetime-col-minute\" v-if=\"type === 'time' || type === 'datetime'\" @touchstart=\"__dragStart($event, 'minute')\" @touchmove=\"__dragMove($event, 'minute')\" @touchend=\"__dragStop($event, 'minute')\"><div v-el:minute class=\"quasar-datetime-col-wrapper\" :style=\"__minuteStyle\"><div v-for=\"n in 60\" class=\"quasar-datetime-item\" @click=\"setMinute(n)\">{{ __pad(n) }}</div></div></div><div class=\"quasar-datetime-highlight\"></div></div><div class=\"quasar-datetime-mask\"></div></div></div>",
  props: {
    model: {
      type: String,
      twoWay: true,
      required: true
    },
    type: {
      type: String,
      default: 'date',
      validator (value) {
        return ['date', 'time', 'datetime'].includes(value)
      }
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      date: moment(this.model),
      monthDragOffset: 0,
      dateDragOffset: 0,
      yearDragOffset: 0,
      hourDragOffset: 0,
      minuteDragOffset: 0,
      monthsList: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    }
  },
  watch: {
    model (value) {
      this.date = moment(value)
    }
  },
  computed: {
    year () {
      let value = this.date.year()
      this.__updatePositions('year', value)
      this.__updatePositions('date', this.date.date())
      return value
    },
    month () {
      let value = this.date.month()
      this.__updatePositions('month', value)
      this.__updatePositions('date', this.date.date())
      return value + 1
    },
    day () {
      let value = this.date.date()
      this.__updatePositions('date', value)
      return value
    },
    daysInMonth () {
      return this.date.daysInMonth()
    },
    hour () {
      let value = this.date.hour()
      this.__updatePositions('hour', value)
      return value
    },
    minute () {
      let value = this.date.minute()
      this.__updatePositions('minute', value)
      return value
    },

    __monthStyle () {
      return this.__colStyle(82 - (this.month - 1 + this.monthDragOffset) * 36)
    },
    __dayStyle () {
      return this.__colStyle(82 - (this.day + this.dateDragOffset) * 36)
    },
    __yearStyle () {
      return this.__colStyle(82 - (this.year + this.yearDragOffset) * 36)
    },
    __hourStyle () {
      return this.__colStyle(82 - (this.hour + this.hourDragOffset) * 36)
    },
    __minuteStyle () {
      return this.__colStyle(82 - (this.minute + this.minuteDragOffset) * 36)
    }
  },
  methods: {
    /* date */
    setYear (value) {
      if (this.disable) {
        return
      }
      this.date.year(this.__parseTypeValue('year', value))
      this.__updateModel()
    },
    setMonth (value) {
      if (this.disable) {
        return
      }
      this.date.month(this.__parseTypeValue('month', value) - 1)
      this.__updateModel()
    },
    setDay (value) {
      if (this.disable) {
        return
      }
      this.date.date(this.__parseTypeValue('date', value))
      this.__updateModel()
    },

    /* time */
    setHour (value) {
      if (this.disable) {
        return
      }
      this.date.hour(this.__parseTypeValue('hour', value))
      this.__updateModel()
    },
    setMinute (value) {
      if (this.disable) {
        return
      }
      this.date.minute(this.__parseTypeValue('minute', value))
      this.__updateModel()
    },

    /* helpers */
    __pad (unit, filler) {
      return (unit < 10 ? filler || '0' : '') + unit
    },
    __parseTypeValue (type, value) {
      if (type === 'month') {
        return Math.max(1, Math.min(12, value))
      }
      if (type === 'date') {
        return Math.max(1, Math.min(this.daysInMonth, value))
      }
      if (type === 'year') {
        return Math.max(1950, Math.min(2050, value))
      }
      if (type === 'hour') {
        return Math.max(0, Math.min(23, value))
      }
      if (type === 'minute') {
        return Math.max(0, Math.min(59, value))
      }
    },
    __updatePositions (type, value) {
      let root = this.$els[type]

      if (!root) {
        return
      }

      let delta = -value + (type === 'year' ? 1950 : (type === 'date' ? 1 : 0));[].slice.call(root.children).forEach(item => {
        Utils.dom.css(item, this.__itemStyle(value * 36, Math.max(-180, Math.min(180, delta * -18))))
        delta++
      })
    },
    __colStyle (value) {
      return {
        '-webkit-transform': 'translate3d(0,' + value + 'px,0)',
        '-ms-transform': 'translate3d(0,' + value + 'px,0)',
        'transform': 'translate3d(0,' + value + 'px,0)'
      }
    },
    __itemStyle (translation, rotation) {
      return {
        '-webkit-transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)',
        '-ms-transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)',
        'transform': 'translate3d(0, ' + translation + 'px, 0) rotateX(' + rotation + 'deg)'
      }
    },

    /* common */
    __updateModel () {
      this.model = this.date.toISOString()
    },
    __dragStart (ev, type) {
      if (this.disable) {
        return
      }

      this.__dragCleanup()
      ;['month', 'date', 'year', 'hour', 'minute'].forEach(type => {
        this[type + 'DragOffset'] = 0
      })
      ev.stopPropagation()
      ev.preventDefault()

      this.dragging = type
      this.__dragPosition = Utils.event.position(ev).top
    },
    __dragMove (ev, type) {
      if (this.dragging !== type || this.disable) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()
      this[type + 'DragOffset'] = (this.__dragPosition - Utils.event.position(ev).top) / 36
      this.__updatePositions(type, this.date[type]() + this[type + 'DragOffset'])
    },
    __dragStop (ev, type) {
      if (this.dragging !== type || this.disable) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()
      this.dragging = false

      let
        offset = Math.round(this[type + 'DragOffset']),
        newValue = this.__parseTypeValue(type, this[type === 'date' ? 'day' : type] + offset),
        actualType = type === 'date' ? 'day' : type

      if (newValue !== this[actualType]) {
        this['set' + actualType.charAt(0).toUpperCase() + actualType.slice(1)](newValue)
        this[type + 'DragOffset'] = 0
      }
      else {
        this.__updatePositions(type, this.date[type]())
        this.timeout = setTimeout(() => {
          this[type + 'DragOffset'] = 0
        }, 150)
      }
    },
    __dragCleanup () {
      if (this.timeout) {
        clearTimeout(this.timeout)
        this.timeout = null
      }
    }
  },
  compiled () {
    if (this.type === 'date' || this.type === 'datetime') {
      this.__updatePositions('month', this.date.month())
      this.__updatePositions('date', this.date.date())
      this.__updatePositions('year', this.date.year())
    }
    if (this.type === 'time' || this.type === 'datetime') {
      this.__updatePositions('hour', this.date.hour())
      this.__updatePositions('minute', this.date.minute())
    }
  },
  beforeDestroy () {
    this.__dragCleanup()
  }
}

const drawerAnimationSpeed = 150;
const backdropOpacity = {
    mat: 0.7,
    ios: 0.2
  };
const appContainer = document.getElementById('quasar-app')

let leftDrawer;
let rightDrawer

function getCurrentPosition (node) {
  let transform = Utils.dom.style(node, 'transform')
  return transform !== 'none' ? parseInt(transform.split(/[()]/)[1].split(', ')[4], 10) : 0
}

function getBetween (value, min, max) {
  if (value < min) {
    return min
  }

  if (value > max) {
    return max
  }

  return value
}

function closeDrawers (done) {
  if (leftDrawer && leftDrawer.opened) {
    leftDrawer.setState(false, done)
    return
  }
  if (rightDrawer && rightDrawer.opened) {
    rightDrawer.setState(false, done)
    return
  }

  if (typeof done === 'function') {
    done()
  }
}

var Drawer = { template: "<div class=\"drawer\" :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><div class=\"drawer-opener touch-only mobile-only\" v-touch:pan=\"openByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\" :class=\"{'fixed-left': !rightSide, 'fixed-right': rightSide}\">&nbsp</div><div v-el:backdrop class=\"drawer-backdrop fullscreen\" style=\"background: rgba(0, 0, 0, 0.01)\" @click=\"setState(false)\" v-touch:pan=\"closeByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\"></div><div v-el:content v-touch:pan=\"closeByTouch\" v-touch-options:pan=\"{ direction: 'horizontal' }\" class=\"drawer-content\" :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><slot></slot></div></div>",
  props: {
    'right-side': {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    'swipe-only': {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      opened: false
    }
  },
  methods: {
    __matToggleAnimate (percentage, done) {
      const
        node = this.$els.content,
        backdrop = this.$els.backdrop,
        currentPosition = getCurrentPosition(node),
        closePosition = (this.rightSide ? 1 : -1) * this.width

      Velocity(node, 'stop')
      Velocity(
        node,
        {translateX: this.opened ? [0, currentPosition] : [closePosition, currentPosition]},
        {duration: !this.opened || currentPosition !== 0 ? drawerAnimationSpeed : 0}
      )

      if (this.opened) {
        backdrop.classList.add('active')
        if (!Platform.within.iframe) {
          if (!window.history.state) {
            window.history.replaceState({__quasar_drawer: true}, '')
          }
          else {
            window.history.state.__quasar_drawer = true
          }
          window.history.pushState({}, '')
          window.addEventListener('popstate', this.__popState)
        }
      }
      else {
        window.removeEventListener('resize', closeDrawers)
        if (!Platform.within.iframe) {
          window.removeEventListener('popstate', this.__popState)
          if (window.history.state && !window.history.state.__quasar_drawer) {
            window.history.go(-1)
          }
        }
      }

      Velocity(backdrop, 'stop')
      Velocity(
        backdrop,
        {
          'backgroundColor': '#000',
          'backgroundColorAlpha': this.opened ? backdropOpacity.mat : 0.01
        },
        {
          duration: drawerAnimationSpeed,
          complete: () => {
            if (!this.opened) {
              backdrop.classList.remove('active')
            }
            else {
              window.addEventListener('resize', closeDrawers)
            }
            if (typeof done === 'function') {
              done()
            }
          }
        }
      )
    },
    __iosToggleAnimate (percentage, done) {
      const backdrop = this.$els.backdrop

      if (this.opened) {
        backdrop.classList.add('active')
        document.body.classList.add('drawer-opened')
        if (!Platform.within.iframe) {
          if (!window.history.state) {
            window.history.replaceState({__quasar_drawer: true}, '')
          }
          else {
            window.history.state.__quasar_drawer = true
          }
          window.history.pushState({}, '')
          window.addEventListener('popstate', this.__popState)
        }
      }
      else {
        window.removeEventListener('resize', closeDrawers)
        if (!Platform.within.iframe) {
          window.removeEventListener('popstate', this.__popState)
          if (window.history.state && !window.history.state.__quasar_drawer) {
            window.history.go(-1)
          }
        }
      }

      let
        currentPosition = getCurrentPosition(appContainer),
        openPosition = (this.rightSide ? -1 : 1) * this.width

      Velocity(appContainer, 'stop')
      Velocity(appContainer,
        {translateX: this.opened ? [openPosition, currentPosition] : [0, currentPosition]},
        {duration: !this.opened || currentPosition !== openPosition ? drawerAnimationSpeed : 0}
      )

      Velocity(backdrop, 'stop')
      Velocity(
        backdrop,
        {
          'backgroundColor': '#000',
          'backgroundColorAlpha': this.opened ? backdropOpacity.ios : 0.01
        },
        {
          duration: drawerAnimationSpeed,
          complete: () => {
            if (!this.opened) {
              backdrop.classList.remove('active')
              document.body.classList.remove('drawer-opened')
            }
            else {
              window.addEventListener('resize', closeDrawers)
            }
            if (typeof done === 'function') {
              done()
            }
          }
        }
      )
    },
    openByTouch (event) {
      const
        content = this.$els.content,
        backdrop = this.$els.backdrop

      if (Utils.dom.style(content, 'position') !== 'fixed') {
        return
      }

      let
        position = Math.abs(event.deltaX),
        target,
        fn,
        percentage

      if (event.isFinal) {
        this.opened = position > 75
      }

      if (current === 'ios') {
        position = Math.min(position, this.width)
        percentage = 1.0 - (this.width - Math.abs(position)) / this.width
        fn = this.__iosToggleAnimate
        target = appContainer
        position = (this.rightSide ? -1 : 1) * position
      }
      else { // mat
        position = this.rightSide ? Math.max(this.width - position, 0) : Math.min(0, position - this.width)
        percentage = (this.width - Math.abs(position)) / this.width
        fn = this.__matToggleAnimate
        target = content
      }

      if (event.isFinal) {
        fn(percentage, null)
        return
      }

      target.style.transform = 'translateX(' + position + 'px)'
      backdrop.classList.add('active')
      backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[current] + ')'
    },
    closeByTouch (event) {
      const
        content = this.$els.content,
        backdrop = this.$els.backdrop

      let
        target, fn, percentage, position,
        initialPosition

      if (Utils.dom.style(content, 'position') !== 'fixed') {
        return
      }

      position = this.rightSide ? getBetween(event.deltaX, 0, this.width) : getBetween(event.deltaX, -this.width, 0)
      initialPosition = (this.rightSide ? -1 : 1) * this.width

      if (event.isFinal) {
        this.opened = Math.abs(position) <= 75
      }

      if (current === 'ios') {
        position = initialPosition + position
        percentage = (this.rightSide ? -1 : 1) * position / this.width
        fn = this.__iosToggleAnimate
        target = appContainer
      }
      else { // mat
        percentage = 1 + (this.rightSide ? -1 : 1) * position / this.width
        fn = this.__matToggleAnimate
        target = content
      }

      if (event.isFinal) {
        fn(percentage, null)
        return
      }

      target.style.transform = 'translateX(' + position + 'px)'
      backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[current] + ')'
    },
    setState (state, done) {
      if (
        (!this.swipeOnly && Utils.dom.viewport().width > 600) ||
        (typeof state === 'boolean' && this.opened === state)
      ) {
        if (typeof done === 'function') {
          done()
        }
        return
      }

      this.opened = !this.opened
      let fn = current === 'ios' ? this.__iosToggleAnimate : this.__matToggleAnimate

      fn(this.opened ? 0.01 : 1, done)
    },
    __popState () {
      if (!Platform.within.iframe) {
        if (window.history.state && window.history.state.__quasar_drawer) {
          this.setState(false)
        }
      }
    },
    open (done) {
      this.setState(true, done)
    },
    close (done) {
      this.setState(false, done)
    }
  },
  ready () {
    const
      content = this.$els.content,
      toggles = this.$el.closest('.layout').getElementsByClassName((this.rightSide ? 'right' : 'left') + '-drawer-opener')

    this.width = Utils.dom.width(content)

    ;[].slice.call(toggles).forEach(el => {
      el.addEventListener('click', () => {
        this.setState(true)
      })
    })

    ;[].slice.call(content.getElementsByClassName('drawer-closer')).forEach(el => {
      el.addEventListener('click', () => {
        this.setState(false)
      })
    })

    if (this.swipeOnly) {
      [].slice.call(toggles).forEach(el => {
        el.classList.add('always-visible')
      })
      this.$el.classList.add('swipe-only')
    }

    if (this.rightSide) {
      rightDrawer = this
    }
    else {
      leftDrawer = this
    }
  },
  beforeDestroy () {
    this.setState(false)

    if (this.rightSide) {
      rightDrawer = null
    }
    else {
      leftDrawer = null
    }
  }
}

var DrawerLink = { template: "<div class=\"item item-link drawer-closer\"><i v-if=\"icon\" class=\"item-primary\">{{icon}}</i><div class=\"item-content\"><slot></slot></div></div>",
  props: ['icon']
}

var Fab = { template: "<div class=\"quasar-fab flex inline justify-center\" :class=\"{opened: opened, 'with-backdrop': click || backdrop}\"><div v-if=\"click || backdrop\" class=\"backdrop\" @click=\"toggle(true)\"></div><button class=\"circular raised\" @click=\"toggle()\" :class=\"type\"><i class=\"quasar-fab-icon\">{{icon}}</i> <i class=\"quasar-fab-active-icon\">{{activeIcon}}</i></button><div class=\"quasar-fab-actions flex inline items-center\" :class=\"[direction]\"><slot></slot></div></div>",
  props: {
    type: {
      type: Array,
      default () {
        return ['primary']
      },
      coerce (value) {
        return Array.isArray(value) || typeof value === 'undefined' ? value : value.split(' ')
      }
    },
    icon: {
      type: String,
      default: 'add'
    },
    activeIcon: {
      type: String,
      default: 'close'
    },
    direction: {
      type: String,
      default: 'right'
    },
    click: {
      type: Function
    },
    backdrop: {
      type: Boolean,
      coerce: Boolean
    }
  },
  data () {
    return {
      opened: false
    }
  },
  methods: {
    toggle (fromBackdrop) {
      this.opened = !this.opened

      if (!fromBackdrop && this.click && !this.opened) {
        this.click()
        return
      }
    }
  },
  events: {
    closeFAB () {
      this.toggle(true)
    }
  }
}

var SmallFab = { template: "<button class=\"circular small raised\" @click=\"closeFAB()\"><i><slot></slot></i></button>",
  methods: {
    closeFAB () {
      this.$dispatch('closeFAB')
    }
  }
}

var Gallery = { template: "<div class=\"quasar-gallery\"><div v-for=\"img in src\" track-by=\"$index\" :style=\"{width: width}\"><img :src=\"img\"></div></div>",
  props: {
    src: {
      type: Array,
      required: true
    },
    width: {
      type: String,
      default: '150px'
    }
  }
}

var GallerySlider = { template: "<quasar-slider v-ref:slider arrows fullscreen class=\"text-white bg-black quasar-gallery-slider\"><div v-for=\"img in src\" track-by=\"$index\" slot=\"slide\" class=\"no-padding flex items-center justify-center\"><div class=\"full-width\"><img :src=\"img\"></div></div><div class=\"quasar-gallery-slider-overlay\" :class=\"{active: quickView}\" @click=\"toggleQuickView()\"></div><i slot=\"action\" @click=\"toggleQuickView()\">view_carousel</i><div class=\"quasar-gallery-slider-quickview\" :class=\"{active: quickView}\"><div v-for=\"img in src\" track-by=\"$index\"><img :src=\"img\" :class=\"{active: $refs.slider.slide === $index}\" @click=\"selectImage($index)\"></div></div></quasar-slider>",
  props: {
    src: {
      type: Array,
      required: true
    }
  },
  data () {
    return {
      quickView: false
    }
  },
  methods: {
    toggleQuickView () {
      this.quickView = !this.quickView
    },
    selectImage (index) {
      this.$refs.slider.goToSlide(index, true)
      this.toggleQuickView()
    }
  }
}

var Grid = { template: "<quasar-grid-table v-ref:table class=\"quasar-grid\" :data=\"data | gridShowSelected showOnlySelected selectionMode singleSelection | filterBy searchQuery\" :columns=\"columns\" :rows-per-page=\"rowsPerPage\" :sortable=\"sortable\" :selection-mode=\"selectionMode\" :selection-actions=\"selectionActions\" :no-data-label=\"noDataLabel\" :id-property=\"idProperty\"></quasar-grid-table>",
  props: {
    columns: {
      type: Array,
      required: true
    },
    data: {
      type: Array,
      required: true
    },
    rowsPerPage: {
      type: Number,
      default: 5
    },
    sortable: {
      type: Boolean,
      default: true,
      coerce: Boolean
    },
    noDataLabel: {
      type: String,
      default: 'No data to display.'
    },
    idProperty: String,
    selectionMode: {
      type: String,
      default: 'none',
      coerce: value => {
        return value === 'single' || value === 'multiple' ? value : 'none'
      }
    },
    selectionActions: Array
  },
  data () {
    return {
      searchQuery: '',
      showOnlySelected: false,
      singleSelection: []
    }
  },
  watch: {
    searchQuery () {
      this.$refs.table.page = 1
    },
    showOnlySelected () {
      this.$refs.table.page = 1
    }
  },
  events: {
    'toggle-selection' () {
      this.showOnlySelected = !this.showOnlySelected
    },
    filter (value) {
      this.searchQuery = value
    },
    'set-single-selection' (value) {
      this.singleSelection = value
    }
  }
}

const defaultRowsPerPage = [
  {label: '5', value: 5},
  {label: '10', value: 10},
  {label: '15', value: 15},
  {label: '25', value: 25},
  {label: '50', value: 50},
  {label: '100', value: 100},
  {label: 'No pagination', value: 0}
]

function getRowsPerPageOption (rowsPerPage) {
  if (defaultRowsPerPage.find(column => column.value === rowsPerPage)) {
    return defaultRowsPerPage
  }

  var options = defaultRowsPerPage.slice(0)

  options.unshift({
    label: '' + rowsPerPage,
    value: rowsPerPage
  })

  return options
}

var GridTable = { template: "<div class=\"quasar-grid-table\"><div class=\"grid-top-controls sm-column gt-sm-row items-center justify-end\"><div class=\"auto sm-order-last self-center\"><div v-show=\"selectionMode !== 'none' && controls === ''\" transition=\"slide\">Selected {{selectedRows.length}} rows.</div><div v-show=\"selectionMode !== 'none' && controls === 'selection'\" transition=\"slide\"><button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=\"chooseAction()\"><i>menu</i></button> <button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=\"clearSelection()\"><i>cancel</i></button><label><quasar-checkbox :model.sync=\"showOnlySelected\"></quasar-checkbox>&nbsp;Show Selected</label></div><div v-show=\"controls === 'filter'\" transition=\"slide\">Filter: <input v-model=\"searchQuery\" type=\"text\" :debounce=\"350\"> <button class=\"primary clear small\" @click=\"clearFilter()\"><i>clear</i></button></div></div><div class=\"grid-control-panel row\"><button class=\"primary\" :class=\"{'clear': controls !== 'filter'}\" @click=\"toggleControls('filter')\"><i>search</i></button> <button v-if=\"selectionMode !== 'none'\" class=\"primary\" :class=\"{'clear': controls !== 'selection'}\" @click=\"toggleControls('selection')\"><i>playlist_add_check</i></button><quasar-select type=\"radio\" :model.sync=\"rowsPerPage\" :options=\"rowsPerPageOptions\" fixed-label=\"<i>format_list_numbered</i>\"></quasar-select><quasar-select type=\"toggle\" :model.sync=\"chosenColumnsModel\" :options=\"chosenColumnsOptions\" fixed-label=\"<i>view_column</i>\"></quasar-select></div></div><table class=\"quasar-table striped highlight bordered compact full-width\"><thead><tr><th v-if=\"selectionMode !== 'none'\" style=\"width: 30px; text-align: center\">&nbsp</th><th v-for=\"column in columns\" v-show=\"!column.hidden\" @click=\"sortBy(column.field)\" :class=\"{'sortable-column': sortable}\" style=\"text-align: left\">{{{column.label}}} <i v-show=\"sortField === column.field && sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field && sortOrder === 1\">keyboard_arrow_up</i></th></tr></thead><tbody><tr v-for=\"row in data | orderBy sortField sortOrder | limitBy computedRowsPerPage rowOffset\" :track-by=\"idProperty\"><td v-if=\"selectionMode !== 'none'\"><quasar-radio v-if=\"selectionMode === 'single'\" :model.sync=\"singleSelectedRow\" :value=\"row\"></quasar-radio><quasar-checkbox v-else :model.sync=\"row.__selected\"></quasar-checkbox></td><td v-for=\"column in columns\" v-if=\"!column.hidden\" :style=\"column.style\" :class=\"column.classes\" :data-th=\"column.label\">{{{column.formatter ? column.formatter(row[column.field]) : row[column.field]}}}</td></tr></tbody><tfoot v-show=\"computedRowsPerPage > 10\"><tr><th v-if=\"selectionMode !== 'none'\">&nbsp</th><th v-for=\"column in columns\" v-show=\"!column.hidden\" @click=\"sortBy(column.field)\" :class=\"{'sortable-column': sortable}\">{{{column.label}}} <i v-show=\"sortField === column.field && sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field && sortOrder === 1\">keyboard_arrow_up</i></th></tr></tfoot></table><div class=\"grid-bottom-controls sm-column gt-sm-row items-center\"><div class=\"auto\" v-show=\"data.length > 0\">Showing {{rowOffset + 1}} to {{Math.min(rowsNumber, rowsPerPage * page)}} of {{rowsNumber}} entries</div><div class=\"auto text-center\" v-else>{{noDataLabel}}</div><quasar-pagination :model.sync=\"page\" :max=\"pagesNumber\" v-show=\"rowsPerPage !== 0 && rowsNumber > 0\"></quasar-pagination></div></div>",
  props: ['data', 'columns', 'rowsPerPage', 'sortable', 'noDataLabel', 'idProperty', 'selectionMode', 'selectionActions'],
  data () {
    let
      rowsPerPage = this.rowsPerPage,
      chosenColumns = this.getChosenColumn()

    return {
      page: 1,
      rowsPerPageOptions: getRowsPerPageOption(rowsPerPage),
      sortField: '',
      sortOrder: 1,
      chosenColumnsModel: chosenColumns,
      singleSelectedRow: null,
      searchQuery: '',
      controls: '',
      showOnlySelected: false
    }
  },
  computed: {
    rowsNumber () {
      return this.data.length
    },
    pagesNumber () {
      return Math.ceil(this.data.length / this.rowsPerPage)
    },
    chosenColumnsOptions () {
      return this.columns.map(column => {
        return {
          label: column.label,
          value: column.field
        }
      })
    },
    computedRowsPerPage () {
      return this.rowsPerPage ? this.rowsPerPage : Infinity
    },
    rowOffset () {
      return this.rowsPerPage * (this.page - 1)
    },
    selectedRows () {
      if (this.selectionMode === 'single') {
        return this.singleSelectedRow ? [this.singleSelectedRow] : []
      }
      return this.data.filter(row => row.__selected === true)
    },
    actionsModel () {
      let index = -1

      return this.selectionActions.map(item => {
        return {
          label: item.label,
          value: ++index
        }
      })
    }
  },
  watch: {
    rowsPerPage (value) {
      this.page = 1
    },
    chosenColumnsModel (options) {
      for (let i = 0; i < this.columns.length; i++) {
        this.columns.$set(i, Utils.extend({}, this.columns[i], {
          hidden: !options.includes(this.columns[i].field)
        }))
      }
    },
    searchQuery (value) {
      this.$dispatch('filter', value)
    },
    showOnlySelected (value) {
      this.$dispatch('toggle-selection')
    },
    singleSelectedRow (value) {
      this.$dispatch('set-single-selection', [value])
    }
  },
  methods: {
    goToPageByOffset (pageOffset) {
      this.page = Math.min(this.pagesNumber, Math.max(1, this.page + pageOffset))
    },
    sortBy (field) {
      if (!this.sortable) {
        return
      }

      // if sort field got changed
      if (this.sortField !== field) {
        this.sortOrder = 1
        this.sortField = field
        return
      }

      // else we sort on same field
      if (this.sortOrder === -1) {
        this.sortField = ''
      }
      else {
        this.sortOrder = -1
      }
    },
    getChosenColumn () {
      return this.columns
        .filter(column => column.hidden !== true)
        .map(column => column.field)
    },
    clearSelection () {
      if (this.selectionMode === 'single') {
        this.singleSelectedRow = null
      }
      else {
        this.data.forEach(row => {
          if (row.hasOwnProperty('__selected')) {
            row.__selected = false
          }
        })
      }

      this.showOnlySelected = false
    },
    clearFilter () {
      this.searchQuery = ''
      this.controls = ''
    },
    toggleControls (mode) {
      this.controls = this.controls === mode ? '' : mode
    },
    chooseAction () {
      let
        options = this.actionsModel,
        selectedRows = this.selectedRows,
        actions = this.selectionActions

      if (selectedRows.length === 0) {
        return
      }

      Dialog.create({
        title: 'Actions',
        message: 'Apply action for the ' + selectedRows.length + ' selected row(s).',
        radios: options,
        buttons: [
          'Cancel',
          {
            label: 'Apply',
            handler (data) {
              actions[data].handler(selectedRows)
            }
          }
        ]
      }).show()
    }
  }
}

var InfiniteScroll = { template: "<div class=\"quasar-infinite-scroll\"><div v-el:content class=\"quasar-infinite-scroll-content\"><slot></slot></div><br><div class=\"quasar-infinite-scroll-message\" v-show=\"fetching\"><slot name=\"message\"></slot></div></div>",
  props: {
    handler: {
      type: Function,
      required: true
    },
    inline: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    offset: {
      type: Number,
      default: 0
    },
    working: {
      type: Boolean,
      default: true,
      coerce: Boolean,
      twoWay: true
    }
  },
  data () {
    return {
      index: 0,
      fetching: false
    }
  },
  watch: {
    working (value) {
      this.scrollContainer[value ? 'addEventListener' : 'removeEventListener']('scroll', this.scroll)
      if (value) {
        this.scroll()
      }
    }
  },
  methods: {
    scroll () {
      if (this.fetching || !this.working) {
        return
      }

      let
        containerHeight = Utils.dom.height(this.scrollContainer),
        containerBottom = Utils.dom.offset(this.scrollContainer).top + containerHeight,
        triggerPosition = Utils.dom.offset(this.element).top + Utils.dom.height(this.element) - (this.offset || containerHeight)

      if (triggerPosition < containerBottom) {
        this.loadMore()
      }
    },
    loadMore () {
      if (this.fetching || !this.working) {
        return
      }

      this.index++
      this.fetching = true
      this.handler(this.index, stopLoading => {
        this.fetching = false
        if (stopLoading) {
          this.stop()
          return
        }
        if (this.element.closest('body')) {
          this.scroll()
        }
      })
    },
    reset () {
      this.index = 0
    },
    resume () {
      this.working = true
    },
    stop () {
      this.working = false
    }
  },
  ready () {
    this.scroll = Utils.debounce(this.scroll, 50)
    this.element = this.$els.content

    this.scrollContainer = this.inline ? this.$el : this.element.closest('.layout-view')
    if (!this.scrollContainer) {
      this.scrollContainer = window
    }
    if (this.working) {
      this.scrollContainer.addEventListener('scroll', this.scroll)
    }

    this.scroll()
  },
  beforeDestroy () {
    this.scrollContainer.removeEventListener('scroll', this.scroll)
  }
}

var Knob = { template: "<div class=\"quasar-knob non-selectable cursor-pointer\" :class=\"{disabled: disable}\" :style=\"{width: size, height: size}\" @mousedown=\"__dragStart\" @mousemove=\"__dragMove\" @mouseup=\"__dragStop\" @touchstart=\"__dragStart\" @touchmove=\"__dragMove\" @touchend=\"__dragStop\"><svg viewBox=\"0 0 100 100\"><path d=\"M 50,50 m 0,-47\n         a 47,47 0 1 1 0,94\n         a 47,47 0 1 1 0,-94\" :stroke=\"trackColor\" :stroke-width=\"lineWidth\" fill-opacity=\"0\"></path><path stroke-linecap=\"round\" fill-opacity=\"0\" d=\"M 50,50 m 0,-47\n         a 47,47 0 1 1 0,94\n         a 47,47 0 1 1 0,-94\" :stroke=\"color\" :stroke-width=\"lineWidth\" :style=\"svgStyle\"></path></svg><div class=\"quasar-knob-label row items-center justify-center content-center\" :style=\"{color: color}\">{{{ placeholder || model }}}</div></div>",
  props: {
    model: {
      type: Number,
      required: true,
      twoWay: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    min: {
      type: Number,
      default: 0
    },
    max: {
      type: Number,
      default: 100
    },
    color: {
      type: String,
      default: '#027be3'
    },
    trackColor: {
      type: String,
      default: '#ececec'
    },
    lineWidth: {
      type: String,
      default: '6px'
    },
    size: {
      type: String,
      default: '100px'
    },
    step: {
      type: Number,
      default: 1
    },
    placeholder: String
  },
  computed: {
    svgStyle () {
      return {
        'stroke-dasharray': '295.31px, 295.31px',
        'stroke-dashoffset': (295.31 * (1.0 - (this.model - this.min) / (this.max - this.min))) + 'px',
        'transition': this.dragging ? '' : 'stroke-dashoffset 0.6s ease 0s, stroke 0.6s ease'
      }
    }
  },
  data () {
    return {
      dragging: false
    }
  },
  watch: {
    model (value) {
      if (value < this.min) {
        this.model = this.min
      }
      else if (value > this.max) {
        this.model = this.max
      }
    }
  },
  methods: {
    __dragStart (ev) {
      if (this.disable) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()

      let knobOffset = Utils.dom.offset(this.$el)

      this.centerPosition = {
        top: knobOffset.top + Utils.dom.height(this.$el) / 2,
        left: knobOffset.left + Utils.dom.width(this.$el) / 2
      }

      this.dragging = true
      this.__updateModel(ev)
    },
    __dragMove (ev) {
      if (!this.dragging || this.disable) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()
      this.__updateModel(ev)
    },
    __dragStop (ev) {
      if (this.disable) {
        return
      }
      ev.stopPropagation()
      ev.preventDefault()
      this.dragging = false
    },
    __updateModel (ev) {
      let
        position = Utils.event.position(ev),
        height = Math.abs(position.top - this.centerPosition.top),
        distance = Math.sqrt(
          Math.pow(Math.abs(position.top - this.centerPosition.top), 2) +
          Math.pow(Math.abs(position.left - this.centerPosition.left), 2)
        ),
        angle = Math.asin(height / distance) * (180 / Math.PI)

      if (position.top < this.centerPosition.top) {
        angle = this.centerPosition.left < position.left ? 90 - angle : 270 + angle
      }
      else {
        angle = this.centerPosition.left < position.left ? angle + 90 : 270 - angle
      }

      let
        model = this.min + (angle / 360) * (this.max - this.min),
        modulo = model % this.step

      this.model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)))
    }
  }
}

var Layout = { template: "<div class=\"layout\"><div class=\"layout-header\"><slot name=\"header\"></slot></div><slot name=\"navigation\"></slot><div class=\"layout-content\"><slot></slot></div><div class=\"layout-footer\"><slot name=\"footer\"></slot></div></div>",}

var ToolbarTitle = { template: "<div class=\"toolbar-content\"><div class=\"toolbar-title\" :class=\"['padding-' + padding]\"><div><slot></slot></div></div></div>",
  props: {
    padding: {
      type: Number,
      default: 1
    }
  }
}

var Modal$2 = { template: "<div class=\"modal hidden fullscreen flex items-center justify-center\"><div class=\"modal-backdrop backdrop\"></div><div class=\"modal-content\"><slot></slot></div></div>",
  props: {
    set: Object,
    css: Object
  },
  methods: {
    show (onShow) {
      if (this.modal) {
        console.warn('Trying to show modal while it is being displayed.')
        return
      }

      this.modal = Modal$1.create(this.$el)
        .set(this.set || {})
        .css(this.css || {})
        .onClose(() => {
          this.modal = null
        })
        .show(onShow)
    },
    close (onClose) {
      if (!this.modal) {
        console.warn('Trying to close modal but no modal exists.')
      }

      this.modal.close(onClose)
    }
  },
  beforeDestroy () {
    if (this.modal) {
      this.modal.destroy()
    }
  }
}

var Numeric = { template: "<div class=\"quasar-numeric textfield row inline items-center\" :class=\"{disabled: disable}\"><i @click=\"setByOffset(-1)\">remove</i> <input class=\"no-style auto\" type=\"text\" v-model=\"model\" class=\"quasar-input-field\" :style=\"{width: (''+model).length * .7 + 'em'}\" v-attr=\"attrib\" number> <i @click=\"setByOffset(1)\">add</i></div>",
  props: {
    model: {
      type: Number,
      default: 0,
      coerce: value => parseFloat(value, 10) || 0
    },
    step: {
      type: Number,
      default: 1,
      coerce: value => parseFloat(value, 10)
    },
    min: Number,
    max: Number,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  watch: {
    model () {
      this.$nextTick(this.validate)
    }
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  },
  methods: {
    validate () {
      if (typeof this.min === 'number' && this.model < this.min && this.model !== 0) {
        this.model = this.min
      }
      else if (typeof this.max === 'number' && this.model > this.max) {
        this.model = this.max
      }
    },
    setByOffset (direction) {
      if (!this.disable) {
        this.model += direction * this.step
      }
    }
  }
}

var Pagination = { template: "<div class=\"quasar-pagination\" :class=\"{disabled: disable}\"><button :class=\"{disabled: model === min}\" class=\"primary clear small\" @click=\"changeModelTo(min)\"><i>first_page</i></button> <button :class=\"{disabled: model === min}\" class=\"primary clear small\" @click=\"changeModelByOffset(-1)\"><i>keyboard_arrow_left</i></button> <input v-el:input type=\"text\" v-model=\"newPage\" number lazy :style=\"{width: inputPlaceholder.length * 10 + 'px'}\" :placeholder=\"inputPlaceholder\" v-attr=\"attrib\"> <button :class=\"{disabled: model === max}\" class=\"primary clear small\" @click=\"changeModelByOffset(1)\"><i>keyboard_arrow_right</i></button> <button :class=\"{disabled: model === max}\" class=\"primary clear small\" @click=\"changeModelTo(max)\"><i>last_page</i></button></div>",
  props: {
    model: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: value => parseInt(value, 10)
    },
    min: {
      type: Number,
      default: 1
    },
    max: {
      type: Number,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      rangeMode: false,
      newPage: ''
    }
  },
  methods: {
    changeModelTo (value) {
      if (!this.disable) {
        this.model = this.normalize(value)
      }
    },
    changeModelByOffset (offset) {
      if (!this.disable) {
        this.model = this.normalize(this.model + offset)
      }
    },
    normalize (value) {
      return Math.min(this.max, Math.max(1, value))
    }
  },
  computed: {
    inputPlaceholder () {
      return this.model + ' / ' + this.max
    },
    attrib () {
      return this.disable ? 'disabled' : []
    }
  },
  watch: {
    newPage (value) {
      var parsed = parseInt(value, 10)

      if (parsed) {
        this.model = this.normalize(parsed)
        this.$els.input.blur()
      }

      this.newPage = ''
    }
  }
}

var Parallax = { template: "<div class=\"quasar-parallax column items-center justify-center\" :style=\"{height: height + 'px'}\"><div class=\"quasar-parallax-image\"><img v-el:img :src=\"src\" @load=\"processImage()\" :class=\"{ready: imageHasBeenLoaded}\" style=\"transform: translate3D(-50%, 0, 0)\"></div><div class=\"quasar-parallax-text\"><slot name=\"loading\" v-if=\"!imageHasBeenLoaded\"></slot><slot v-else></slot></div></div>",
  props: {
    src: {
      type: String,
      required: true
    },
    height: {
      type: Number,
      default: 500
    },
    speed: {
      type: Number,
      default: 1,
      validator (value) {
        return value >= 0 && value <= 1
      }
    }
  },
  data () {
    return {
      imageHasBeenLoaded: false
    }
  },
  watch: {
    src () {
      this.imageHasBeenLoaded = false
    },
    height () {
      this.updatePosition()
    }
  },
  methods: {
    processImage () {
      this.imageHasBeenLoaded = true
      this.processResize()
    },
    processResize () {
      if (!this.imageHasBeenLoaded || !this.scrollTarget) {
        return
      }

      this.imageHeight = Utils.dom.height(this.image)
      this.updatePosition()
    },
    updatePosition () {
      if (!this.imageHasBeenLoaded) {
        return
      }

      let containerTop, containerHeight, containerBottom, top, bottom

      if (this.scrollTarget === window) {
        containerTop = 0
        containerHeight = Utils.dom.viewport().height
        containerBottom = containerHeight
      }
      else {
        containerTop = Utils.dom.offset(this.scrollTarget).top
        containerHeight = Utils.dom.height(this.scrollTarget)
        containerBottom = containerTop + containerHeight
      }
      top = Utils.dom.offset(this.container).top
      bottom = top + this.height

      if (bottom > containerTop && top < containerBottom) {
        let percentScrolled = (containerBottom - top) / (this.height + containerHeight)
        let imageOffset = Math.round((this.imageHeight - this.height) * percentScrolled * this.speed)
        requestAnimationFrame(() => {
          this.$els.img.style.transform = 'translate3D(-50%,' + imageOffset + 'px, 0)'
        })
      }
    }
  },
  ready () {
    this.container = this.$el
    this.image = this.$els.img

    this.scrollTarget = Utils.dom.getScrollTarget(this.$el)
    this.resizeHandler = Utils.debounce(this.processResize, 50)

    window.addEventListener('resize', this.resizeHandler)
    this.scrollTarget.addEventListener('scroll', this.updatePosition)
    this.processResize()
  },
  beforeDestroy () {
    window.removeEventListener('resize', this.resizeHandler)
    this.scrollTarget.removeEventListener('scroll', this.updatePosition)
  }
}

const offset$1 = 20;
const cssReset = {
    top: '',
    bottom: '',
    left: '',
    right: '',
    minWidth: '',
    maxHeight: '',
    maxWidth: '',
    transformOrigin: ''
  }

var Popover = { template: "<span class=\"quasar-popover-target\"><slot name=\"target\"></slot><div v-el:content class=\"quasar-popover-content\" :class=\"{active: active}\"><slot></slot></div></span>",
  data () {
    return {
      active: false
    }
  },
  props: {
    touchPosition: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    position: String,
    cover: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  methods: {
    toggle (event) {
      this[this.active ? 'close' : 'open'](event)
    },
    open (event) {
      if (this.disable || this.active || this.inProgress) {
        return
      }

      event.preventDefault()

      let
        content = this.$els.content,
        target = this.$el.children[0],
        targetWidth = Utils.dom.width(target),
        targetHeight = Utils.dom.height(target),
        targetPosition = target.getBoundingClientRect(),
        position,
        css = Utils.extend({}, cssReset)

      if (this.cover) {
        css.minWidth = targetWidth + 'px'
      }
      Utils.dom.css(content, css)

      // necessary to compute menu width and height
      content.classList.add('check')
      content.scrollTop = 0

      let
        viewport = Utils.dom.viewport(),
        windowWidth = viewport.width,
        windowHeight = viewport.height,
        contentWidth = Utils.dom.width(content),
        contentHeight = Utils.dom.height(content)

      if (this.touchPosition) {
        let touchPosition = Utils.event.position(event)
        position = {
          top: touchPosition.top,
          left: touchPosition.left
        }
      }
      else {
        position = {
          top: targetPosition.top,
          left: targetPosition.left
        }
      }

      let
        toRight = position.left + contentWidth < windowWidth || 2 * position.left < windowWidth,
        toBottom = position.top + contentHeight < windowHeight || 2 * position.top < windowHeight

      content.classList.remove('check', 'left', 'right', 'bottom', 'top')

      if (this.position) {
        let position = this.position.split(' ')

        if (position.includes('left')) {
          toRight = false
        }
        else if (position.includes('right')) {
          toRight = true
        }

        if (position.includes('top')) {
          toBottom = false
        }
        else if (position.includes('bottom')) {
          toBottom = true
        }
      }

      if (this.touchPosition) {
        if (!toRight) {
          position.left -= contentWidth
        }
      }
      else {
        if (!toBottom) {
          position.top += targetHeight
        }
        if (!toRight) {
          position.left += targetWidth - contentWidth
        }
      }

      if (toRight) {
        content.classList.add('left')
        css.left = position.left + 'px'
        if (windowWidth - position.left < contentWidth) {
          css.maxWidth = (windowWidth - position.left - offset$1) + 'px'
        }
      }
      else {
        content.classList.add('right')
        css.left = position.left + 'px'
        if (position.left < contentWidth) {
          css.maxWidth = (position.left - offset$1) + 'px'
        }
      }

      if (toBottom) {
        content.classList.add('top')
        css.top = position.top + 'px'
        if (windowHeight - position.top < contentHeight) {
          css.maxHeight = (windowHeight - position.top - offset$1) + 'px'
        }
      }
      else {
        content.classList.add('bottom')
        css.bottom = (windowHeight - position.top) + 'px'
        if (position.top < contentHeight) {
          css.maxHeight = (position.top - offset$1) + 'px'
        }
      }

      Utils.dom.css(content, css)
      this.active = true
      this.inProgress = true

      // give a little timeout so that click
      // event won't be triggered immediately
      setTimeout(() => {
        document.addEventListener('click', this.closeFromOutside)
        this.scrollTarget = Utils.dom.getScrollTarget(target)
        this.scrollTarget.addEventListener('scroll', this.close)
        EscapeKey.register(() => { this.close() })
        this.inProgress = false
      }, 210)
    },
    close () {
      if (this.active && !this.inProgress) {
        this.active = false
        this.inProgress = true
        setTimeout(() => {
          if (this.$els.content) {
            Utils.dom.css(this.$els.content, cssReset)
          }
          this.inProgress = false
        }, 200)

        if (this.scrollTarget) {
          this.scrollTarget.removeEventListener('scroll', this.close)
          this.scrollTarget = null
        }
        document.removeEventListener('click', this.closeFromOutside)
        EscapeKey.pop()
      }
    },
    closeFromOutside (event) {
      if (!this.active || this.$els.content === event.target.closest('.quasar-popover-content')) {
        return
      }
      this.close()
    }
  },
  ready () {
    this.$el.children[0].addEventListener('click', this.toggle)
  },
  beforeDestroy () {
    this.$el.children[0].removeEventListener('click', this.toggle)
    if (this.active) {
      this.close()
    }
  }
}

var Progress = { template: "<div class=\"quasar-progress\"><div :style=\"{width: model + '%'}\"></div></div>",
  props: {
    model: {
      type: Number,
      default: 0
    }
  }
}

var ProgressButton = { template: "<button class=\"quasar-progress-button\" :class=\"{active: active, indeterminate: indeterminate}\"><span v-if=\"!indeterminate\" class=\"quasar-progress-button-filler\" :class=\"{'quasar-progress-button-dark-filler': darkFiller}\" :style=\"{width: computedPercentage}\"></span><div class=\"quasar-progress-button-content\" :class=\"state\"><div class=\"quasar-progress-button-error\"><i>{{ errorIcon }}</i></div><div class=\"quasar-progress-button-label\"><slot></slot></div><div class=\"quasar-progress-button-success\"><i>{{ successIcon }}</i></div></div></button>",
  props: {
    percentage: {
      type: Number,
      required: true
    },
    errorIcon: {
      type: String,
      default: 'warning'
    },
    successIcon: {
      type: String,
      default: 'done'
    },
    darkFiller: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    indeterminate: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    active () {
      return this.percentage > 0 && this.percentage < 100
    },
    state () {
      if (this.percentage >= 100) {
        return 'quasar-progress-button-complete'
      }
      if (this.percentage < 0) {
        return 'quasar-progress-button-incomplete'
      }
      return 'quasar-progress-button-default'
    },
    computedPercentage () {
      if (this.percentage >= 100) {
        return '0%'
      }

      return Math.max(0, this.percentage) + '%'
    }
  }
}

var PullToRefresh = { template: "<div class=\"pull-to-refresh\"><div class=\"pull-to-refresh-container\" :style=\"{transform: 'translateY(' + pullPosition + 'px)'}\" v-touch:pan=\"pull\" v-touch-options:pan=\"{ direction: 'vertical' }\"><div class=\"pull-to-refresh-message row items-center justify-center\"><i v-show=\"state !== 'refreshing'\" :class=\"{'rotate-180': state === 'pulled'}\">arrow_downward</i> <i v-else class=\"spin\">{{refreshIcon}}</i> &nbsp;&nbsp; <span v-show=\"state === 'pull'\">{{pullMessage}} </span><span v-show=\"state === 'pulled'\">{{releaseMessage}} </span><span v-show=\"state === 'refreshing'\">{{refreshMessage}}</span></div><slot></slot></div></div>",
  props: {
    handler: {
      type: Function,
      required: true
    },
    distance: {
      type: Number,
      default: 35
    },
    pullMessage: {
      type: String,
      default: 'Pull down to refresh'
    },
    releaseMessage: {
      type: String,
      default: 'Release to refresh'
    },
    refreshMessage: {
      type: String,
      default: 'Refreshing...'
    },
    refreshIcon: {
      type: String,
      default: 'refresh'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    let height = 65

    return {
      state: 'pull',
      pullPosition: -height,
      height: height,
      animating: false,
      pulling: false,
      scrolling: false
    }
  },
  methods: {
    pull (hammer) {
      if (this.scrolling) {
        if (hammer.isFinal) {
          this.scrolling = false
        }
        return
      }
      if (this.animating) {
        return
      }
      if (this.disable) {
        this.scrolling = false
        this.pulling = false
        this.animating = false
        this.state = 'pull'
        return
      }

      if (!this.pulling) {
        if (this.state === 'refreshing') {
          return
        }
        if (this.pullPosition === -this.height && hammer.direction === Hammer.DIRECTION_UP) {
          return
        }

        let
          containerTop = Utils.dom.offset(this.scrollContainer).top,
          thisContainerTop = Utils.dom.offset(this.$el).top

        if (containerTop > thisContainerTop) {
          this.scrolling = true
          return
        }

        this.originalScrollOverflow = this.scrollContainer.style.overflow
        this.scrollContainer.style.overflow = 'hidden'
      }

      this.pulling = true
      this.pullPosition = -this.height + Math.max(0, Math.pow(hammer.deltaY, 0.85))

      if (this.pullPosition > this.distance) {
        if (hammer.isFinal) {
          this.state = 'refreshing'
          this.pulling = false
          this.scrollContainer.style.overflow = this.originalScrollOverflow
          this.animateTo(0)
          this.trigger()
        }
        else {
          this.state = 'pulled'
        }
      }
      else {
        this.state = 'pull'
        if (hammer.isFinal) {
          this.pulling = false
          this.scrollContainer.style.overflow = this.originalScrollOverflow
          this.animateTo(-this.height)
        }
      }
    },
    animateTo (target, done, previousCall) {
      if (!previousCall && this.animationId) {
        cancelAnimationFrame(this.animating)
      }

      this.pullPosition -= (this.pullPosition - target) / 7

      if (this.pullPosition - target > 1) {
        this.animating = requestAnimationFrame(() => {
          this.animateTo(target, done, true)
        })
      }
      else {
        this.animating = requestAnimationFrame(() => {
          this.pullPosition = target
          this.animating = false
          done && done()
        })
      }
    },
    trigger () {
      this.handler(() => {
        this.animateTo(-this.height, () => {
          this.state = 'pull'
        })
      })
    }
  },
  ready () {
    this.scrollContainer = this.$el.parentNode
  }
}

var Radio = { template: "<label class=\"quasar-radio\" :class=\"{disabled: disable}\"><input type=\"radio\" v-model=\"model\" :value=\"value\" v-attr=\"attrib\"><div></div></label>",
  props: {
    model: {
      twoWay: true,
      required: true
    },
    value: {
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  }
}

var Range = { template: "<div class=\"quasar-range non-selectable\" :class=\"{disabled: disable}\" @mousedown.prevent=\"setActive\" @touchstart.prevent=\"setActive\" @touchend.prevent=\"end\" @touchmove.prevent=\"update\"><div v-el:handle class=\"quasar-range-handle-container\"><div class=\"quasar-range-track\"></div><div v-if=\"markers\" class=\"quasar-range-mark\" v-for=\"n in ((this.max - this.min) / this.step + 1)\" :style=\"{left: n * 100 * this.step / (this.max - this.min) + '%'}\"></div><div class=\"quasar-range-track active-track\" :style=\"{width: percentage}\" :class=\"{'no-transition': dragging, 'handle-at-minimum': model === min}\"></div><div class=\"quasar-range-handle\" :style=\"{left: percentage}\" :class=\"{dragging: dragging, 'handle-at-minimum': model === min}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ model }}</div></div></div></div>",
  props: {
    model: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: value => parseInt(value, 10)
    },
    min: {
      type: Number,
      default: 1,
      coerce: value => parseInt(value, 10)
    },
    max: {
      type: Number,
      default: 5,
      coerce: value => parseInt(value, 10)
    },
    step: {
      type: Number,
      default: 1,
      coerce: value => parseInt(value, 10)
    },
    snap: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    markers: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    label: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      dragging: false,
      currentPercentage: (this.model - this.min) / (this.max - this.min)
    }
  },
  computed: {
    percentage () {
      if (this.snap) {
        return (this.model - this.min) / (this.max - this.min) * 100 + '%'
      }
      return 100 * this.currentPercentage + '%'
    }
  },
  watch: {
    model (value) {
      if (this.dragging) {
        return
      }
      this.currentPercentage = (value - this.min) / (this.max - this.min)
    },
    min (value) {
      if (this.model < value) {
        this.model = value
        return
      }
      this.$nextTick(this.validateProps)
    },
    max (value) {
      if (this.model > value) {
        this.model = value
        return
      }
      this.$nextTick(this.validateProps)
    },
    step () {
      this.$nextTick(this.validateProps)
    }
  },
  methods: {
    setActive (event) {
      if (this.disable) {
        return
      }

      let container = this.$els.handle

      this.dragging = {
        left: container.getBoundingClientRect().left,
        width: container.offsetWidth
      }
      this.update(event)
    },
    update (event) {
      if (!this.dragging) {
        return
      }

      let
        percentage = Math.min(1, Math.max(0, (Utils.event.position(event).left - this.dragging.left) / this.dragging.width)),
        model = this.min + percentage * (this.max - this.min),
        modulo = model % this.step

      this.currentPercentage = percentage
      this.model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)))
    },
    end () {
      this.dragging = false
      this.currentPercentage = (this.model - this.min) / (this.max - this.min)
    },
    validateProps () {
      if (this.min >= this.max) {
        console.error('Range error: min >= max', this.$el, this.min, this.max)
      }
      else if ((this.max - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of max - min', this.$el, this.min, this.max, this.step)
      }
    }
  },
  beforeCompile () {
    this.validateProps()
    if (Platform.is.desktop) {
      document.body.addEventListener('mousemove', this.update)
      document.body.addEventListener('mouseup', this.end)
    }
  },
  beforeDestroy () {
    if (Platform.is.dekstop) {
      document.body.removeEventListener('mousemove', this.update)
      document.body.removeEventListener('mouseup', this.end)
    }
  }
}

var DoubleRange = { template: "<div class=\"quasar-range non-selectable\" :class=\"{disabled: disable}\" @mousedown.prevent=\"setActive\" @touchstart.prevent=\"setActive\" @touchend.prevent=\"end\" @touchmove.prevent=\"update\"><div v-el:handle class=\"quasar-range-handle-container\"><div class=\"quasar-range-track\"></div><div v-if=\"markers\" class=\"quasar-range-mark\" v-for=\"n in ((this.max - this.min) / this.step + 1)\" :style=\"{left: n * 100 * this.step / (this.max - this.min) + '%'}\"></div><div class=\"quasar-range-track active-track no-transition\" :style=\"{left: percentageMin * 100 + '%', width: activeTrackWidth}\"></div><div class=\"quasar-range-handle no-transition\" :style=\"{left: percentageMin * 100 + '%'}\" :class=\"{dragging: dragging, 'handle-at-minimum': modelMin === min}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ modelMin }}</div></div><div class=\"quasar-range-handle no-transition\" :style=\"{left: percentageMax * 100 + '%'}\" :class=\"{dragging: dragging}\"><div class=\"quasar-range-label\" v-if=\"label\">{{ modelMax }}</div></div></div></div>",
  props: {
    modelMin: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: value => parseInt(value, 10)
    },
    modelMax: {
      type: Number,
      twoWay: true,
      required: true,
      coerce: value => parseInt(value, 10)
    },
    min: {
      type: Number,
      default: 0,
      coerce: value => parseInt(value, 10)
    },
    max: {
      type: Number,
      default: 100,
      coerce: value => parseInt(value, 10)
    },
    step: {
      type: Number,
      default: 1,
      coerce: value => parseInt(value, 10)
    },
    snap: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    markers: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    label: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      dragging: false,
      currentMinPercentage: (this.modelMin - this.min) / (this.max - this.min),
      currentMaxPercentage: (this.modelMax - this.min) / (this.max - this.min)
    }
  },
  computed: {
    percentageMin () {
      if (this.snap) {
        return (this.modelMin - this.min) / (this.max - this.min)
      }
      return this.currentMinPercentage
    },
    percentageMax () {
      if (this.snap) {
        return (this.modelMax - this.min) / (this.max - this.min)
      }
      return this.currentMaxPercentage
    },
    activeTrackWidth () {
      return 100 * (this.percentageMax - this.percentageMin) + '%'
    }
  },
  watch: {
    modelMin (value) {
      if (this.dragging) {
        return
      }
      if (value > this.modelMax) {
        value = this.modelMax
      }
      this.currentMinPercentage = (value - this.min) / (this.max - this.min)
    },
    modelMax (value) {
      if (this.dragging) {
        return
      }
      if (value < this.modelMin) {
        value = this.modelMin
      }
      this.currentMaxPercentage = (value - this.min) / (this.max - this.min)
    },
    min (value) {
      if (this.modelMin < value) {
        this.modelMin = value
      }
      if (this.modelMax < value) {
        this.modelMax = value
      }
      this.$nextTick(this.validateProps)
    },
    max (value) {
      if (this.modelMin > value) {
        this.modelMin = value
      }
      if (this.modelMax > value) {
        this.modelMax = value
      }
      this.$nextTick(this.validateProps)
    },
    step () {
      this.$nextTick(this.validateProps)
    }
  },
  methods: {
    setActive (event) {
      if (this.disable) {
        return
      }

      let container = this.$els.handle

      this.dragging = {
        left: container.getBoundingClientRect().left,
        width: container.offsetWidth,
        modelMin: this.modelMin,
        percentageMin: this.currentMinPercentage,
        modelMax: this.modelMax,
        percentageMax: this.currentMaxPercentage
      }

      let
        offset = Utils.event.position(event).left - this.dragging.left,
        percentage = Math.min(1, Math.max(0, offset / this.dragging.width))

      this.dragging.onLeft = Math.abs(percentage - this.currentMinPercentage) <= Math.abs(percentage - this.currentMaxPercentage)
      this.update(event)
    },
    update (event) {
      if (!this.dragging) {
        return
      }

      let
        percentage = Math.min(1, Math.max(0, (Utils.event.position(event).left - this.dragging.left) / this.dragging.width)),
        model = this.min + percentage * (this.max - this.min),
        modulo = model % this.step

      model = Math.min(this.max, Math.max(this.min, model - modulo + (Math.abs(modulo) >= this.step / 2 ? (modulo < 0 ? -1 : 1) * this.step : 0)))

      if (this.dragging.onLeft) {
        if (percentage <= this.dragging.percentageMax) {
          this.currentMinPercentage = percentage
          this.modelMin = model

          this.currentMaxPercentage = this.dragging.percentageMax
          this.modelMax = this.dragging.modelMax
        }
        else {
          this.currentMinPercentage = this.dragging.percentageMax
          this.modelMin = this.dragging.modelMax

          this.currentMaxPercentage = percentage
          this.modelMax = model
        }
      }
      else {
        if (percentage >= this.dragging.percentageMin) {
          this.currentMaxPercentage = percentage
          this.modelMax = model

          this.currentMinPercentage = this.dragging.percentageMin
          this.modelMin = this.dragging.modelMin
        }
        else {
          this.currentMaxPercentage = this.dragging.percentageMin
          this.modelMax = this.dragging.modelMin

          this.currentMinPercentage = percentage
          this.modelMin = model
        }
      }
    },
    end () {
      this.dragging = false
      this.currentMinPercentage = (this.modelMin - this.min) / (this.max - this.min)
      this.currentMaxPercentage = (this.modelMax - this.min) / (this.max - this.min)
    },
    validateProps () {
      if (this.min >= this.max) {
        console.error('Range error: min >= max', this.$el, this.min, this.max)
      }
      else if ((this.max - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of max - min', this.$el, this.min, this.max, this.step)
      }
      else if ((this.modelMin - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of initial modelMin - min', this.$el, this.modelMin, this.min, this.step)
      }
      else if ((this.modelMax - this.min) % this.step !== 0) {
        console.error('Range error: step must be a divisor of initial modelMax - min', this.$el, this.modelMax, this.max, this.step)
      }
    }
  },
  beforeCompile () {
    this.validateProps()
    if (Platform.is.desktop) {
      document.body.addEventListener('mousemove', this.update)
      document.body.addEventListener('mouseup', this.end)
    }
  },
  beforeDestroy () {
    if (Platform.is.dekstop) {
      document.body.removeEventListener('mousemove', this.update)
      document.body.removeEventListener('mouseup', this.end)
    }
  }
}

var Rating = { template: "<div class=\"quasar-rating\" :class=\"{disabled: disable}\"><i v-for=\"index in maxGrade\" :class=\"{active: (!mouseModel && model > index) || (mouseModel && mouseModel > index)}\" @click=\"set(index + 1)\" @mouseover=\"setHoverValue(index + 1)\" @mouseout=\"mouseModel = 0\">{{icon}}</i></div>",
  props: {
    model: {
      type: Number,
      default: 0,
      required: true
    },
    maxGrade: {
      type: Number,
      required: true
    },
    icon: {
      type: String,
      default: 'grade'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      mouseModel: 0
    }
  },
  methods: {
    set (value) {
      if (!this.disable) {
        this.model = this.normalize(value)
      }
    },
    setHoverValue (value) {
      if (!this.disable) {
        this.mouseModel = value
      }
    },
    normalize (value) {
      return Math.min(this.maxGrade, Math.max(1, value))
    }
  }
}

var Search = { template: "<div class=\"quasar-search\" :class=\"{'quasar-search-centered': !this.focused && this.model === '', disabled: disable}\"><div class=\"quasar-search-input-container\"><button class=\"quasar-search-icon\"><i>{{ icon }}</i></button> <input type=\"text\" class=\"quasar-search-input no-style\" :placeholder=\"placeholder\" v-model=\"model\" :debounce=\"debounce\" @focus=\"focused = true\" @blur=\"focused = false\" v-attr=\"attrib\"> <button class=\"quasar-search-clear\" @click=\"clear()\" :class=\"{hidden: this.model === ''}\"><i class=\"mat-only\">clear</i> <i class=\"ios-only\">cancel</i></button></div></div>",
  props: {
    model: {
      type: String,
      default: ''
    },
    debounce: {
      type: Number,
      default: 300
    },
    icon: {
      type: String,
      default: 'search'
    },
    placeholder: {
      type: String,
      default: 'Search'
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      focused: false
    }
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  },
  methods: {
    clear () {
      if (!this.disable) {
        this.model = ''
      }
    }
  }
}

var Select = { template: "<div class=\"quasar-select-container\"><quasar-popover v-ref:popover :disable=\"disable\" cover><div slot=\"target\" class=\"cursor-pointer textfield\" @click=\"__parseOptions\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div><div class=\"list highlight\"><label v-if=\"type === 'radio'\" v-for=\"radio in options\" class=\"item\" @click=\"close\"><div class=\"item-primary\"><quasar-radio :model.sync=\"model\" :value.once=\"radio.value\"></quasar-radio></div><div class=\"item-content\">{{{* radio.label}}}</div></label><button v-if=\"type === 'checkbox' || type === 'toggle'\" class=\"primary clear small full-width\" @click=\"$refs.popover.close()\">Close</button><label v-if=\"type === 'checkbox'\" v-for=\"checkbox in options\" class=\"item\"><div class=\"item-primary\"><quasar-checkbox :model.sync=\"multipleOptions[$index]\"></quasar-checkbox></div><div class=\"item-content\">{{{* checkbox.label}}}</div></label><label v-if=\"type === 'toggle'\" v-for=\"toggle in options\" class=\"item\"><div class=\"item-content has-secondary\">{{{* toggle.label}}}</div><div class=\"item-secondary\"><quasar-toggle :model.sync=\"multipleOptions[$index]\"></quasar-toggle></div></label></div></quasar-popover></div>",
  data () {
    return {
      multipleOptions: [],
      skipModelUpdate: false
    }
  },
  props: {
    model: {
      required: true,
      twoWay: true
    },
    options: {
      type: Array,
      required: true,
      validator: options => {
        return !options.some(option =>
          typeof option.label === 'undefined' || typeof option.value === 'undefined'
        )
      }
    },
    type: {
      type: String,
      required: true,
      validator (value) {
        return ['radio', 'checkbox', 'toggle'].includes(value)
      }
    },
    placeholder: String,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label () {
      return this.placeholder || (this.type === 'radio' ? this.__getSingleLabel() : this.__getMultipleLabel())
    },
    multiple () {
      return this.type !== 'radio'
    }
  },
  watch: {
    multipleOptions: {
      deep: true,
      handler (options) {
        if (!this.multiple || this.skipModelUpdate) {
          this.skipModelUpdate = false
          return
        }

        let index = 0
        let model = []

        options.forEach(option => {
          if (option) {
            model.push(this.options[index].value)
          }
          index++
        })

        this.model = model
      }
    }
  },
  methods: {
    __getSingleLabel () {
      let option = this.options.find(option => option.value === this.model)
      return option ? option.label : 'Select'
    },
    __getMultipleLabel () {
      let options = this.options
        .filter(option => this.model.includes(option.value))
        .map(option => option.label)

      if (options.length === 0) {
        return 'Select'
      }
      else if (options.length > 1) {
        return options[0] + ' and ' + (options.length - 1) + ' more'
      }
      return options[0]
    },
    __parseOptions () {
      if (!Array.isArray(this.options)) {
        throw new Error('Select options parameter must be an array.')
      }
      if (this.options.some(
        option => typeof option.label === 'undefined' || typeof option.value === 'undefined'
      )) {
        throw new Error('One of Select\'s option is missing either label or value')
      }

      if (this.multiple) {
        this.skipModelUpdate = true
        this.multipleOptions = this.options.map(option => {
          return this.model.includes(option.value) || false
        })
      }
    },
    open (event) {
      if (this.disable) {
        return
      }
      this.parseOptions()
      this.$refs.popover.open(event)
    },
    close (event) {
      this.$refs.popover.close(event)
    }
  }
}

let mapTypeConfig = {
  radio: 'radios',
  checkbox: 'checkboxes',
  toggle: 'toggles'
}

var DialogSelect = { template: "<div class=\"quasar-select cursor-pointer textfield\" @click=\"pick\" :class=\"{disabled: disable}\"><span>{{{ label }}}</span><div class=\"float-right quasar-select-arrow caret-down\"></div></div>",
  props: {
    model: {
      required: true,
      twoWay: true
    },
    options: {
      type: Array,
      required: true,
      validator: options => {
        return !options.some(option =>
          typeof option.label === 'undefined' || typeof option.value === 'undefined'
        )
      }
    },
    type: {
      type: String,
      required: true,
      validator (value) {
        return ['radio', 'checkbox', 'toggle'].includes(value)
      }
    },
    okLabel: {
      type: String,
      default: 'OK'
    },
    cancelLabel: {
      type: String,
      default: 'Cancel'
    },
    title: {
      type: String,
      default: 'Select'
    },
    message: String,
    placeholder: String,
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  computed: {
    label () {
      return this.placeholder || (this.type === 'radio' ? this.__getSingleLabel() : this.__getMultipleLabel())
    }
  },
  methods: {
    __getSingleLabel () {
      let option = this.options.find((option) => option.value === this.model)
      return option ? option.label : 'Select'
    },
    __getMultipleLabel () {
      let options = this.options
        .filter((option) => this.model.includes(option.value))
        .map((option) => option.label)

      if (options.length === 0) {
        return 'Select'
      }
      else if (options.length > 1) {
        return options[0] + ' and ' + (options.length - 1) + ' more'
      }
      return options[0]
    },
    mapSingle (option) {
      option.selected = option.value === this.model
      return option
    },
    mapMultiple (option) {
      option.checked = this.model.includes(option.value)
      return option
    },
    pick () {
      if (this.disable) {
        return
      }

      let
        self = this,
        mapHandler = this.type === 'radio' ? this.mapSingle : this.mapMultiple,
        options = this.options.map(mapHandler.bind(this)),
        config = {
          title: self.title,
          message: self.message,
          buttons: [
            self.cancelLabel,
            {
              label: self.okLabel,
              handler (data) {
                self.model = data
              }
            }
          ]
        }

      config[mapTypeConfig[this.type]] = options

      Dialog.create(config).show()
    }
  }
}

var Slider = { template: "<div class=\"quasar-slider\" :class=\"{fullscreen: inFullscreen}\"><div class=\"quasar-slider-inner\"><div v-el:track class=\"quasar-slider-track\" :class=\"{'with-arrows': arrows, 'with-toolbar': toolbar}\" v-touch:pan=\"pan\" v-touch-options:pan=\"{ direction: 'horizontal' }\"><slot name=\"slide\"></slot></div><div v-if=\"arrows\" class=\"quasar-slider-left-button row items-center justify-center\" :class=\"{hidden: slide === 0}\"><i @click=\"goToSlide(slide - 1)\">keyboard_arrow_left</i></div><div v-if=\"arrows\" class=\"quasar-slider-right-button row items-center justify-center\" :class=\"{hidden: slide === slidesNumber - 1}\" @click=\"goToSlide(slide + 1)\"><i>keyboard_arrow_right</i></div><div v-if=\"toolbar\" class=\"quasar-slider-toolbar row items-center justify-end\"><div class=\"quasar-slider-dots auto row items-center justify-center\"><i v-if=\"dots\" v-for=\"n in slidesNumber\" @click=\"goToSlide(n)\"><span v-show=\"n !== slide\">panorama_fish_eye</span> <span v-else>lens</span></i></div><div class=\"row items-center\"><slot name=\"action\"></slot><i v-if=\"fullscreen\" @click=\"toggleFullscreen()\"><span v-show=\"!inFullscreen\">fullscreen</span> <span v-else>fullscreen_exit</span></i></div></div><slot></slot></div></div>",
  props: {
    arrows: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    dots: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    fullscreen: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    actions: {
      type: Boolean,
      default: false,
      coerce: Boolean
    }
  },
  data () {
    return {
      position: 0,
      slide: 0,
      slidesNumber: 0,
      inFullscreen: false
    }
  },
  computed: {
    toolbar () {
      return this.dots || this.fullscreen || this.actions
    }
  },
  methods: {
    pan (event) {
      if (!this.hasOwnProperty('initialPosition')) {
        this.initialPosition = this.position
        Velocity(this.$els.track, 'stop')
      }

      let delta = event.deltaX

      if (
        this.slide === 0 && event.deltaX > 0 ||
        this.slide === this.slidesNumber - 1 && event.deltaX < 0
      ) {
        delta = delta / 10
      }

      this.position = this.initialPosition + delta / this.$els.track.offsetWidth * 100
      this.$els.track.style.transform = 'translateX(' + this.position + '%)'

      if (event.isFinal) {
        if (event.distance < 100) {
          this.goToSlide(this.slide)
        }
        else {
          this.goToSlide(event.deltaX < 0 ? this.slide + 1 : this.slide - 1)
        }
        delete this.initialPosition
      }
    },
    goToSlide (slide, noAnimation) {
      this.slide = Math.min(this.slidesNumber - 1, Math.max(0, slide))

      Velocity(this.$els.track, 'stop')
      Velocity(this.$els.track, {
        translateX: [-this.slide * 100 + '%', this.position + '%']
      }, noAnimation ? {duration: 0} : undefined)

      this.position = -this.slide * 100
    },
    toggleFullscreen () {
      if (this.inFullscreen) {
        if (Platform.within.iframe) {
          this.inFullscreen = false
        }
        else {
          window.history.go(-1)
        }
        return
      }

      this.inFullscreen = true
      if (!Platform.within.iframe) {
        window.history.pushState({}, '')
        window.addEventListener('popstate', this.__popState)
      }
    },
    __popState () {
      if (this.inFullscreen) {
        this.inFullscreen = false
      }
      window.removeEventListener('popstate', this.__popState)
    }
  },
  ready () {
    this.slidesNumber = this.$els.track.children.length
  }
}

var audio = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 55 80\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"matrix(1 0 0 -1 0 80)\"><rect width=\"10\" height=\"20\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"4.3s\" values=\"20;45;57;80;64;32;66;45;64;23;66;13;64;56;34;34;2;23;76;79;20\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"15\" width=\"10\" height=\"80\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"80;55;33;5;75;23;73;33;12;14;60;80\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" width=\"10\" height=\"50\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1.4s\" values=\"50;34;78;23;56;23;34;76;80;54;21;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"45\" width=\"10\" height=\"30\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"30;45;13;80;56;72;45;76;34;23;67;30\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></g></svg>\n";

var ball = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 57 57\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle cx=\"5\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;5;50;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" values=\"5;27;49;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"27\" cy=\"5\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" from=\"5\" to=\"5\" values=\"5;50;50;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" from=\"27\" to=\"27\" values=\"27;49;5;27\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"49\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;50;5;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" from=\"49\" to=\"49\" begin=\"0s\" dur=\"2.2s\" values=\"49;5;27;49\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var bars = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 140\" xmlns=\"http://www.w3.org/2000/svg\"><rect y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"60\" width=\"15\" height=\"140\" rx=\"6\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"90\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"120\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></svg>\n";

var circles = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 135\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M67.447 58c5.523 0 10-4.477 10-10s-4.477-10-10-10-10 4.477-10 10 4.477 10 10 10zm9.448 9.447c0 5.523 4.477 10 10 10 5.522 0 10-4.477 10-10s-4.478-10-10-10c-5.523 0-10 4.477-10 10zm-9.448 9.448c-5.523 0-10 4.477-10 10 0 5.522 4.477 10 10 10s10-4.478 10-10c0-5.523-4.477-10-10-10zM58 67.447c0-5.523-4.477-10-10-10s-10 4.477-10 10 4.477 10 10 10 10-4.477 10-10z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"-360 67 67\" dur=\"2.5s\" repeatCount=\"indefinite\"/></path><path d=\"M28.19 40.31c6.627 0 12-5.374 12-12 0-6.628-5.373-12-12-12-6.628 0-12 5.372-12 12 0 6.626 5.372 12 12 12zm30.72-19.825c4.686 4.687 12.284 4.687 16.97 0 4.686-4.686 4.686-12.284 0-16.97-4.686-4.687-12.284-4.687-16.97 0-4.687 4.686-4.687 12.284 0 16.97zm35.74 7.705c0 6.627 5.37 12 12 12 6.626 0 12-5.373 12-12 0-6.628-5.374-12-12-12-6.63 0-12 5.372-12 12zm19.822 30.72c-4.686 4.686-4.686 12.284 0 16.97 4.687 4.686 12.285 4.686 16.97 0 4.687-4.686 4.687-12.284 0-16.97-4.685-4.687-12.283-4.687-16.97 0zm-7.704 35.74c-6.627 0-12 5.37-12 12 0 6.626 5.373 12 12 12s12-5.374 12-12c0-6.63-5.373-12-12-12zm-30.72 19.822c-4.686-4.686-12.284-4.686-16.97 0-4.686 4.687-4.686 12.285 0 16.97 4.686 4.687 12.284 4.687 16.97 0 4.687-4.685 4.687-12.283 0-16.97zm-35.74-7.704c0-6.627-5.372-12-12-12-6.626 0-12 5.373-12 12s5.374 12 12 12c6.628 0 12-5.373 12-12zm-19.823-30.72c4.687-4.686 4.687-12.284 0-16.97-4.686-4.686-12.284-4.686-16.97 0-4.687 4.686-4.687 12.284 0 16.97 4.686 4.687 12.284 4.687 16.97 0z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"360 67 67\" dur=\"8s\" repeatCount=\"indefinite\"/></path></svg>\n";

var dots = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 120 30\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"15\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"60\" cy=\"15\" r=\"9\" fill-opacity=\".3\"><animate attributeName=\"r\" from=\"9\" to=\"9\" begin=\"0s\" dur=\"0.8s\" values=\"9;15;9\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\".5\" to=\".5\" begin=\"0s\" dur=\"0.8s\" values=\".5;1;.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"105\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

var facebook = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" xmlns=\"http://www.w3.org/2000/svg\" preserveAspectRatio=\"xMidYMid\"><g transform=\"translate(20 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.6\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(50 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.8\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.1s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(80 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.9\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.2s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g></svg>\n";

var gears = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(-20,-20)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"90 50 50\" to=\"0 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g><g transform=\"translate(20,20) rotate(15 50 50)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"90 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g></svg>\n";

var grid = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 105 105\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"12.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"52.5\" r=\"12.5\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"100ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"300ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"600ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"800ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"400ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"700ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"500ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"200ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

var hearts = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 140 64\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M30.262 57.02L7.195 40.723c-5.84-3.976-7.56-12.06-3.842-18.063 3.715-6 11.467-7.65 17.306-3.68l4.52 3.76 2.6-5.274c3.716-6.002 11.47-7.65 17.304-3.68 5.84 3.97 7.56 12.054 3.842 18.062L34.49 56.118c-.897 1.512-2.793 1.915-4.228.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M105.512 56.12l-14.44-24.272c-3.716-6.008-1.996-14.093 3.843-18.062 5.835-3.97 13.588-2.322 17.306 3.68l2.6 5.274 4.52-3.76c5.84-3.97 13.593-2.32 17.308 3.68 3.718 6.003 1.998 14.088-3.842 18.064L109.74 57.02c-1.434 1.014-3.33.61-4.228-.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0.7s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M67.408 57.834l-23.01-24.98c-5.864-6.15-5.864-16.108 0-22.248 5.86-6.14 15.37-6.14 21.234 0L70 16.168l4.368-5.562c5.863-6.14 15.375-6.14 21.235 0 5.863 6.14 5.863 16.098 0 22.247l-23.007 24.98c-1.43 1.556-3.757 1.556-5.188 0z\"/></svg>\n";

var hourglass = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\"  viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g><path fill=\"none\" :stroke=\"color\" stroke-width=\"5\" stroke-miterlimit=\"10\" d=\"M58.4,51.7c-0.9-0.9-1.4-2-1.4-2.3s0.5-0.4,1.4-1.4 C70.8,43.8,79.8,30.5,80,15.5H70H30H20c0.2,15,9.2,28.1,21.6,32.3c0.9,0.9,1.4,1.2,1.4,1.5s-0.5,1.6-1.4,2.5 C29.2,56.1,20.2,69.5,20,85.5h10h40h10C79.8,69.5,70.8,55.9,58.4,51.7z\" class=\"glass\"></path><clipPath id=\"uil-hourglass-clip1\"><rect x=\"15\" y=\"20\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"25\" to=\"0\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"25;0;0\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"20\" to=\"45\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"20;45;45\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><clipPath id=\"uil-hourglass-clip2\"><rect x=\"15\" y=\"55\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"0\" to=\"25\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"0;25;25\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"80\" to=\"55\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"80;55;55\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><path d=\"M29,23c3.1,11.4,11.3,19.5,21,19.5S67.9,34.4,71,23H29z\" clip-path=\"url(#uil-hourglass-clip1)\" :fill=\"color\" class=\"sand\"></path><path d=\"M71.6,78c-3-11.6-11.5-20-21.5-20s-18.5,8.4-21.5,20H71.6z\" clip-path=\"url(#uil-hourglass-clip2)\" :fill=\"color\" class=\"sand\"></path><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"180 50 50\" repeatCount=\"indefinite\" dur=\"1s\" values=\"0 50 50;0 50 50;180 50 50\" keyTimes=\"0;0.7;1\"></animateTransform></g></svg>\n";

var infinity = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\"><path d=\"M24.3,30C11.4,30,5,43.3,5,50s6.4,20,19.3,20c19.3,0,32.1-40,51.4-40C88.6,30,95,43.3,95,50s-6.4,20-19.3,20C56.4,70,43.6,30,24.3,30z\" fill=\"none\" :stroke=\"color\" stroke-width=\"8\" stroke-dasharray='10.691205342610678 10.691205342610678' stroke-dashoffset=\"0\"><animate attributeName=\"stroke-dashoffset\" from=\"0\" to=\"21.382410685221355\" begin=\"0\" dur=\"2s\" repeatCount=\"indefinite\" fill=\"freeze\"></animate></path></svg>\n";

var ios = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(0 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(30 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.08333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(60 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.16666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(90 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.25s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(120 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.3333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(150 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.4166666666666667s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(180 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(210 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5833333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(240 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.6666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(270 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.75s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(300 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.8333333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(330 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.9166666666666666s' repeatCount='indefinite'/></rect></svg>\n";

var oval = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle stroke-opacity=\".5\" cx=\"18\" cy=\"18\" r=\"18\"/><path d=\"M36 18c0-9.94-8.06-18-18-18\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"1s\" repeatCount=\"indefinite\"/></path></g></svg>\n";

var pie = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M0 50A50 50 0 0 1 50 0L50 50L0 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"0.8s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 0A50 50 0 0 1 100 50L50 50L50 0\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"1.6s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M100 50A50 50 0 0 1 50 100L50 50L100 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"2.4s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 100A50 50 0 0 1 0 50L50 50L50 100\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"3.2s\" repeatCount=\"indefinite\"></animateTransform></path></svg>\n";

var puff = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 44 44\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"0s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var radio = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"scale(0.55)\"><circle cx=\"30\" cy=\"150\" r=\"30\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></circle><path d=\"M90,150h30c0-49.7-40.3-90-90-90v30C63.1,90,90,116.9,90,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.1\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path><path d=\"M150,150h30C180,67.2,112.8,0,30,0v30C96.3,30,150,83.7,150,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.2\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path></g></svg>\n";

var rings = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 45 45\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(1 1)\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"1.5s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"1.5s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"1.5s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"3s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"3s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"3s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"8\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.5s\" values=\"6;1;2;3;4;5;6\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

var tail = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><defs><linearGradient x1=\"8.042%\" y1=\"0%\" x2=\"65.682%\" y2=\"23.865%\" id=\"a\"><stop :stop-color=\"color\" stop-opacity=\"0\" offset=\"0%\"/><stop :stop-color=\"color\" stop-opacity=\".631\" offset=\"63.146%\"/><stop :stop-color=\"color\" offset=\"100%\"/></linearGradient></defs><g transform=\"translate(1 1)\" fill=\"none\" fill-rule=\"evenodd\"><path d=\"M36 18c0-9.94-8.06-18-18-18\" stroke=\"url(#a)\" stroke-width=\"2\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></path><circle :fill=\"color\" cx=\"36\" cy=\"18\" r=\"1\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

let templates = {
  audio,
  ball,
  bars,
  circles,
  dots,
  facebook,
  gears,
  grid,
  hearts,
  hourglass,
  infinity,
  ios,
  oval,
  pie,
  puff,
  radio,
  rings,
  tail
}

var registerSpinners = (_Vue) => {
  Object.keys(templates).forEach(spinner => {
    _Vue.partial('quasar-partial-' + spinner, templates[spinner])
  })

  _Vue.component('spinner', {
    template: '<span><partial :name="partialName"></partial></span>',
    props: {
      name: {
        type: String,
        default: current === 'ios' ? 'ios' : 'tail'
      },
      size: {
        type: Number,
        default: 64
      },
      color: {
        type: String,
        default: '#000'
      }
    },
    computed: {
      partialName () {
        return 'quasar-partial-' + this.name
      }
    }
  })
}

var State = { template: "<span><slot v-if=\"!model\"></slot><slot v-else name=\"active\"></slot></span>",
  props: {
    model: {
      type: Boolean,
      required: true,
      twoWay: true
    }
  }
}

var Stepper = { template: "<div class=\"quasar-stepper timeline primary\"><slot></slot></div>",
  events: {
    'stepper::reset' () {
      this.redraw()
    },
    'stepper::nextStep' () {
      this.nextStep()
    },
    'stepper::previousStep' () {
      this.previousStep()
    },
    'stepper::finish' () {
      this.finish()
    }
  },
  data () {
    return {
      config: {
        steps: 0,
        currentStep: 0
      }
    }
  },
  methods: {
    reset () {
      this.redraw()
      this.config.currentStep = 1
    },
    nextStep () {
      this.config.currentStep++
      if (this.config.currentStep > this.config.steps) {
        this.$emit('finish')
      }
    },
    previousStep () {
      this.config.currentStep--
    },
    finish () {
      this.config.currentStep = this.config.steps + 1
      this.$emit('finish')
    },
    redraw () {
      let step = 1

      this.config.currentStep = this.config.currentStep || 1
      this.config.steps = this.$children.length
      this.$children.forEach(child => {
        child.$set('stepper', this.config)
        child.step = step
        step++
      })
    }
  },
  beforeCompile () {
    this.reset = Utils.debounce(this.reset, 50)
  }
}

var Step = { template: "<div class=\"timeline-item\" :class=\"{incomplete: step > stepper.currentStep}\"><div class=\"timeline-badge\"><i v-if=\"step < stepper.currentStep\">done </i><span v-else>{{ step }}</span></div><div class=\"timeline-title text-bold\">{{{ title }}}</div><div class=\"timeline-content\" v-show=\"stepper && step === stepper.currentStep\" transition=\"slide\"><slot></slot><div class=\"group\" style=\"margin-top: 1rem; margin-left: -5px\"><button class=\"primary\" :class=\"{disabled: !ready}\" @click=\"nextStep()\">{{ stepper && step === stepper.steps ? 'Finish' : 'Continue' }}</button> <button class=\"primary clear\" v-if=\"step > 1\" @click=\"previousStep()\">Back</button></div></div></div>",
  props: {
    title: {
      type: String,
      required: true
    },
    ready: {
      type: Boolean,
      default: true
    }
  },
  data () {
    return {
      step: 0,
      stepper: {}
    }
  },
  watch: {
    visible () {
      this.__notify('reset')
    },
    disabled () {
      this.__notify('reset')
    }
  },
  methods: {
    nextStep () {
      if (this.ready) {
        this.__notify('nextStep')
      }
    },
    previousStep () {
      this.__notify('previousStep')
    },
    finish () {
      this.__notify('finish')
    },
    __notify (event) {
      this.$dispatch('stepper::' + event)
    }
  },
  ready () {
    this.__notify('reset')
  },
  destroyed () {
    this.__notify('reset')
  }
}

var Tab = { template: "<div class=\"quasar-tab items-center justify-center\" :class=\"{'v-link-active': active, hidden: hidden, disabled: disable, hideIcon: hide === 'icon', hideLabel: hide === 'label'}\" @click=\"activate()\"><i v-if=\"icon\" class=\"quasar-tabs-icon\">{{icon}}</i> <span class=\"quasar-tab-label\"><slot></slot></span></div>",
  props: ['active', 'hidden', 'disable', 'hide', 'icon', 'label', 'target'],
  methods: {
    activate () {
      if (this.disable) {
        return
      }
      this.active = true
    },
    setTargetVisibility (visible) {
      if (this.targetElement) {
        this.targetElement.style.display = visible ? '' : 'none'
      }
    }
  },
  computed: {
    targetElement () {
      // if no target
      if (!this.target) {
        return
      }

      return document.querySelector(this.target)
    }
  },
  events: {
    tabSelected (tab) {
      let targetIsMe = tab === this

      if (!targetIsMe) {
        this.active = false
      }

      this.setTargetVisibility(tab === this)
    }
  },
  watch: {
    active (value) {
      if (this.disable) {
        return
      }
      if (value) {
        this.$dispatch('selected', this)
      }
    },
    hidden (value) {
      this.$dispatch('hidden')
    },
    target (value, oldValue) {
      if (oldValue) {
        let oldTab = document.querySelector(oldValue)
        if (oldTab) {
          oldTab.style.display = 'none'
        }
      }
      this.$nextTick(() => {
        this.setTargetVisibility(this.active)
      })
    },
    '$route' (value) {
      this.$nextTick(() => {
        if (this.$el.classList.contains('v-link-active')) {
          this.$dispatch('selected', this)
        }
      })
    }
  },
  ready () {
    if (this.active && this.target || this.$el.classList.contains('v-link-active')) {
      this.$nextTick(() => {
        this.$dispatch('selected', this)
      })
    }
    else {
      this.setTargetVisibility(false)
    }
  }
}

const scrollNavigationSpeed = 5;
const debounceDelay = 50 // in ms

var Tabs = { template: "<div class=\"quasar-tabs row\"><div v-el:left-scroll class=\"row items-center justify-center left-scroll\"><i>chevron_left</i></div><div v-el:scroller class=\"quasar-tabs-scroller row\"><slot></slot></div><div v-el:right-scroll class=\"row items-center justify-center right-scroll\"><i>chevron_right</i></div></div>",
  methods: {
    redraw () {
      if (!Platform.is.desktop) {
        return
      }
      if (Utils.dom.width(this.$els.scroller) === 0 && this.$els.scroller.scrollWidth === 0) {
        return
      }
      if (Utils.dom.width(this.$els.scroller) + 5 < this.$els.scroller.scrollWidth) {
        this.$el.classList.add('scrollable')
        this.scrollable = true
        this.updateScrollIndicator()
      }
      else {
        this.$el.classList.remove('scrollable')
        this.scrollable = false
      }
    },
    updateScrollIndicator () {
      if (!Platform.is.desktop || !this.scrollable) {
        return
      }

      let action = this.$els.scroller.scrollLeft + Utils.dom.width(this.$els.scroller) + 5 >= this.$els.scroller.scrollWidth ? 'add' : 'remove'

      this.$els.leftScroll.classList[this.$els.scroller.scrollLeft <= 0 ? 'add' : 'remove']('disabled')
      this.$els.rightScroll.classList[action]('disabled')
    },
    scrollToSelectedIfNeeded (tab) {
      if (tab.length === 0 || !this.scrollable) {
        return
      }

      let
        contentRect = this.$els.scroller.getBoundingClientRect(),
        tabRect = tab.getBoundingClientRect(),
        tabWidth = tabRect.width,
        offset = tabRect.left - contentRect.left

      if (offset < 0) {
        this.animScrollTo(this.$els.scroller.scrollLeft + offset)
      }
      else {
        offset += tabWidth - this.$els.scroller.offsetWidth
        /* istanbul ignore else */
        if (offset > 0) {
          this.animScrollTo(this.$els.scroller.scrollLeft + offset)
        }
      }
    },
    animScrollTo (value) {
      if (this.scrollTimer) {
        clearInterval(this.scrollTimer)
      }

      this.scrollTowards(value)
      this.scrollTimer = setInterval(() => {
        if (this.scrollTowards(value)) {
          clearInterval(this.scrollTimer)
        }
      }, 5)
    },
    scrollTowards (value) {
      let
        scrollPosition = this.$els.scroller.scrollLeft,
        direction = value < scrollPosition ? -1 : 1,
        done = false

      scrollPosition += direction * scrollNavigationSpeed

      if (scrollPosition < 0) {
        done = true
        scrollPosition = 0
      }
      else if (direction === -1 && scrollPosition <= value || direction === 1 && scrollPosition >= value) {
        done = true
        scrollPosition = value
      }

      this.$els.scroller.scrollLeft = scrollPosition
      return done
    }
  },
  events: {
    selected (tab) {
      this.$broadcast('tabSelected', tab)

      setTimeout(() => {
        this.scrollToSelectedIfNeeded(tab.$el)
      }, debounceDelay * 4)
    },
    hidden () {
      this.redraw()
    }
  },
  watch: {
    '$children' () {
      this.redraw()
    }
  },
  ready () {
    this.scrollTimer = null
    this.scrollable = !Platform.is.desktop

    // debounce some costly methods;
    // debouncing here because debounce needs to be per instance
    this.redraw = Utils.debounce(this.redraw, debounceDelay)
    this.updateScrollIndicator = Utils.debounce(this.updateScrollIndicator, debounceDelay)

    this.$els.scroller.addEventListener('scroll', this.updateScrollIndicator)
    window.addEventListener('resize', this.redraw)

    // let browser drawing stabilize then
    setTimeout(() => { this.redraw() }, debounceDelay)

    if (Platform.is.desktop) {
      var scrollEvents = {
        start: [],
        stop: []
      }

      scrollEvents.start.push('mousedown')
      scrollEvents.stop.push('mouseup')

      if (Platform.has.touch) {
        scrollEvents.start.push('touchstart')
        scrollEvents.stop.push('touchend')
      }

      scrollEvents.start.forEach(evt => {
        this.$els.leftScroll.addEventListener(evt, () => {
          this.animScrollTo(0)
        })
        this.$els.rightScroll.addEventListener(evt, () => {
          this.animScrollTo(9999)
        })
      })
      scrollEvents.stop.forEach(evt => {
        this.$els.leftScroll.addEventListener(evt, () => {
          clearInterval(this.scrollTimer)
        })
        this.$els.rightScroll.addEventListener(evt, () => {
          clearInterval(this.scrollTimer)
        })
      })
    }
  },
  beforeDestroy () {
    if (this.scrollTimer) {
      clearInterval(this.scrollTimer)
    }
    this.$els.scroller.removeEventListener('scroll', this.updateScrollIndicator)
    window.removeEventListener('resize', this.redraw)
  }
}

var Toggle = { template: "<label class=\"quasar-toggle\" :class=\"{disabled: disable}\" v-touch:pan=\"toggle\" v-touch-options:pan=\"{ direction: 'horizontal' }\"><input type=\"checkbox\" v-model=\"model\" v-attr=\"attrib\"><div></div><i v-if=\"icon\">{{ icon }}</i></label>",
  props: {
    model: {
      type: Boolean,
      twoWay: true,
      required: true
    },
    disable: {
      type: Boolean,
      default: false,
      coerce: Boolean
    },
    icon: String
  },
  computed: {
    attrib () {
      return this.disable ? 'disabled' : []
    }
  },
  methods: {
    toggle (event) {
      if (
        !this.disable &&
        event.isFinal &&
        (this.model && event.deltaX < 0 || !this.model && event.deltaX > 0)
      ) {
        this.model = !this.model
      }
    }
  }
}

var Tree = { template: "<div class=\"quasar-tree\"><ul><quasar-tree-item v-for=\"item in model\" :model=\"item\" :contract-html=\"contractHtml\" :expand-html=\"expandHtml\"></quasar-tree-item></ul></div>",
  props: {
    model: {
      type: Array,
      required: true
    },
    contractHtml: {
      type: String,
      required: true
    },
    expandHtml: {
      type: String,
      required: true
    }
  }
}

var TreeItem = { template: "<li class=\"quasar-tree-item\"><div :class=\"{'quasar-tree-expandable-item': isExpandable, 'quasar-tree-link': model.handler}\" @click=\"toggle\"><i v-if=\"model.icon\">{{model.icon}}</i> <span class=\"quasar-tree-label\">{{model.title}}</span> <span v-if=\"isExpandable\">{{{model.expanded ? contractHtml : expandHtml}}}</span></div><ul v-show=\"model.expanded\" v-if=\"isExpandable\" transition=\"slide\"><quasar-tree-item v-for=\"item in model.children\" :model=\"item\" :contract-html=\"contractHtml\" :expand-html=\"expandHtml\"></quasar-tree-item></ul></li>",
  props: ['model', 'contract-html', 'expand-html'],
  methods: {
    toggle () {
      if (this.isExpandable) {
        this.model.expanded = !this.model.expanded
        return
      }

      if (typeof this.model.handler === 'function') {
        this.model.handler(this.model)
      }
    }
  },
  computed: {
    isExpandable () {
      return this.model.children && this.model.children.length
    }
  }
}

var Video = { template: "<div class=\"video\"><iframe :src=\"src\" frameborder=\"0\" allowfullscreen></iframe></div>",
  props: ['src']
}

function registerTransitions (_Vue) {
  _Vue.transition('slide', transitionSlide)
}

function registerFilters (_Vue) {
  _Vue.filter('gridShowSelected', GridSelectedFilter)
}

function registerDirectives (_Vue) {
  _Vue.directive('attr', directiveAttr)
  _Vue.directive('go-back', directiveGoBack)
  _Vue.directive('scroll-fire', directiveScrollFire)
  _Vue.directive('scroll', directiveScroll)
  _Vue.directive('tooltip', directiveTooltip)
}

function registerComponents (_Vue) {
  _Vue.component('quasar-checkbox', Checkbox)
  _Vue.component('quasar-chips', Chips)
  _Vue.component('quasar-collapsible', Collapsible)
  _Vue.component('quasar-context-menu', Platform.is.desktop ? ContextMenuDesktop : ContextMenuMobile)
  _Vue.component('quasar-inline-datetime', current === 'ios' ? iOSInlineDatetime : MaterialInlineDatetime)
  _Vue.component('quasar-datetime', Platform.is.desktop && !Platform.within.iframe ? InputDatetimeDesktop : InputDatetimeMobile)
  _Vue.component('quasar-drawer', Drawer)
  _Vue.component('quasar-drawer-link', DrawerLink)
  _Vue.component('quasar-fab', Fab)
  _Vue.component('quasar-small-fab', SmallFab)
  _Vue.component('quasar-gallery', Gallery)
  _Vue.component('quasar-gallery-slider', GallerySlider)
  _Vue.component('quasar-grid', Grid)
  _Vue.component('quasar-grid-table', GridTable)
  _Vue.component('quasar-infinite-scroll', InfiniteScroll)
  _Vue.component('quasar-knob', Knob)
  _Vue.component('quasar-layout', Layout)
  _Vue.component('quasar-toolbar-title', ToolbarTitle)
  _Vue.component('quasar-modal', Modal$2)
  _Vue.component('quasar-numeric', Numeric)
  _Vue.component('quasar-pagination', Pagination)
  _Vue.component('quasar-parallax', Parallax)
  _Vue.component('quasar-popover', Popover)
  _Vue.component('quasar-progress', Progress)
  _Vue.component('quasar-progress-button', ProgressButton)
  _Vue.component('quasar-pull-to-refresh', PullToRefresh)
  _Vue.component('quasar-radio', Radio)
  _Vue.component('quasar-range', Range)
  _Vue.component('quasar-double-range', DoubleRange)
  _Vue.component('quasar-rating', Rating)
  _Vue.component('quasar-search', Search)
  _Vue.component('quasar-select', Select)
  _Vue.component('quasar-dialog-select', DialogSelect)
  _Vue.component('quasar-slider', Slider)
  _Vue.component('quasar-state', State)
  _Vue.component('quasar-stepper', Stepper)
  _Vue.component('quasar-step', Step)
  _Vue.component('quasar-tab', Tab)
  _Vue.component('quasar-tabs', Tabs)
  _Vue.component('quasar-toggle', Toggle)
  _Vue.component('quasar-tree', Tree)
  _Vue.component('quasar-tree-item', TreeItem)
  _Vue.component('quasar-video', Video)
}

var Vue

var install = function (_Vue) {
  if (this.installed) {
    console.warn('Quasar already installed in Vue.')
    return
  }

  Vue = _Vue

  registerTransitions(_Vue)
  registerFilters(_Vue)
  registerDirectives(_Vue)
  registerComponents(_Vue)
  registerSpinners(_Vue)

  Events.trigger('app:vue-ready', Vue)
}

function addClass (className) {
  document.body.classList.add(className)
}

addClass(Platform.is.desktop ? 'desktop' : 'mobile')
addClass(Platform.has.touch ? 'touch' : 'no-touch')

if (Platform.within.iframe) {
  addClass('within-iframe')
}

if (Platform.is.cordova) {
  addClass('cordova')
}

var start = function (callback = function () {}) {
  if (!current) {
    set(Platform.is.ios ? 'ios' : 'mat')
  }

  /*
    if on Cordova, but not on an iframe,
    like on Quasar Play app
   */
  if (Platform.is.cordova && !Platform.within.iframe) {
    var tag = document.createElement('script')

    document.addEventListener('deviceready', callback, false)

    tag.type = 'text/javascript'
    document.body.appendChild(tag)
    tag.src = 'cordova.js'

    return
  }

  callback()
}

var init = function (Quasar) {
  // auto install in standalone mode
  if (typeof window !== 'undefined' && window.Vue) {
    window.Quasar = Quasar
    window.Vue.use(Quasar)
  }
}

/* eslint-disable no-extend-native, one-var, no-self-compare */

if (!Array.prototype.includes) {
  Array.prototype.includes = function (searchElement, startFrom) {
    'use strict'

    let O = Object(this)
    let len = parseInt(O.length, 10) || 0
    if (len === 0) {
      return false
    }
    let n = parseInt(startFrom, 10) || 0
    let k
    if (n >= 0) {
      k = n
    }
    else {
      k = len + n
      if (k < 0) { k = 0 }
    }
    let currentElement
    while (k < len) {
      currentElement = O[k]
      if (searchElement === currentElement ||
         (searchElement !== searchElement && currentElement !== currentElement)) { // NaN !== NaN
        return true
      }
      k++
    }
    return false
  }
}

if (!String.prototype.startsWith) {
  String.prototype.startsWith = function (searchString, position) {
    position = position || 0
    return this.substr(position, searchString.length) === searchString
  }
}

if (!String.prototype.endsWith) {
  String.prototype.endsWith = function (searchString, position) {
    let subjectString = this.toString()

    if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
      position = subjectString.length
    }
    position -= searchString.length

    let lastIndex = subjectString.indexOf(searchString, position)

    return lastIndex !== -1 && lastIndex === position
  }
}

if (typeof Element.prototype.matches !== 'function') {
  Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.mozMatchesSelector || Element.prototype.webkitMatchesSelector || function matches (selector) {
    let
      element = this,
      elements = (element.document || element.ownerDocument).querySelectorAll(selector),
      index = 0

    while (elements[index] && elements[index] !== element) {
      ++index
    }

    return Boolean(elements[index])
  }
}

if (typeof Element.prototype.closest !== 'function') {
  Element.prototype.closest = function closest (selector) {
    let element = this

    while (element && element.nodeType === 1) {
      if (element.matches(selector)) {
        return element
      }

      element = element.parentNode
    }

    return null
  }
}

/*
 * Capture errors
 */
window.onerror = function (message, source, lineno, colno, error) {
  Events.trigger('app:error', {
    message: message,
    source: source,
    lineno: lineno,
    colno: colno,
    error: error
  })
}

if (Platform.has.touch) {
  FastClick.attach(document.body)
}

var matTemplate = "<div>\n  <div v-if=\"title\" class=\"modal-header\">\n    {{{* title}}}\n  </div>\n\n  <div class=\"modal-scroll\">\n    <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"cursor-pointer column inline items-center justify-center\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n        <span>{{* button.label}}</span>\n      </div>\n    </div>\n    <div v-else class=\"list no-border\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"item item-link\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\" class=\"item-primary\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"item-primary\">\n        <div class=\"item-content inset\">\n          {{* button.label}}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"list no-border\">\n    <div\n      class=\"item item-link\"\n      @click=\"close(dismissButton.handler)\"\n      :class=\"dismissButton.classes\"\n    >\n      <i v-if=\"dismissButton.icon\" class=\"item-primary\">{{* dismissButton.icon}}</i>\n      <div class=\"item-content inset\">\n        {{* dismissButton.label}}\n      </div>\n    </div>\n  </div>\n</div>\n";

var iosTemplate = "<div>\n  <div class=\"quasar-action-sheet\">\n    <div v-if=\"title\" class=\"modal-header\">\n      {{{* title}}}\n    </div>\n\n    <div class=\"modal-scroll\">\n      <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n        <div\n          v-for=\"button in buttons\"\n          class=\"cursor-pointer column inline items-center justify-center\"\n          @click=\"close(button.handler)\"\n          :class=\"button.classes\"\n        >\n          <i v-if=\"button.icon\">{{* button.icon}}</i>\n          <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n          <span>{{* button.label}}</span>\n        </div>\n      </div>\n      <div v-else class=\"list no-border\">\n        <div\n          v-for=\"button in buttons\"\n          class=\"item item-link\"\n          @click=\"close(button.handler)\"\n          :class=\"button.classes\"\n        >\n          <i v-if=\"button.icon\" class=\"item-primary\">{{* button.icon}}</i>\n          <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"item-primary\">\n          <div class=\"item-content inset\">\n            {{* button.label}}\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"quasar-action-sheet\">\n    <div\n      class=\"item item-link\"\n      @click=\"close(dismissButton.handler)\"\n      :class=\"dismissButton.classes\"\n    >\n      <div class=\"item-content row justify-center\">\n        {{* dismissButton.label}}\n      </div>\n    </div>\n  </div>\n</div>\n";

let css$1 = {
  mat: {
    maxHeight: '80vh',
    height: 'auto'
  },
  ios: {
    maxHeight: '80vh',
    height: 'auto',
    backgroundColor: 'transparent',
    boxShadow: 'none'
  }
}

function parseButtons$1 (buttons) {
  if (!Array.isArray(buttons)) {
    throw new Error('Action Sheet buttons parameter must be an array.')
  }

  if (buttons.length <= 1) {
    throw new Error('Action Sheet requires at least one button')
  }

  if (buttons.some(
    button => Object(button) !== button || !button.label || !button.handler
  )) {
    throw new Error('At least one of Action Sheet\'s button parameter is not an object or missing label and/or handler.')
  }

  return buttons.map(button => {
    if (button.classes) {
      if (Array.isArray(button.classes)) {
        button.classes = button.classes.split(' ')
      }
      else if (typeof button.classes !== 'string') {
        throw new Error('Action Sheet button "classes" parameter must be either an array or string')
      }
    }
    return button
  })
}

var actionSheet = {
  create (data) {
    data.buttons = parseButtons$1(data.buttons)
    data.dismissButton = data.buttons.pop()

    let modal = Modal$1.create({
      template: current === 'ios' ? iosTemplate : matTemplate,
      data
    })
    .css(css$1[current])
    .set({
      transitionIn: {translateY: [0, '101%']},
      transitionOut: {translateY: ['101%', 0]},
      onBackButton: data.dismissButton.handler,
      onEscapeKey: data.dismissButton.handler
    })

    modal.$el.classList.remove('items-center')
    modal.$el.classList.add('items-end')
    modal.$backdrop.addEventListener('click', () => {
      modal.close(data.dismissButton.handler)
    })

    return modal
  }
}

let transitionDuration = 300;
let displayDuration = 2500 // in ms

function parseOptions (opts, defaults) {
  if (!opts) {
    throw new Error('Missing toast options.')
  }

  let options = Utils.extend(
    true,
    {},
    defaults,
    typeof opts === 'string' ? {html: opts} : opts
  )

  if (!options.html) {
    throw new Error('Missing toast content/HTML.')
  }

  return options
}

var Toast = { template: "<div class=\"quasar-toast-container\" :class=\"{active: active}\"><div class=\"quasar-toast row no-wrap items-center non-selectable\" v-if=\"stack[0]\" :style=\"{color: stack[0].color, background: stack[0].bgColor}\" :class=\"classes\"><i v-if=\"stack[0].icon\">{{ stack[0].icon }}</i> <img v-if=\"stack[0].image\" :src=\"stack[0].image\"><div class=\"quasar-toast-message auto\">{{{ stack[0].html }}}</div><a v-if=\"stack[0].button && stack[0].button.label\" @click=\"dismiss(stack[0].button.handler)\" :style=\"{color: stack[0].button.color}\">{{ stack[0].button.label }} </a><a @click=\"dismiss()\" :style=\"{color: stack[0].button.color}\"><i>close</i></a></div></div>",
  data () {
    return {
      active: false,
      inTransition: false,
      stack: [],
      timer: null,
      defaults: {
        color: 'white',
        bgColor: '#323232',
        button: {
          color: 'yellow'
        }
      }
    }
  },
  computed: {
    classes () {
      if (!this.stack.length || !this.stack[0].classes) {
        return {}
      }

      return this.stack[0].classes.split(' ')
    }
  },
  methods: {
    create (options) {
      this.stack.push(parseOptions(options, this.defaults))

      if (this.active || this.inTransition) {
        return
      }

      this.active = true
      this.inTransition = true

      this.__show()
    },
    __show () {
      Events.trigger('app:toast', this.stack[0].html)

      this.timer = setTimeout(() => {
        if (this.stack.length > 0) {
          this.dismiss()
        }
        else {
          this.inTransition = false
        }
      }, transitionDuration + (this.stack[0].timeout || displayDuration))
    },
    dismiss (done) {
      this.active = false

      if (this.timer) {
        clearTimeout(this.timer)
        this.timer = null
      }

      setTimeout(() => {
        if (typeof this.stack[0].onDismiss === 'function') {
          this.stack[0].onDismiss()
        }

        this.stack.shift()
        done && done()

        if (this.stack.length > 0) {
          this.active = true
          this.__show()
          return
        }

        this.inTransition = false
      }, transitionDuration + 50)
    },
    setDefaults (opts) {
      Utils.extend(true, this.defaults, opts)
    }
  }
}

let toast;
let types = [
    {
      name: 'positive',
      defaults: {icon: 'check', classes: 'bg-positive'}
    },
    {
      name: 'negative',
      defaults: {icon: 'whatshot', classes: 'bg-negative'}
    },
    {
      name: 'info',
      defaults: {icon: 'info', classes: 'bg-info'}
    },
    {
      name: 'warning',
      defaults: {icon: 'warning', classes: 'bg-warning'}
    }
  ]

Events.on('app:vue-ready', (_Vue) => {
  toast = new _Vue(Toast)
  toast.$mount().$appendTo(document.body)
})

function create$1 (opts, defaults) {
  if (!opts) {
    throw new Error('Missing toast options.')
  }

  if (defaults) {
    opts = Utils.extend(
      true,
      typeof opts === 'string' ? {html: opts} : opts,
      defaults
    )
  }

  toast.create(opts)
}

types.forEach(type => {
  create$1[type.name] = opts => create$1(opts, type.defaults)
})

var toast$1 = {
  create: create$1,
  setDefaults (opts) {
    toast.setDefaults(opts)
  }
}

function isActive () {
  return document.fullscreenElement ||
      document.mozFullScreenElement ||
      document.webkitFullscreenElement ||
      document.msFullscreenElement
}

function request (target) {
  target = target || document.documentElement

  if (isActive()) {
    return
  }

  if (target.requestFullscreen) {
    target.requestFullscreen()
  }
  else if (target.msRequestFullscreen) {
    target.msRequestFullscreen()
  }
  else if (target.mozRequestFullScreen) {
    target.mozRequestFullScreen()
  }
  else if (target.webkitRequestFullscreen) {
    target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT) // eslint-disable-line no-undef
  }
}

function exit () {
  if (document.exitFullscreen) {
    document.exitFullscreen()
  }
  else if (document.msExitFullscreen) {
    document.msExitFullscreen()
  }
  else if (document.mozCancelFullScreen) {
    document.mozCancelFullScreen()
  }
  else if (document.webkitExitFullscreen) {
    document.webkitExitFullscreen()
  }
}

function toggle (target) {
  if (isActive()) {
    exit()
  }
  else {
    request(target)
  }
}

var appFullscreen = {
  isActive,
  request,
  exit,
  toggle
}

let hidden = 'hidden';
let appVisibility = 'visible'

function onchange (evt) {
  let
    v = 'visible',
    h = 'hidden',
    state,
    evtMap = {
      focus: v,
      focusin: v,
      pageshow: v,
      blur: h,
      focusout: h,
      pagehide: h
    }

  evt = evt || window.event

  if (evt.type in evtMap) {
    state = evtMap[evt.type]
  }
  else {
    state = this[hidden] ? h : v
  }

  appVisibility = state
  Events.trigger('app:visibility', state)
}

Utils.dom.ready(() => {
  // Standards:
  if (hidden in document) {
    document.addEventListener('visibilitychange', onchange)
  }
  else if ((hidden = 'mozHidden') in document) {
    document.addEventListener('mozvisibilitychange', onchange)
  }
  else if ((hidden = 'webkitHidden') in document) {
    document.addEventListener('webkitvisibilitychange', onchange)
  }
  else if ((hidden = 'msHidden') in document) {
    document.addEventListener('msvisibilitychange', onchange)
  }
  // IE 9 and lower:
  else if ('onfocusin' in document) {
    document.onfocusin = document.onfocusout = onchange
  }
  // All others:
  else {
    window.onpageshow = window.onpagehide = window.onfocus = window.onblur = onchange
  }

  // set the initial state (but only if browser supports the Page Visibility API)
  if (document[hidden] !== undefined) {
    onchange({type: document[hidden] ? 'blur' : 'focus'})
  }
})

var appVisibility$1 = {
  isVisible: () => appVisibility === 'visible'
}

function encode (string) {
  return encodeURIComponent(string)
}

function decode (string) {
  return decodeURIComponent(string)
}

function stringifyCookieValue (value) {
  return encode(value === Object(value) ? JSON.stringify(value) : '' + value)
}

function read (string) {
  if (string === '') {
    return string
  }

  if (string.indexOf('"') === 0) {
    // This is a quoted cookie as according to RFC2068, unescape...
    string = string.slice(1, -1).replace(/\\"/g, '"').replace(/\\\\/g, '\\')
  }

  // Replace server-side written pluses with spaces.
  // If we can't decode the cookie, ignore it, it's unusable.
  // If we can't parse the cookie, ignore it, it's unusable.
  string = decode(string.replace(/\+/g, ' '))

  try {
    string = JSON.parse(string)
  }
  catch (e) {}

  return string
}

function set$1 (key, value, options = {}) {
  let
    days = options.expires,
    time = options.expires = new Date()

  if (typeof options.expires === 'number') {
    time.setMilliseconds(time.getMilliseconds() + days * 864e+5)
  }

  document.cookie = [
    encode(key), '=', stringifyCookieValue(value),
    options.expires ? ' expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
    options.path ? ' path=' + options.path : '',
    options.domain ? ' domain=' + options.domain : '',
    options.secure ? ' secure' : ''
  ].join('')
}

function get (key) {
  let
    result = key ? undefined : {},
    cookies = document.cookie ? document.cookie.split(' ') : [],
    i = 0,
    l = cookies.length,
    parts,
    name,
    cookie

  for (; i < l; i++) {
    parts = cookies[i].split('=')
    name = decode(parts.shift())
    cookie = parts.join('=')

    if (!key) {
      result[name] = cookie
    }
    else if (key === name) {
      result = read(cookie)
      break
    }
  }

  return result
}

function remove$1 (key, options) {
  set$1(key, '', Utils.extend(true, {}, options, {
    expires: -1
  }))
}

function has (key) {
  return get(key) !== undefined
}

var cookies = {
  get,
  set: set$1,
  has,
  remove: remove$1,
  all: () => get()
}

let vm;
let appIsInProgress = false;
let timeout

const template$1 = `
    <div class="quasar-loading fullscreen column items-center justify-center z-absolute">
      <spinner :name="spinner" color="#fff" :size="80"></spinner>
      <div v-if="message" style="margin: 40px 20px 0 20px; max-width: 450px; text-align: center; color: white; text-shadow: 0 0 7px black">{{ message }}</div>
    </div>
  `

function isActive$1 () {
  return appIsInProgress
}

function show ({
  delay = 500,
  spinner = current === 'ios' ? 'ios' : 'tail',
  message = false
} = {}) {
  if (appIsInProgress) {
    vm.$data = {spinner, message}
    return
  }

  timeout = setTimeout(() => {
    document.body.classList.add('dimmed')

    vm = new Vue({
      template: template$1,
      data: {
        spinner,
        message
      }
    })

    vm.$mount().$appendTo(document.body)

    timeout = null
  }, delay)

  appIsInProgress = true
  Events.trigger('app:loading', true)
}

function hide () {
  if (!appIsInProgress) {
    return
  }

  if (timeout) {
    clearTimeout(timeout)
    timeout = null
  }
  else {
    document.body.classList.remove('dimmed')
    vm.$destroy(true)
  }

  appIsInProgress = false
  Events.trigger('app:loading', false)
}

var loading = {
  isActive: isActive$1,
  show,
  hide
}

function encode$1 (value) {
  if (Object.prototype.toString.call(value) === '[object Date]') {
    return '__q_date|' + value.toUTCString()
  }
  if (Object.prototype.toString.call(value) === '[object RegExp]') {
    return '__q_expr|' + value.source
  }
  if (typeof value === 'number') {
    return '__q_numb|' + value
  }
  if (typeof value === 'boolean') {
    return '__q_bool|' + (value ? '1' : '0')
  }
  if (typeof value === 'string') {
    return '__q_strn|' + value
  }
  if (typeof value === 'function') {
    return '__q_strn|' + value.toString()
  }
  if (value === Object(value)) {
    return '__q_objt|' + JSON.stringify(value)
  }

  // hmm, we don't know what to do with it,
  // so just return it as is
  return value
}

function decode$1 (value) {
  let type, length, source

  length = value.length
  if (length < 10) {
    // then it wasn't encoded by us
    return value
  }

  type = value.substr(0, 8)
  source = value.substring(9)

  switch (type) {
    case '__q_date':
      return new Date(source)

    case '__q_expr':
      return new RegExp(source)

    case '__q_numb':
      return Number(source)

    case '__q_bool':
      return Boolean(source === '1')

    case '__q_strn':
      return '' + source

    case '__q_objt':
      return JSON.parse(source)

    default:
      // hmm, we reached here, we don't know the type,
      // then it means it wasn't encoded by us, so just
      // return whatever value it is
      return value
  }
}

function generateFunctions (fn) {
  return {
    local: fn('local'),
    session: fn('session')
  }
}

let hasStorageItem = generateFunctions(
    (type) => (key) => window[type + 'Storage'].getItem(key) !== null
  );
let getStorageLength = generateFunctions(
    (type) => () => window[type + 'Storage'].length
  );
let getStorageItem = generateFunctions((type) => {
    let
      hasFn = hasStorageItem[type],
      storage = window[type + 'Storage']

    return (key) => {
      if (hasFn(key)) {
        return decode$1(storage.getItem(key))
      }
      return null
    }
  });
let getStorageAtIndex = generateFunctions((type) => {
    let
      lengthFn = getStorageLength[type],
      getItemFn = getStorageItem[type],
      storage = window[type + 'Storage']

    return (index) => {
      if (index < lengthFn()) {
        return getItemFn(storage.key(index))
      }
    }
  });
let getAllStorageItems = generateFunctions((type) => {
    let
      lengthFn = getStorageLength[type],
      storage = window[type + 'Storage'],
      getItemFn = getStorageItem[type]

    return () => {
      let
        result = {},
        key,
        length = lengthFn()

      for (let i = 0; i < length; i++) {
        key = storage.key(i)
        result[key] = getItemFn(key)
      }

      return result
    }
  });
let setStorageItem = generateFunctions((type) => {
    let storage = window[type + 'Storage']
    return (key, value) => { storage.setItem(key, encode$1(value)) }
  });
let removeStorageItem = generateFunctions((type) => {
    let storage = window[type + 'Storage']
    return (key) => { storage.removeItem(key) }
  });
let clearStorage = generateFunctions((type) => {
    let storage = window[type + 'Storage']
    return () => { storage.clear() }
  });
let storageIsEmpty = generateFunctions((type) => {
    let getLengthFn = getStorageLength[type]
    return () => getLengthFn() === 0
  })

var LocalStorage = {
  has: hasStorageItem.local,
  get: {
    length: getStorageLength.local,
    item: getStorageItem.local,
    index: getStorageAtIndex.local,
    all: getAllStorageItems.local
  },
  set: setStorageItem.local,
  remove: removeStorageItem.local,
  clear: clearStorage.local,
  isEmpty: storageIsEmpty.local
}

var SessionStorage = { // eslint-disable-line one-var
  has: hasStorageItem.session,
  get: {
    length: getStorageLength.session,
    item: getStorageItem.session,
    index: getStorageAtIndex.session,
    all: getAllStorageItems.session
  },
  set: setStorageItem.session,
  remove: removeStorageItem.session,
  clear: clearStorage.session,
  isEmpty: storageIsEmpty.session
}

window.Velocity = Velocity$1
let Quasar = {
  version: '0.7.1',
  install,
  start,
  theme
}

init(Quasar)

export { actionSheet as ActionSheet, Dialog, appFullscreen as AppFullscreen, appVisibility$1 as AppVisibility, cookies as Cookies, Platform, Events, loading as Loading, Modal$1 as Modal, toast$1 as Toast, Utils, LocalStorage, SessionStorage, theme };export default Quasar;
